@@ -1,4 +1,4 @@
-<?php # $Id: comments.inc.php 1490 2006-11-05 11:19:55Z garvinhicking $
+<?php # $Id: comments.inc.php 1458 2006-10-26 09:46:53Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -10,10 +10,10 @@ if (!serendipity_checkPermission('adminComments')) {
     return;
 }
 
-$commentsPerPage = (!empty($serendipity['GET']['filter']['perpage']) ? $serendipity['GET']['filter']['perpage'] : 10);
+$commentsPerPage = (int)(!empty($serendipity['GET']['filter']['perpage']) ? $serendipity['GET']['filter']['perpage'] : 10);
 $summaryLength = 200;
 
-if ( $serendipity['POST']['formAction'] == 'multiDelete' && sizeof($serendipity['POST']['delete']) != 0 && serendipity_checkFormToken()) {
+if ($serendipity['POST']['formAction'] == 'multiDelete' && sizeof($serendipity['POST']['delete']) != 0 && serendipity_checkFormToken()) {
     foreach ( $serendipity['POST']['delete'] as $k => $v ) {
         serendipity_deleteComment($k, $v);
         echo DONE . ': '. sprintf(COMMENT_DELETED, $k) . '<br />';
@@ -22,7 +22,7 @@ if ( $serendipity['POST']['formAction'] == 'multiDelete' && sizeof($serendipity[
 
 
 /* We are asked to save the edited comment, and we are not in preview mode */
-if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'doEdit' && !isset($serendipity['POST']['preview']) && serendipity_checkFormToken()) {
+if (isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'doEdit' && !isset($serendipity['POST']['preview']) && serendipity_checkFormToken()) {
     $sql = "UPDATE {$serendipity['dbPrefix']}comments
                     SET
                         author    = '" . serendipity_db_escape_string($serendipity['POST']['name'])    . "',
@@ -36,9 +36,32 @@ if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminActi
     echo COMMENT_EDITED;
 }
 
+/* Submit a new comment */
+if (isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'doReply' && !isset($serendipity['POST']['preview']) && serendipity_checkFormToken()) {
+    $comment = array();
+    $comment['url']       = $serendipity['POST']['url'];
+    $comment['comment']   = trim($serendipity['POST']['comment']);
+    $comment['name']      = $serendipity['POST']['name'];
+    $comment['email']     = $serendipity['POST']['email'];
+    $comment['subscribe'] = $serendipity['POST']['subscribe'];
+    $comment['parent_id'] = $serendipity['POST']['replyTo'];
+    if (!empty($comment['comment'])) {
+        if (serendipity_saveComment($serendipity['POST']['entry_id'], $comment, 'NORMAL')) {
+            echo '<script type="text/javascript">alert("' . COMMENT_ADDED . '"); parent.focus(); this.close();</script>';
+            echo '<noscript>' . COMMENT_ADDED . '</noscript>';
+            return true;
+        } else {
+            echo COMMENT_NOT_ADDED;
+            $serendipity['GET']['adminAction'] = 'reply';
+        }
+    } else {
+        echo COMMENT_NOT_ADDED;
+        $serendipity['GET']['adminAction'] = 'reply';
+    }
+}
 
 /* We approve a comment */
-if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'approve' && serendipity_checkFormToken()) {
+if (isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'approve' && serendipity_checkFormToken()) {
     $sql = "SELECT c.*, e.title, a.email as authoremail, a.mail_comments
             FROM {$serendipity['dbPrefix']}comments c
             LEFT JOIN {$serendipity['dbPrefix']}entries e ON (e.id = c.entry_id)
@@ -47,58 +70,89 @@ if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminActi
     $rs  = serendipity_db_query($sql, true);
 
     if ($rs === false) {
-        echo ERROR .': '. sprintf(COMMENT_ALREADY_APPROVED, $serendipity['GET']['id']);
+        echo ERROR .': '. sprintf(COMMENT_ALREADY_APPROVED, (int)$serendipity['GET']['id']);
     } else {
         serendipity_approveComment($serendipity['GET']['id'], $rs['entry_id']);
-        echo DONE . ': '. sprintf(COMMENT_APPROVED, $serendipity['GET']['id']);
+        echo DONE . ': '. sprintf(COMMENT_APPROVED, (int)$serendipity['GET']['id']);
     }
 }
 
 /* We are asked to delete a comment */
-if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'delete' && serendipity_checkFormToken()) {
+if (isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'delete' && serendipity_checkFormToken()) {
     serendipity_deleteComment($serendipity['GET']['id'], $serendipity['GET']['entry_id']);
-    echo DONE . ': '. sprintf(COMMENT_DELETED, $serendipity['GET']['id']);
+    echo DONE . ': '. sprintf(COMMENT_DELETED, (int)$serendipity['GET']['id']);
 }
 
 /* We are either in edit mode, or preview mode */
-if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminAction'] == 'edit' || isset($serendipity['POST']['preview'])) {
+if (isset($serendipity['GET']['adminAction']) && ($serendipity['GET']['adminAction'] == 'edit' || $serendipity['GET']['adminAction'] == 'reply') || isset($serendipity['POST']['preview'])) {
 
     $serendipity['smarty_raw_mode'] = true; // Force output of Smarty stuff in the backend
     serendipity_smarty_init();
 
-    /* If we are not in preview, we need data from our database */
-    if (!isset($serendipity['POST']['preview']) ) {
-        $comment = serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}comments WHERE id = ". (int)$serendipity['GET']['id']);
-        $data['name']       = $comment[0]['author'];
-        $data['email']      = $comment[0]['email'];
-        $data['url']        = $comment[0]['url'];
-        $data['replyTo']    = $comment[0]['parent_id'];
-        $data['comment']    = $comment[0]['body'];
+    if ($serendipity['GET']['adminAction'] == 'reply' || $serendipity['GET']['adminAction'] == 'doReply') {
+        $c          = serendipity_fetchComments($serendipity['GET']['entry_id'], 1, 'co.id', false, 'NORMAL', ' AND co.id=' . (int)$serendipity['GET']['id']);
 
-    /* If we are in preview, we get data from our form */
-    } elseif ( isset($serendipity['POST']['preview']) ) {
-        $data['name']       = $serendipity['POST']['name'];
-        $data['email']      = $serendipity['POST']['email'];
-        $data['url']        = $serendipity['POST']['url'];
-        $data['replyTo']    = $serendipity['POST']['replyTo'];
-        $data['comment']    = $serendipity['POST']['comment'];
-        $pc_data = array(
-                array(
-                  'email'     => $serendipity['POST']['email'],
-                  'author'    => $serendipity['POST']['name'],
-                  'body'      => $serendipity['POST']['comment'],
-                  'url'       => $serendipity['POST']['url'],
-                  'timestamp' => time()
-                )
-              );
-
-        serendipity_printComments($pc_data);
+        if (isset($serendipity['POST']['preview'])) {
+            $c[] = array(
+                      'email'     => $serendipity['POST']['email'],
+                      'author'    => $serendipity['POST']['name'],
+                      'body'      => $serendipity['POST']['comment'],
+                      'url'       => $serendipity['POST']['url'],
+                      'timestamp' => time(),
+                      'parent_id' => $serendipity['GET']['id']
+            );
+        }
+        
+        $target_url = '?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=doReply&amp;serendipity[id]=' . (int)$serendipity['GET']['id'] . '&amp;serendipity[entry_id]=' . (int)$serendipity['GET']['entry_id'] . '&amp;serendipity[noBanner]=true&amp;serendipity[noSidebar]=true&amp;' . serendipity_setFormToken('url');
+        $data       = $serendipity['POST'];
+        $data['replyTo'] = (int)$serendipity['GET']['id'];
+        $out        = serendipity_printComments($c);
         $serendipity['smarty']->display(serendipity_getTemplateFile('comments.tpl', 'serendipityPath'));
+        
+        if (!isset($data['name'])) {
+            $data['name']  = $serendipity['serendipityRealname'];
+        }
+
+        if (!isset($data['email'])) {
+            $data['email']  = $serendipity['serendipityEmail'];
+        }
+    } else {
+        $target_url = '?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=doEdit&amp;serendipity[id]=' . (int)$serendipity['GET']['id'] . '&amp;serendipity[entry_id]=' . (int)$serendipity['GET']['entry_id'] . '&amp;' . serendipity_setFormToken('url');
+
+        /* If we are not in preview, we need data from our database */
+        if (!isset($serendipity['POST']['preview'])) {
+            $comment = serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}comments WHERE id = ". (int)$serendipity['GET']['id']);
+            $data['name']       = $comment[0]['author'];
+            $data['email']      = $comment[0]['email'];
+            $data['url']        = $comment[0]['url'];
+            $data['replyTo']    = $comment[0]['parent_id'];
+            $data['comment']    = $comment[0]['body'];
+    
+        /* If we are in preview, we get data from our form */
+        } elseif (isset($serendipity['POST']['preview'])) {
+            $data['name']       = $serendipity['POST']['name'];
+            $data['email']      = $serendipity['POST']['email'];
+            $data['url']        = $serendipity['POST']['url'];
+            $data['replyTo']    = $serendipity['POST']['replyTo'];
+            $data['comment']    = $serendipity['POST']['comment'];
+            $pc_data = array(
+                    array(
+                      'email'     => $serendipity['POST']['email'],
+                      'author'    => $serendipity['POST']['name'],
+                      'body'      => $serendipity['POST']['comment'],
+                      'url'       => $serendipity['POST']['url'],
+                      'timestamp' => time()
+                    )
+                  );
+    
+            serendipity_printComments($pc_data);
+            $serendipity['smarty']->display(serendipity_getTemplateFile('comments.tpl', 'serendipityPath'));
+        }
     }
 
     serendipity_displayCommentForm(
       $serendipity['GET']['entry_id'],
-      '?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=doEdit&amp;serendipity[id]=' . $serendipity['GET']['id'] . '&amp;serendipity[entry_id]=' . $serendipity['GET']['entry_id'] . '&amp;' . serendipity_setFormToken('url'),
+      $target_url,
       NULL,
       $data,
       false,
@@ -114,9 +168,9 @@ if ( isset($serendipity['GET']['adminAction']) && $serendipity['GET']['adminActi
 $filters = array('author', 'email', 'ip', 'url', 'body', 'referer');
 
 /* Compress the filters into an "AND" SQL query, and a querystring */
-foreach ( $filters as $filter ) {
+foreach ($filters as $filter) {
     $and          .= (!empty($serendipity['GET']['filter'][$filter]) ? "AND c.". $filter ." LIKE '%". serendipity_db_escape_string($serendipity['GET']['filter'][$filter]) ."%'" : "");
-    $searchString .= (!empty($serendipity['GET']['filter'][$filter]) ? "&amp;serendipity[filter][". $filter ."]=". $serendipity['GET']['filter'][$filter] : "");
+    $searchString .= (!empty($serendipity['GET']['filter'][$filter]) ? "&amp;serendipity[filter][". $filter ."]=". htmlspecialchars($serendipity['GET']['filter'][$filter]) : "");
 }
 
 if ($serendipity['GET']['filter']['show'] == 'approved') {
@@ -139,6 +193,20 @@ if ($serendipity['GET']['filter']['type'] == 'TRACKBACK') {
     $c_type = null;
 }
 
+if ($serendipity['GET']['filter']['type'] == 'TRACKBACK') {
+    $c_type = 'TRACKBACK';
+    $searchString .= "&amp;serendipity[filter][type]=TRACKBACK";
+} elseif ($serendipity['GET']['filter']['type'] == 'NORMAL') {
+    $c_type = 'NORMAL';
+    $searchString .= "&amp;serendipity[filter][type]=NORMAL";
+} else {
+    $c_type = null;
+}
+
+if ($commentsPerPage != 10) {
+    $searchString .= '&amp;serendipity[filter][perpage]=' . $commentsPerPage;
+}
+
 $searchString .= '&amp;' . serendipity_setFormToken('url');
 
 /* Paging */
@@ -171,7 +239,7 @@ function FT_toggle(id) {
     if ( document.getElementById(id + '_full').style.display == '' ) {
         document.getElementById(id + '_full').style.display='none';
         document.getElementById(id + '_summary').style.display='';
-        document.getElementById(id + '_text').innerHTML = '<?php echo VIEW ?>';
+        document.getElementById(id + '_text').innerHTML = '<?php echo TOGGLE_ALL ?>';
     } else {
         document.getElementById(id + '_full').style.display='';
         document.getElementById(id + '_summary').style.display='none';
@@ -209,19 +277,19 @@ function highlightComment(id, checkvalue) {
     </tr>
     <tr>
         <td><?php echo AUTHOR ?>:</td>
-        <td><input type="text" name="serendipity[filter][author]" size="15" value="<?php echo $serendipity['GET']['filter']['author'] ?>" /></td>
+        <td><input type="text" name="serendipity[filter][author]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['author']) ?>" /></td>
         <td><?php echo EMAIL ?>:</td>
-        <td><input type="text" name="serendipity[filter][email]" size="15" value="<?php echo $serendipity['GET']['filter']['email'] ?>" /></td>
+        <td><input type="text" name="serendipity[filter][email]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['email']) ?>" /></td>
         <td><?php echo URL ?>:</td>
-        <td><input type="text" name="serendipity[filter][url]" size="15" value="<?php echo $serendipity['GET']['filter']['url'] ?>" /></td>
+        <td><input type="text" name="serendipity[filter][url]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['url']) ?>" /></td>
     </tr>
     <tr>
         <td>IP:</td>
-        <td><input type="text" name="serendipity[filter][ip]" size="15" value="<?php echo $serendipity['GET']['filter']['ip'] ?>" /></td>
+        <td><input type="text" name="serendipity[filter][ip]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['ip']) ?>" /></td>
         <td><?php echo CONTENT ?>:</td>
-        <td><input type="text" name="serendipity[filter][body]" size="15" value="<?php echo $serendipity['GET']['filter']['body'] ?>" /></td>
+        <td><input type="text" name="serendipity[filter][body]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['body']) ?>" /></td>
         <td><?php echo REFERER ?>:</td>
-        <td><input type="text" name="serendipity[filter][referer]" size="15" value="<?php echo $serendipity['GET']['filter']['referer'] ?>" /></td>
+        <td><input type="text" name="serendipity[filter][referer]" size="15" value="<?php echo htmlspecialchars($serendipity['GET']['filter']['referer']) ?>" /></td>
     </tr>
     <tr>
         <td><?php echo COMMENTS; ?>:</td>
@@ -303,6 +371,7 @@ foreach ($sql as $rs) {
         'entry_id'  => $rs['entry_id']
     );
 
+    $entrylink = serendipity_archiveURL($comment['entry_id'], 'comments', 'serendipityHTTPPath', true) . '#c' . $comment['id'];
     if (strlen($comment['fullBody']) > strlen($comment['summary']) ) {
         $comment['summary'] .= ' ...';
         $comment['excerpt'] = true;
@@ -316,7 +385,7 @@ foreach ($sql as $rs) {
         $comment['fullBody'] = $comment['summary'] = nl2br(htmlspecialchars($comment['fullBody']));
     }
 
-    serendipity_plugin_api::hook_event('backend_view_comment', $comment);
+    serendipity_plugin_api::hook_event('backend_view_comment', $comment, '&amp;serendipity[page]='. $page . $searchString);
     $class = 'serendipity_admin_list_item_' . (($i % 2 == 0 ) ? 'even' : 'uneven');
     $header_class = ($comment['status'] == 'pending' ? 'serendipityAdminMsgNote' : '');
 ?>
@@ -387,10 +456,12 @@ foreach ($sql as $rs) {
           <a href="?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=approve&amp;serendipity[id]=<?php echo $comment['id'] ?>&amp;<?php echo serendipity_setFormToken('url'); ?>" class="serendipityIconLink" title="<?php echo APPROVE; ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/accept.png'); ?>" alt="<?php echo APPROVE ?>" /><?php echo APPROVE ?></a>
 <?php } ?>
 <?php if ($comment['excerpt']) { ?>
-          <a href="#c<?php echo $comment['id'] ?>" onclick="FT_toggle(<?php echo $comment['id'] ?>); return false;" title="<?php echo VIEW; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo VIEW; ?>" /><span id="<?php echo $comment['id'] ?>_text"><?php echo VIEW ?></span></a>
+          <a href="#c<?php echo $comment['id'] ?>" onclick="FT_toggle(<?php echo $comment['id'] ?>); return false;" title="<?php echo VIEW; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo TOGGLE_ALL; ?>" /><span id="<?php echo $comment['id'] ?>_text"><?php echo TOGGLE_ALL ?></span></a>
 <?php } ?>
+          <a target="_blank" href="<?php echo $entrylink; ?>" title="<?php echo VIEW; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo VIEW; ?>" /><?php echo VIEW ?></a>
           <a href="?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=edit&amp;serendipity[id]=<?php echo $comment['id'] ?>&amp;serendipity[entry_id]=<?php echo $comment['entry_id'] ?>&amp;<?php echo serendipity_setFormToken('url'); ?>" title="<?php echo EDIT; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/edit.png'); ?>" alt="<?php echo EDIT; ?>" /><?php echo EDIT ?></a>
           <a href="?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=delete&amp;serendipity[id]=<?php echo $comment['id'] ?>&amp;serendipity[entry_id]=<?php echo $comment['entry_id'] ?>&amp;<?php echo serendipity_setFormToken('url'); ?>" onclick='return confirm("<?php echo sprintf(COMMENT_DELETE_CONFIRM, $comment['id'], htmlspecialchars($comment['author'])) ?>")' title="<?php echo DELETE ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/delete.png'); ?>" alt="<?php echo DELETE; ?>" /><?php echo DELETE ?></a>
+          <a target="_blank" onclick="cf = window.open(this.href, 'CommentForm', 'width=800,height=600,toolbar=no,scrollbars=1,scrollbars,resize=1,resizable=1'); cf.focus(); return false;" href="?serendipity[action]=admin&amp;serendipity[adminModule]=comments&amp;serendipity[adminAction]=reply&amp;serendipity[id]=<?php echo $comment['id'] ?>&amp;serendipity[entry_id]=<?php echo $comment['entry_id'] ?>&amp;serendipity[noBanner]=true&amp;serendipity[noSidebar]=true&amp;<?php echo serendipity_setFormToken('url'); ?>" title="<?php echo REPLY ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/user_editor.png'); ?>" alt="<?php echo REPLY; ?>" /><?php echo REPLY ?></a>
           <?php echo $comment['action_more']; ?>
     </td>
 </tr>
