@@ -1,4 +1,4 @@
-<?php # $Id: movabletype.inc.php 868 2006-01-24 12:10:55Z garvinhicking $
+<?php # $Id: movabletype.inc.php 1028 2006-03-27 11:17:11Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -101,7 +101,7 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
                     // Post mediam, add 12 hours.
                     $match[4] = $match[4] + 12;
                 }
-                
+
                 $ts = mktime($match[4], $match[5], $match[6], $match[1], $match[2], $match[3]);
                 $this->debug('Matched string date format: ' . $ts);
             }
@@ -110,7 +110,7 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
         if ($ts <= 1) {
             $ts = time();
         }
-        
+
         return $ts;
     }
 
@@ -176,24 +176,30 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
 
                 case 'PRIMARY CATEGORY':
                 case 'CATEGORY':
-                      $cat_found = false;
-                      if ( is_array($this->categories) ) {
-                          for ( $y=0 ; $y<sizeof($this->categories) ; $y++ ) {
-                              if ( $this->categories[$y]['category_name'] == $data ) {
-                                  $cat_found = true;
-                                  break;
-                              }
-                          }
-                          if ( $cat_found){
-                              if (!in_array($this->categories[$y]['categoryid'], $entry['categories']) ) {
-                                  //$entries[$n]['categories'][] = $categories[$y]['categoryid'];
-                                  $entry['categories'][] = $this->categories[$y]['categoryid'];
-                              }
-                          }else {
-                              $tasks[] = sprintf(CREATE_CATEGORY, htmlspecialchars($data));
-                          }
-                      }
-                      break;
+                    $categories = explode("\0", $data);
+                    #echo '<pre>' . print_r($this->categories, true) . '</pre>';
+                    foreach($categories AS $data) {
+                        $data = trim($data);
+                        $cat_found  = false;
+                        if (is_array($this->categories)) {
+                            for ( $y=0 ; $y<sizeof($this->categories) ; $y++ ) {
+                                echo '"' . $this->categories[$y]['category_name'] . '" == "' . $data . '"<br />';
+                                if ( $this->categories[$y]['category_name'] == $data ) {
+                                    $cat_found = true;
+                                    break;
+                                }
+                            }
+                            if ($cat_found) {
+                                if (!in_array($this->categories[$y]['categoryid'], $entry['categories']) ) {
+                                    //$entries[$n]['categories'][] = $categories[$y]['categoryid'];
+                                    $entry['categories'][] = $this->categories[$y]['categoryid'];
+                                }
+                            } else {
+                                $tasks[] = sprintf(CREATE_CATEGORY, htmlspecialchars($data));
+                            }
+                        }
+                    }
+                    break;
             }
         }
         $entry['props'] = $entryprops;
@@ -399,7 +405,11 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
                         $comment[$c_el] = $content;
                     } else {
                         $this->debug("Appending to entry: $line");
-                        $entry[$c_el]   = $content;
+                        if (isset($entry[$c_el])) {
+                            $entry[$c_el] .= "\0" . $content;
+                        } else {
+                            $entry[$c_el]   = $content;
+                        }
                     }
                 }
             } elseif ($is_comment || $is_trackback) {
@@ -415,11 +425,13 @@ class Serendipity_Import_MovableType extends Serendipity_Import {
         if ( !sizeof($tasks) || $force == true ) {
             serendipity_db_begin_transaction();
             foreach ($entries as $entry) {
+                #echo '<pre>' . printR_($entry, true) . '</pre><br />';
+                #continue;
                 if (empty($entry['authorid'])) {
                     $entry['authorid'] = $serendipity['authorid'];
                     $entry['author']   = $serendipity['realname'];
                 }
-                
+
                 if (!isset($entry['isdraft'])) {
                     $entry['isdraft'] = 'false';
                 }
