@@ -1,4 +1,4 @@
-<?php # $Id: installer.inc.php 1521 2006-11-30 21:34:33Z garvinhicking $
+<?php # $Id: installer.inc.php 1540 2006-12-11 08:36:14Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -40,11 +40,11 @@ function serendipity_installerResultDiagnose($result, $s) {
         return '<span style="color: green; font-weight: bold">'. $s .'</span>';
     }
     if ( $result === S9Y_I_WARNING ) {
-        return '<span style="color: orange; font-weight: bold">'. $s .'</span>';
+        return '<span style="color: orange; font-weight: bold">'. $s .' [?]</span>';
     }
     if ( $result === S9Y_I_ERROR ) {
         $errorCount++;
-        return '<span style="color: red; font-weight: bold">'. $s .'</span>';
+        return '<span style="color: red; font-weight: bold">'. $s .' [!]</span>';
     }
 }
 
@@ -360,7 +360,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
             if ( is_writable($basedir . PATH_SMARTY_COMPILE) ) {
                 echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
             } else {
-                if ($basewritable) {
+                if ($basewritable && !is_dir($basedir . PATH_SMARTY_COMPILE)) {
                     echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
                     #This directory will be created later in the process
                 } else {
@@ -376,7 +376,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
             if ( is_writable($basedir . 'archives/') ) {
                 echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
             } else {
-                if ($basewritable) {
+                if ($basewritable && !is_dir($basedir . 'archives/')) {
                     echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
                     #This directory will be created later in the process
                 } else {
@@ -393,7 +393,7 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
             if ( is_writable($basedir . 'uploads/') ) {
                 echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
             } else {
-                if ($basewritable) {
+                if ($basewritable && !is_dir($basedir . 'uploads/')) {
                     echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, WRITABLE);
                     #This directory will be created later in the process
                 } else {
