@@ -1,4 +1,4 @@
-<?php # $Id: plugins.inc.php 904 2006-02-06 15:20:50Z garvinhicking $
+<?php # $Id: plugins.inc.php 1438 2006-10-09 09:19:39Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -111,7 +111,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
     echo "</ul>\n";
     ?>
     </div>
-<?php } elseif ( isset($_POST['SAVECONF']) ) { ?>
+<?php } elseif ( isset($_POST['SAVECONF'])) { ?>
     <div class="serendipityAdminMsgSuccess"><?php echo DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')); ?></div>
 <?php } ?>
 
@@ -196,7 +196,11 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
     $pluggroups     = array();
     $pluggroups[''] = array();
     foreach($pluginstack AS $plugname => $plugdata) {
-        if (is_array($plugdata['groups'])) {
+        if ($serendipity['GET']['only_group'] == 'ALL') {
+            $pluggroups['ALL'][] = $plugdata;
+        } elseif ($serendipity['GET']['only_group'] == 'UPGRADE' && $plugdata['upgradable']) {
+            $pluggroups['UPGRADE'][] = $plugdata;
+        } elseif (is_array($plugdata['groups'])) {
             foreach($plugdata['groups'] AS $group) {
                 $pluggroups[$group][] = $plugdata;
             }
@@ -209,6 +213,10 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
     foreach($errorstack as $e_idx => $e_name) {
         echo ERROR . ': ' . $e_name . '<br />';
     }
+
+    if ($serendipity['GET']['only_group'] == 'UPGRADE') {
+        serendipity_plugin_api::hook_event('backend_pluginlisting_header_upgrade', $pluggroups);
+    }
 ?>
 <table cellspacing="0" cellpadding="0" border="0" width="100%">
 <?php
@@ -228,6 +236,8 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
                     ?>
                     <option value="<?php echo $available_group; ?>" <?php echo ($serendipity['GET']['only_group'] == $available_group ? 'selected="selected"' : ''); ?>><?php echo serendipity_groupname($available_group); ?>
             <?php } ?>
+                    <option value="ALL" <?php echo ($serendipity['GET']['only_group'] == 'ALL' ? 'selected="selected"' : ''); ?>><?php echo ALL_CATEGORIES; ?>
+                    <option value="UPGRADE" <?php echo ($serendipity['GET']['only_group'] == 'UPGRADE' ? 'selected="selected"' : ''); ?>><?php echo WORD_NEW; ?>
                 </select>
                 <input type="submit" value="<?php echo GO; ?>" />
             </form>
@@ -309,9 +319,9 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
                         <?php if ( $plug['requirements_fail'] == true ) { ?>
                             <span style="color: #cccccc"><?php printf(UNMET_REQUIREMENTS, implode(', ', $notice['requirements_failures'])); ?></span>
                         <?php } elseif ( $plug['upgradable'] == true ) { ?>
-                            <a href="?serendipity[adminModule]=plugins&amp;serendipity[pluginPath]=<?php echo $plug['pluginPath']; ?>&amp;serendipity[install_plugin]=<?php echo $plug['plugin_class'] . $plug['customURI'] ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/upgrade_now.png') ?>" title="<?php echo UPGRADE ?>" alt="<?php echo UPGRADE ?>" border="0"></a>
+                            <a href="?serendipity[adminModule]=plugins&amp;serendipity[pluginPath]=<?php echo $plug['pluginPath']; ?>&amp;serendipity[install_plugin]=<?php echo $plug['plugin_class'] . $plug['customURI'] ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/upgrade_now.png') ?>" title="<?php echo UPGRADE ?>" alt="<?php echo UPGRADE ?>" border="0" /></a>
                         <?php } elseif ($plug['installable'] == true) { ?>
-                            <a href="?serendipity[adminModule]=plugins&amp;serendipity[pluginPath]=<?php echo $plug['pluginPath']; ?>&amp;serendipity[install_plugin]=<?php echo $plug['plugin_class'] . $plug['customURI'] ?>"><img src="<?php echo $installimage ?>" title="<?php echo INSTALL ?>" alt="<?php echo INSTALL ?>" border="0"></a>
+                            <a href="?serendipity[adminModule]=plugins&amp;serendipity[pluginPath]=<?php echo $plug['pluginPath']; ?>&amp;serendipity[install_plugin]=<?php echo $plug['plugin_class'] . $plug['customURI'] ?>"><img src="<?php echo $installimage ?>" title="<?php echo INSTALL ?>" alt="<?php echo INSTALL ?>" border="0" /></a>
                         <?php } else { ?>
                             <span style="color: #cccccc"><?php echo ALREADY_INSTALLED ?></span>
                         <?php } ?>
@@ -332,12 +342,67 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
         }
     }
 ?>
+    <tr>
+        <td colspan="2" align="right"><?php printf(PLUGIN_AVAILABLE_COUNT, count($pluginstack)); ?></td>
+    </tr>
 </table>
 
 <?php
 } else {
     /* show general plugin list */
 
+    /* get sidebar locations */
+    serendipity_smarty_init();
+
+    if (is_array($template_config)) {
+        $template_vars =& serendipity_loadThemeOptions($template_config);
+    }
+
+    $col_assoc = array(
+        'event_col'  => 'event',
+        'eventh_col' => 'eventh'
+    );
+    if (isset($template_vars['sidebars'])) {
+        $sidebars = explode(',', $template_vars['sidebars']);
+    } elseif (isset($serendipity['sidebars'])) {
+        $sidebars = $serendipity['sidebars'];
+    } else {
+        $sidebars = array('left', 'hide', 'right');
+    }
+
+    foreach($sidebars AS $sidebar) {
+        $col_assoc[$sidebar . '_col'] = $sidebar;
+    }
+
+    /* preparse Javascript-generated input */
+    if (isset($_POST['SAVE']) && !empty($_POST['serendipity']['pluginorder'])) {
+        $parts = explode(':', $_POST['serendipity']['pluginorder']);
+
+        foreach($parts AS $sidepart) {
+            preg_match('@^(.+)\((.*)\)$@imsU', $sidepart, $matches);
+            if (!isset($col_assoc[$matches[1]])) {
+                continue;
+            }
+            $pluginsidelist = explode(',', $matches[2]);
+            foreach($pluginsidelist AS $pluginname) {
+                $pluginname = trim(urldecode(str_replace(array('s9ycid', '-'), array('', '%'), $pluginname)));
+
+                if (empty($pluginname)) {
+                    continue;
+                }
+                $serendipity['POST']['placement'][$pluginname] = $col_assoc[$matches[1]];
+                $new_order[] = $pluginname;
+
+            }
+        }
+
+        if (is_array($new_order)) {
+            foreach($new_order AS $new_order_pos => $order_plugin) {
+                serendipity_db_query("UPDATE {$serendipity['dbPrefix']}plugins SET sort_order = ". (int)$new_order_pos . " WHERE name='" . serendipity_db_escape_string($order_plugin) . "'");
+            }
+        }
+    }
+
     if (isset($_POST['SAVE']) && isset($_POST['serendipity']['placement']) && serendipity_checkFormToken()) {
         foreach ($_POST['serendipity']['placement'] as $plugin_name => $placement) {
             serendipity_plugin_api::update_plugin_placement(
@@ -369,7 +434,7 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
             /* Load the new plugin */
             $plugin = &serendipity_plugin_api::load_plugin($inst);
             if (!is_object($plugin)) {
-                echo "DEBUG: Plugin $inst not an object: " . print_r($plugin, true) . ".<br />Input: " . print_r($serendipity['GET'], true) . ".<br /><br />\n\nPlease report this bug. This error can happen if a plugin was not properly downloaded (check your plugins directory if the requested plugin was downloaded) or the inclusion of a file failed (permissions?)<br />\n";
+                echo "DEBUG: Plugin $inst not an object: " . print_r($plugin, true) . ".<br />Input: " . print_r($serendipity['GET'], true) . ".<br /><br />\n\nThis error can happen if a plugin was not properly downloaded (check your plugins directory if the requested plugin was downloaded) or the inclusion of a file failed (permissions?)<br />\n";
                 echo "Backtrace:<br />\n" . implode("<br />\n", $serendipity['debug']['pluginload']) . "<br />";
             }
             $bag  = new serendipity_property_bag;
@@ -399,20 +464,32 @@ if (isset($_GET['serendipity']['plugin_to_conf'])) {
         }
     }
 ?>
-    <?php echo BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS ?>
-    <br />
+
+<?php if (isset($_POST['SAVE'])) { ?>
+    <div class="serendipityAdminMsgSuccess"><?php echo DONE .': '. sprintf(SETTINGS_SAVED_AT, serendipity_strftime('%H:%M:%S')); ?></div>
+<?php } ?>
+
+    <div><?php echo BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS ?></div>
+<?php
+    if (!isset($serendipity['eyecandy']) || serendipity_db_bool($serendipity['eyecandy'])) {
+        echo '<script src="bundled-libs/dragdrop.js" type="text/javascript"></script>';
+        echo '<div class="warning js_warning"><em>' . PREFERENCE_USE_JS_WARNING . '</em></div>';
+    }
+
+    serendipity_plugin_api::hook_event('backend_pluginlisting_header', $serendipity['eyecandy']);
+?>
     <br />
 
     <h3><?php echo SIDEBAR_PLUGINS ?></h3>
-    <a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/install.png') ?>" style="border: 0px none ; vertical-align: middle; display: inline;" alt=""><?php echo sprintf(CLICK_HERE_TO_INSTALL_PLUGIN, SIDEBAR_PLUGIN) ?></a>
+    <a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/install.png') ?>" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" /><?php echo sprintf(CLICK_HERE_TO_INSTALL_PLUGIN, SIDEBAR_PLUGIN) ?></a>
     <?php serendipity_plugin_api::hook_event('backend_plugins_sidebar_header', $serendipity); ?>
-    <?php show_plugins(false); ?>
+    <?php show_plugins(false, $sidebars); ?>
 
     <br />
     <br />
 
     <h3><?php echo EVENT_PLUGINS ?></h3>
-    <a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[type]=event" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/install.png') ?>" style="border: 0px none ; vertical-align: middle; display: inline;" alt=""><?php echo sprintf(CLICK_HERE_TO_INSTALL_PLUGIN, EVENT_PLUGIN) ?></a>
+    <a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[type]=event" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/install.png') ?>" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" /><?php echo sprintf(CLICK_HERE_TO_INSTALL_PLUGIN, EVENT_PLUGIN) ?></a>
     <?php serendipity_plugin_api::hook_event('backend_plugins_event_header', $serendipity); ?>
     <?php show_plugins(true); ?>
 
