@@ -1,4 +1,4 @@
-<?php # $Id: mysqli.inc.php 1176 2006-05-01 12:01:21Z garvinhicking $
+<?php # $Id: mysqli.inc.php 1247 2006-06-09 09:32:30Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -107,9 +107,13 @@ function &serendipity_db_query($sql, $single = false, $result_type = "both", $re
 
             $rows = array();
             while ($row = mysqli_fetch_array($c, $result_type)) {
-                if (!empty($assocKey) && !empty($assocVal)) {
+                if (!empty($assocKey)) {
                     // You can fetch a key-associated array via the two function parameters assocKey and assocVal
-                    $rows[$row[$assocKey]] = $row[$assocVal];
+                    if (empty($assocVal)) {
+                        $rows[$row[$assocKey]] = $row;
+                    } else {
+                        $rows[$row[$assocKey]] = $row[$assocVal];
+                    }
                 } else {
                     $rows[] = $row;
                 }
@@ -228,14 +232,22 @@ function serendipity_db_connect() {
 
     $serendipity['dbConn'] = $function($serendipity['dbHost'], $serendipity['dbUser'], $serendipity['dbPass']);
     mysqli_select_db($serendipity['dbConn'], $serendipity['dbName']);
-
-    if (defined('SQL_CHARSET') && $serendipity['dbNames']) {
-        mysqli_query($serendipity['dbConn'], "SET NAMES " . SQL_CHARSET);
-    }
+    serendipity_db_reconnect();
 
     return $serendipity['dbConn'];
 }
 
+function serendipity_db_reconnect() {
+    global $serendipity;
+
+    if (isset($serendipity['dbCharset'])) {
+        mysqli_query($serendipity['dbConn'], "SET NAMES " . $serendipity['dbCharset']);
+        define('SQL_CHARSET_INIT', true);
+    } elseif (defined('SQL_CHARSET') && $serendipity['dbNames'] && !defined('SQL_CHARSET_INIT')) {
+        mysqli_query($serendipity['dbConn'], "SET NAMES " . SQL_CHARSET, $serendipity['dbConn']);
+    }
+}
+
 /**
  * Prepares a Serendipty query input to fully valid SQL. Replaces certain "template" variables.
  *
