@@ -1,4 +1,4 @@
-<?php # $Id: functions_comments.inc.php 1521 2006-11-30 21:34:33Z garvinhicking $
+<?php # $Id: functions_comments.inc.php 1730 2007-06-17 10:46:06Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -6,6 +6,11 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
+if (defined('S9Y_FRAMEWORK_COMMENTS')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_COMMENTS', true);
+
 /**
  * Store the personal details of a commenting user in a cookie (or delete that cookie)
  *
@@ -84,8 +89,7 @@ function serendipity_displayCommentForm($id, $url = '', $comments = NULL, $data
         $comments = serendipity_fetchComments($id);
     }
 
-    $serendipity['smarty']->assign(
-      array(
+    $commentform_data = array(
         'commentform_action'         => $url,
         'commentform_id'             => $id,
         'commentform_name'           => isset($data['name'])      ? htmlspecialchars($data['name'])       : (isset($serendipity['COOKIE']['name'])     ? htmlspecialchars($serendipity['COOKIE']['name'])     : ''),
@@ -99,9 +103,10 @@ function serendipity_displayCommentForm($id, $url = '', $comments = NULL, $data
         'is_allowSubscriptions'      => $serendipity['allowSubscriptions'],
         'is_moderate_comments'       => $moderate_comments,
         'commentform_entry'          => $entry
-      )
     );
 
+    $serendipity['smarty']->assign($commentform_data);
+
     serendipity_smarty_fetch('COMMENTFORM', 'commentform.tpl');
 }
 
@@ -113,9 +118,10 @@ function serendipity_displayCommentForm($id, $url = '', $comments = NULL, $data
  * @param   int     How many comments to fetch (empty: all)
  * @param   string  How shall comments be ordered (ASC|DESC)
  * @param   boolean Shall non-approved comments be displayed?
+ * @param   string  Comment type to fetch
  * @return  array   The SQL result of comments
  */
-function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = false) {
+function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = false, $type = 'NORMAL', $where = '') {
     global $serendipity;
     $and = '';
 
@@ -125,6 +131,14 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
         $limit = '';
     }
 
+    if ($type == 'comments' || empty($type)) {
+        $type = 'NORMAL';
+    } elseif ($type == 'trackbacks') {
+        $type = 'TRACKBACK';
+    } elseif ($type == 'comments_and_trackbacks') {
+        $type = '%';
+    }
+
     if (!empty($id)) {
         $and .= " AND co.entry_id = '" . (int)$id ."'";
     }
@@ -133,6 +147,8 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
         $and .= ' AND co.status = \'approved\'';
     }
 
+    $and .= $where;
+
     if ($serendipity['dbType'] == 'postgres') {
         $group    = '';
         $distinct = 'DISTINCT';
@@ -143,9 +159,10 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
 
     $query = "SELECT $distinct
                     co.id,
-                    co.entry_id, co.timestamp, co.title, co.email, co.url, co.ip, co.body, co.type, co.subscribed,
+                    co.entry_id, co.timestamp, co.title AS ctitle, co.email, co.url, co.ip, co.body, co.type, co.subscribed,
                     co.author,
                     e.title,
+                    e.timestamp AS entrytimestamp,
                     e.id AS entryid,
                     e.authorid,
                     co.id AS commentid,
@@ -153,19 +170,19 @@ function serendipity_fetchComments($id, $limit = null, $order = '', $showAll = f
               FROM
                     {$serendipity['dbPrefix']}comments co
                     LEFT JOIN {$serendipity['dbPrefix']}entries e ON (co.entry_id = e.id)
-              WHERE co.type LIKE 'NORMAL' AND co.entry_id > 0 $and
+              WHERE co.type LIKE '" . $type . "' AND co.entry_id > 0 $and
               $group
               ORDER BY
-                    co.id " . ($order != '' ? $order : '') . "
+                    " . ($where != '' ? '' : 'co.id') . " " . ($order != '' ? $order : '') . "
                     $limit";
-
-    $comments = serendipity_db_query($query);
+    $comments = serendipity_db_query($query, false, 'assoc');
 
     if (!is_array($comments)) {
         return array();
     }
 
     serendipity_plugin_api::hook_event('fetchcomments', $comments);
+
     return $comments;
 }
 
@@ -217,7 +234,7 @@ function serendipity_generateCommentList($id, $comments = NULL, $selected = 0, $
  * @param   string      A string repesenting the actual comment (1.1.2.1)
  * @return  string      The HTML construct of all comments
  */
-function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace = null) {
+function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace = null, $smarty_block = 'COMMENTS', $smarty_file = 'comments.tpl') {
     global $serendipity;
     static $_smartyComments;
 
@@ -261,7 +278,8 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
             if (isset($comment['no_email']) && $comment['no_email']) {
                 $comment['email'] = false;
             } elseif (!empty($comment['email'])) {
-                $comment['email'] = htmlspecialchars(str_replace('@', '[at]', $comment['email']));
+                $comment['clear_email'] = $comment['email'];
+                $comment['email']       = htmlspecialchars(str_replace('@', '[at]', $comment['email']));
             }
 
             $comment['body']    = $comment['comment'];
@@ -272,7 +290,7 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
 
             $_smartyComments[] = $comment;
             if ($comment['id'] && $parentid !== VIEWMODE_LINEAR ) {
-                serendipity_printComments($comments, $comment['id'], ($depth+1), ($trace . $i . '.'));
+                serendipity_printComments($comments, $comment['id'], ($depth+1), ($trace . $i . '.'), $smarty_block, $smarty_file);
             }
         }
     }
@@ -282,10 +300,83 @@ function serendipity_printComments($comments, $parentid = 0, $depth = 0, $trace
         return true;
     }
 
-    $serendipity['smarty']->assign('comments', $_smartyComments);
+    $serendipity['smarty']->assign_by_ref('comments', $_smartyComments);
     unset($_smartyComments);
 
-    return serendipity_smarty_fetch('COMMENTS', 'comments.tpl');
+    return serendipity_smarty_fetch($smarty_block, $smarty_file);
+}
+
+/**
+ * Fetches and prints a listing of comments by author
+ */
+function serendipity_printCommentsByAuthor() {
+    global $serendipity;
+
+    $type      = serendipity_db_escape_string($serendipity['GET']['commentMode']);
+
+    if ($type == 'comments' || empty($type)) {
+        $type = 'NORMAL';
+    } elseif ($type == 'trackbacks') {
+        $type = 'TRACKBACK';
+    } elseif ($type == 'comments_and_trackbacks') {
+        $type = '%';
+    }
+
+    $sql_where = " AND co.author = '" . serendipity_db_escape_string($serendipity['GET']['viewCommentAuthor']) . "'";
+
+    if (!empty($serendipity['GET']['commentStartTime'])) {
+        $sql_where .= " AND co.timestamp >= " . (int)$serendipity['GET']['commentStartTime'];
+    }
+
+    if (!empty($serendipity['GET']['commentEndTime'])) {
+        $sql_where .= " AND co.timestamp <= " . (int)$serendipity['GET']['commentEndTime'];
+    }
+
+    if (empty($serendipity['GET']['page'])) {
+        $serendipity['GET']['page'] = 1;
+    }
+    $sql_limit = $serendipity['fetchLimit'] * ($serendipity['GET']['page']-1) . ',' . $serendipity['fetchLimit'];
+    $c = serendipity_fetchComments(null, $sql_limit, 'co.entry_id DESC, co.id ASC', false, $type, $sql_where);
+
+    $entry_comments = array();
+    foreach($c as $i => $comment) {
+        if (!isset($entry_comments[$comment['entry_id']])) {
+            $comment['link'] = serendipity_archiveURL($comment['entry_id'], $comment['title'], 'serendipityHTTPPath', true, array('timestamp' => $comment['entrytimestamp']));
+            $entry_comments[$comment['entry_id']] = $comment;
+        }
+        $entry_comments[$comment['entry_id']]['comments'][] = $comment;
+    }
+
+    foreach($entry_comments AS $entry_id => $_data) {
+        $entry_comments[$entry_id]['tpl_comments'] =& serendipity_printComments($_data['comments'], VIEWMODE_LINEAR, 0, null, 'COMMENTS', 'comments.tpl');
+    }
+
+    $serendipity['smarty']->assign_by_ref('comments_by_authors', $entry_comments);
+
+    if (!empty($id)) {
+        $and .= " AND co.entry_id = '" . (int)$id ."'";
+    }
+
+    if (!$showAll) {
+        $and .= ' AND co.status = \'approved\'';
+    }
+
+    $cc = serendipity_db_query("SELECT count(co.id) AS counter
+                                  FROM {$serendipity['dbPrefix']}comments AS co
+                                 WHERE co.entry_id > 0
+                                   AND co.type LIKE '" . $type . "'
+                                   AND co.status = 'approved' " . $sql_where . "
+                              GROUP BY co.author", true, 'assoc');
+    if (!isset($cc['counter'])) {
+        $totalComments = 0;
+    } else {
+        $totalComments = $cc['counter'];
+    }
+    serendipity_printEntryFooter('', $totalComments);
+
+    serendipity_smarty_fetch('ENTRIES', 'comments_by_author.tpl');
+
+    return true;
 }
 
 /**
@@ -314,25 +405,41 @@ function serendipity_deleteComment($id, $entry_id, $type='comments') {
 
         /* We have to figure out if the comment we are about to delete, is awaiting approval,
            if so - we should *not* subtract it from the entries table */
-        $sql = serendipity_db_query("SELECT type, status, parent_id FROM {$serendipity['dbPrefix']}comments
+        $sql = serendipity_db_query("SELECT type, status, parent_id, body FROM {$serendipity['dbPrefix']}comments
                                             WHERE entry_id = ". $entry_id ."
-                                                    AND id = ". $id , true);
+                                                    AND id = ". $id, true);
 
-        serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}comments
-                                    WHERE entry_id = ". $entry_id ."
-                                            AND id = ". $id );
 
-        if ($sql['status'] !== 'pending') {
-            if (!empty($sql['type']) && $sql['type'] != 'NORMAL') {
-                $type = 'trackbacks';
-            } else {
-                $type = 'comments';
+        /* Check to see if the comment has children
+         * if it does, don't delete, but replace with "*(COMMENT DELETED)*"
+            to delete a tree, delete children first */
+        $has_parent = serendipity_db_query("SELECT count(id) AS count
+                                              FROM {$serendipity['dbPrefix']}comments
+                                             WHERE parent_id = ". $id . "
+                                             LIMIT 1", true);
+
+        if (is_array($has_parent) && isset($has_parent['count']) && $has_parent['count'] > 0 && $sql['body'] != 'COMMENT_DELETED') {
+            // Comment has childs, so don't delete it.
+            serendipity_db_query("UPDATE {$serendipity['dbPrefix']}comments
+                                     SET body = 'COMMENT_DELETED'
+                                   WHERE id = " . $id);
+        } else {
+            // Comment has no childs or had already been deleted., it can be safely removed.
+            serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}comments
+                                        WHERE entry_id = ". $entry_id ."
+                                                AND id = ". $id);
+
+            if (is_array($sql) && $sql['status'] !== 'pending') {
+                if (!empty($sql['type']) && $sql['type'] != 'NORMAL') {
+                    $type = 'trackbacks';
+                } else {
+                    $type = 'comments';
+                }
+                serendipity_db_query("UPDATE {$serendipity['dbPrefix']}entries SET $type = $type-1 WHERE id = ". $entry_id ." AND $type > 0 $admin");
             }
-            serendipity_db_query("UPDATE {$serendipity['dbPrefix']}entries SET $type = $type-1 WHERE id = ". $entry_id . " AND $type > 0 $admin");
+
+            serendipity_db_query("UPDATE {$serendipity['dbPrefix']}comments SET parent_id = " . (int)$sql['parent_id'] . " WHERE parent_id = " . $id);
         }
-
-        serendipity_db_query("UPDATE {$serendipity['dbPrefix']}comments SET parent_id = " . (int)$sql['parent_id'] . " WHERE parent_id = " . $id);
-
         return true;
     } else {
         return false;
