@@ -1,4 +1,4 @@
-<?php # $Id: functions_config.inc.php 1521 2006-11-30 21:34:33Z garvinhicking $
+<?php # $Id: functions_config.inc.php 1618 2007-02-13 08:35:56Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -6,6 +6,11 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
+if (defined('S9Y_FRAMEWORK_CONFIG')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_CONFIG', true);
+
 /**
  * Adds a new author account
  *
@@ -146,6 +151,8 @@ function serendipity_get_user_config_var($name, $authorid, $default = '') {
     $author_sql = '';
     if (!empty($authorid)) {
         $author_sql = "authorid = " . (int)$authorid . " AND ";
+    } elseif (isset($serendipity[$name])) {
+        return $serendipity[$name];
     }
 
     $r = serendipity_db_query("SELECT value FROM {$serendipity['dbPrefix']}config WHERE $author_sql name = '" . $name . "' LIMIT 1", true);
@@ -256,16 +263,21 @@ function serendipity_getTemplateFile($file, $key = 'serendipityHTTPPath') {
     if (isset($serendipity['template_engine']) && (stristr($file, 'admin/') === false || $serendipity['template_engine'] != 'default')) {
          $directories[] = $serendipity['template_engine'] . '/';
     }
+
     $directories[] = $serendipity['defaultTemplate'] .'/';
     $directories[] = 'default/';
 
     foreach ($directories as $directory) {
         $templateFile = $serendipity['templatePath'] . $directory . $file;
-
         if (file_exists($serendipity['serendipityPath'] . $templateFile)) {
             return $serendipity[$key] . $templateFile;
         }
     }
+
+    if (preg_match('@\.(tpl|css|php)@i', $file) && !stristr($file, 'plugin')) {
+        return $file;
+    }
+
     return false;
 }
 
@@ -281,15 +293,20 @@ function serendipity_getTemplateFile($file, $key = 'serendipityHTTPPath') {
  */
 function serendipity_load_configuration($author = null) {
     global $serendipity;
+    static $config_loaded = array();
+
+    if (isset($config_loaded[$author])) {
+        return true;
+    }
 
     if (!empty($author)) {
         // Replace default configuration directives with user-relevant data
-        $rows = serendipity_db_query("SELECT name,value
+        $rows =& serendipity_db_query("SELECT name,value
                                         FROM {$serendipity['dbPrefix']}config
                                         WHERE authorid = '". (int)$author ."'");
     } else {
         // Only get default variables, user-independent (frontend)
-        $rows = serendipity_db_query("SELECT name, value
+        $rows =& serendipity_db_query("SELECT name, value
                                         FROM {$serendipity['dbPrefix']}config
                                         WHERE authorid = 0");
     }
@@ -300,6 +317,7 @@ function serendipity_load_configuration($author = null) {
             $serendipity[$row['name']] = serendipity_get_bool($row['value']);
         }
     }
+    $config_loaded[$author] = true;
 }
 
 /**
@@ -336,25 +354,151 @@ function serendipity_login($use_external = true) {
     if (serendipity_authenticate_author($serendipity['POST']['user'], $serendipity['POST']['pass'], false, $use_external)) {
         if (empty($serendipity['POST']['auto'])) {
             serendipity_deleteCookie('author_information');
+            serendipity_deleteCookie('author_information_iv');
             return false;
         } else {
-            $package = serialize(array('username' => $serendipity['POST']['user'],
-                                       'password' => $serendipity['POST']['pass']));
-            serendipity_setCookie('author_information', base64_encode($package));
+            serendipity_issueAutologin(
+                array('username' => $serendipity['POST']['user'],
+                      'password' => $serendipity['POST']['pass']
+                )
+            );
             return true;
         }
     // Now try login via COOKIE data
-    } elseif ( isset($serendipity['COOKIE']['author_information']) ) {
-        $cookie = unserialize(base64_decode($serendipity['COOKIE']['author_information']));
-        if (serendipity_authenticate_author($cookie['username'], $cookie['password'], false, $use_external)) {
+    } elseif (isset($serendipity['COOKIE']['author_information'])) {
+        $cookie = serendipity_checkAutologin($serendipity['COOKIE']['author_information'], $serendipity['COOKIE']['author_information_iv']);
+
+        if (is_array($cookie) && serendipity_authenticate_author($cookie['username'], $cookie['password'], false, $use_external)) {
             return true;
         } else {
             serendipity_deleteCookie('author_information');
+            serendipity_deleteCookie('author_information_iv');
             return false;
         }
     }
 }
 
+/**
+ * Issue a new auto login cookie
+ * @param array The input data
+ */
+function serendipity_issueAutologin($array) {
+    global $serendipity;
+
+    $package = serialize($array);
+
+    if (function_exists('mcrypt_encrypt')) {
+        // Secure the package data when being stored inside the Database
+        $iv  = mcrypt_create_iv(mcrypt_get_iv_size(MCRYPT_BLOWFISH, MCRYPT_MODE_CBC), MCRYPT_RAND);
+        $key = base64_encode($iv);
+        $package = mcrypt_encrypt(MCRYPT_BLOWFISH, $key, $package, MCRYPT_MODE_CBC, $iv);
+        serendipity_setCookie('author_information_iv', $key);
+    }
+    $package = base64_encode($package);
+
+    $rnd = md5(time() . $_SERVER['REMOTE_ADDR']);
+
+    // Delete possible current cookie
+    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options WHERE okey = '" . serendipity_db_escape_string($serendipity['COOKIE']['author_information']) . "'");
+
+    // Issue new autologin cookie
+    serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (name, value, okey) VALUES ('" . time() . "', '" . serendipity_db_escape_string($package) . "', '" . $rnd . "')");
+    serendipity_setCookie('author_information', $rnd);
+}
+
+/**
+ * Checks a new auto login cookie
+ * @param array The input data
+ */
+function serendipity_checkAutologin($ident, $iv) {
+    global $serendipity;
+
+    // Fetch login data from DB
+    $autologin =& serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}options WHERE okey = '" . serendipity_db_escape_string($ident) . "' LIMIT 1", true, 'assoc');
+    if (!is_array($autologin)) {
+        return false;
+    }
+
+    if (function_exists('mcrypt_decrypt') && !empty($iv)) {
+        $key    = $iv;
+        $iv     = base64_decode($iv);
+        $cookie = unserialize(mcrypt_decrypt(MCRYPT_BLOWFISH, $key, base64_decode($autologin['value']), MCRYPT_MODE_CBC, $iv));
+    } else {
+        $cookie = unserialize(base64_decode($autologin['value']));
+    }
+
+    if ($autologin['name'] < (time()-86400)) {
+        // Issued autologin cookie has been issued more than 1 day ago. Re-Issue new cookie, invalidate old one to prevent abuse
+        serendipity_header('X-ReIssue-Cookie: +' . (time() - $autologin['name']) . 's');
+        serendipity_issueAutologin($cookie);
+    }
+
+    return $cookie;
+}
+
+/**
+ * Perform user authentication routine
+ *
+ * If a user is already authenticated via session data, this bypasses some routines.
+ * After a user has ben authenticated, several SESSION variables ar set.
+ * If the authentication fails, the session is destroyed.
+ *
+ * @access public
+ * @param   string      The username to check
+ * @param   string      The password to check (may contain plaintext or MD5 hash)
+ * @param   boolean     Indicates whether the input password is already in MD5 format (TRUE) or not (FALSE).
+ * @param   boolean     Indicates whether to query external plugins for authentication
+ * @return  boolean     True on success, False on error
+ */
+function serendipity_authenticate_author($username = '', $password = '', $is_md5 = false, $use_external = true) {
+    global $serendipity;
+
+    if (isset($_SESSION['serendipityUser']) && isset($_SESSION['serendipityPassword']) && isset($_SESSION['serendipityAuthedUser']) && $_SESSION['serendipityAuthedUser'] == true) {
+        $username = $_SESSION['serendipityUser'];
+        $password = $_SESSION['serendipityPassword'];
+        // For safety reasons when multiple blogs are installed on the same host, we need to check the current author each time to not let him log into a different blog with the same sessiondata
+        $is_md5 = true;
+    }
+
+    if ($username != '') {
+        if ($use_external) {
+            serendipity_plugin_api::hook_event('backend_auth', $is_md5, array('username' => $username, 'password' => $password));
+        }
+
+        if ($is_md5 === false && !empty($password)) {
+            $password = md5($password);
+        }
+
+        $query = "SELECT DISTINCT
+                    email, realname, authorid, userlevel, right_publish
+                  FROM
+                    {$serendipity['dbPrefix']}authors
+                  WHERE
+                    username   = '" . serendipity_db_escape_string($username) . "'
+                  AND password = '" . serendipity_db_escape_string($password) . "'";
+        $row =& serendipity_db_query($query, true, 'assoc');
+
+        if (is_array($row)) {
+            serendipity_setCookie('old_session', session_id());
+            $_SESSION['serendipityUser']        = $serendipity['serendipityUser']         = $username;
+            $_SESSION['serendipityRealname']    = $serendipity['serendipityRealname']     = $row['realname'];
+            $_SESSION['serendipityPassword']    = $serendipity['serendipityPassword']     = $password;
+            $_SESSION['serendipityEmail']       = $serendipity['serendipityEmail']        = $row['email'];
+            $_SESSION['serendipityAuthorid']    = $serendipity['authorid']                = $row['authorid'];
+            $_SESSION['serendipityUserlevel']   = $serendipity['serendipityUserlevel']    = $row['userlevel'];
+            $_SESSION['serendipityAuthedUser']  = $serendipity['serendipityAuthedUser']   = true;
+            $_SESSION['serendipityRightPublish']= $serendipity['serendipityRightPublish'] = $row['right_publish'];
+            serendipity_load_configuration($serendipity['authorid']);
+            return true;
+        } else {
+            $_SESSION['serendipityAuthedUser'] = false;
+            @session_destroy();
+        }
+    }
+
+    return false;
+}
+
 /**
  * Check if a user is logged in
  *
@@ -419,7 +563,8 @@ function serendipity_JSsetCookie($name, $value) {
 function serendipity_setCookie($name,$value) {
     global $serendipity;
 
-    setcookie("serendipity[$name]", $value, time()+60*60*24*30, $serendipity['serendipityHTTPPath']);
+    $secure = (strtolower($_SERVER['HTTPS']) == 'on') ? true : false;
+    setcookie("serendipity[$name]", $value, time()+60*60*24*30, $serendipity['serendipityHTTPPath'], $_SERVER['HTTP_HOST'], $secure);
     $_COOKIE[$name] = $value;
     $serendipity['COOKIE'][$name] = $value;
 }
@@ -441,68 +586,6 @@ function serendipity_deleteCookie($name) {
     unset($serendipity['COOKIE'][$name]);
 }
 
-/**
- * Perform user authentication routine
- *
- * If a user is already authenticated via session data, this bypasses some routines.
- * After a user has ben authenticated, several SESSION variables ar set.
- * If the authentication fails, the session is destroyed.
- *
- * @access public
- * @param   string      The username to check
- * @param   string      The password to check (may contain plaintext or MD5 hash)
- * @param   boolean     Indicates whether the input password is already in MD5 format (TRUE) or not (FALSE).
- * @param   boolean     Indicates whether to query external plugins for authentication
- * @return  boolean     True on success, False on error
- */
-function serendipity_authenticate_author($username = '', $password = '', $is_md5 = false, $use_external = true) {
-    global $serendipity;
-
-    if (isset($_SESSION['serendipityUser']) && isset($_SESSION['serendipityPassword']) && isset($_SESSION['serendipityAuthedUser']) && $_SESSION['serendipityAuthedUser'] == true) {
-        $username = $_SESSION['serendipityUser'];
-        $password = $_SESSION['serendipityPassword'];
-        // For safety reasons when multiple blogs are installed on the same host, we need to check the current author each time to not let him log into a different blog with the same sessiondata
-        $is_md5 = true;
-    }
-
-    if ($username != '') {
-        if ($use_external) {
-            serendipity_plugin_api::hook_event('backend_auth', $is_md5, array('username' => $username, 'password' => $password));
-        }
-
-        if ($is_md5 === false && !empty($password)) {
-            $password = md5($password);
-        }
-
-        $query = "SELECT DISTINCT
-                    email, authorid, userlevel, right_publish
-                  FROM
-                    {$serendipity['dbPrefix']}authors
-                  WHERE
-                    username   = '" . serendipity_db_escape_string($username) . "'
-                  AND password = '" . serendipity_db_escape_string($password) . "'";
-        $row = serendipity_db_query($query, true, 'assoc');
-
-        if (is_array($row)) {
-            serendipity_setCookie('old_session', session_id());
-            $_SESSION['serendipityUser']        = $serendipity['serendipityUser']         = $username;
-            $_SESSION['serendipityPassword']    = $serendipity['serendipityPassword']     = $password;
-            $_SESSION['serendipityEmail']       = $serendipity['serendipityEmail']        = $row['email'];
-            $_SESSION['serendipityAuthorid']    = $serendipity['authorid']                = $row['authorid'];
-            $_SESSION['serendipityUserlevel']   = $serendipity['serendipityUserlevel']    = $row['userlevel'];
-            $_SESSION['serendipityAuthedUser']  = $serendipity['serendipityAuthedUser']   = true;
-            $_SESSION['serendipityRightPublish']= $serendipity['serendipityRightPublish'] = $row['right_publish'];
-            serendipity_load_configuration($serendipity['authorid']);
-            return true;
-        } else {
-            $_SESSION['serendipityAuthedUser'] = false;
-            @session_destroy();
-        }
-    }
-
-    return false;
-}
-
 /**
  * Performs a check whether an iframe for the admin section shall be emitted
  *
@@ -576,8 +659,7 @@ function serendipity_iframe(&$entry, $mode = null, $use_smarty = true) {
                     echo '<script type="text/javascript">parent.document.forms[\'serendipityEntry\'][\'serendipity[id]\'].value = "' . $serendipity['lastSavedEntry'] . '";</script>';
                 }
                 $entrylink = serendipity_archiveURL($res, $entry['title'], 'serendipityHTTPPath', true, array('timestamp' => $entry['timestamp']));
-                echo '<div class="serendipityAdminMsgSuccess">' . ENTRY_SAVED . ' (<a href="' . $entrylink . '" target="_blank">' . VIEW . '</a
->)</div>';
+                echo '<div class="serendipityAdminMsgSuccess">' . ENTRY_SAVED . ' (<a href="' . $entrylink . '" target="_blank">' . VIEW . '</a>)</div>';
             }
             echo '<br style="clear: both" />';
 
@@ -596,7 +678,7 @@ function serendipity_iframe(&$entry, $mode = null, $use_smarty = true) {
     if ($use_smarty) {
         $preview = ob_get_contents();
         ob_end_clean();
-        $serendipity['smarty']->assign('preview', $preview);
+        $serendipity['smarty']->assign_by_ref('preview', $preview);
         $serendipity['smarty']->display(serendipity_getTemplateFile('preview_iframe.tpl', 'serendipityPath'));
     }
 
@@ -767,7 +849,7 @@ function &serendipity_getPermissions($authorid) {
     global $serendipity;
 
         // Get group information
-        $groups = serendipity_db_query("SELECT ag.groupid, g.name, gc.property, gc.value
+        $groups =& serendipity_db_query("SELECT ag.groupid, g.name, gc.property, gc.value
                                           FROM {$serendipity['dbPrefix']}authorgroups AS ag
                                LEFT OUTER JOIN {$serendipity['dbPrefix']}groups AS g
                                             ON ag.groupid = g.id
@@ -913,7 +995,11 @@ function serendipity_checkPermission($permName, $authorid = null, $returnMyGroup
     }
 
     if ($returnMyGroups) {
-        return $group[$authorid]['membership'];
+        if ($returnMyGroups === 'all') {
+            return $group[$authorid];
+        } else {
+            return $group[$authorid]['membership'];
+        }
     }
 
     if ($authorid == $serendipity['authorid'] && $serendipity['no_create']) {
@@ -1032,8 +1118,11 @@ function &serendipity_fetchGroup($groupid) {
                            LEFT OUTER JOIN {$serendipity['dbPrefix']}groupconfig AS gc
                                         ON g.id = gc.id
                                      WHERE g.id = " . (int)$groupid, false, 'assoc');
-    foreach($groups AS $group) {
-        $conf[$group['property']] = $group['value'];
+
+    if (is_array($groups)) {
+        foreach($groups AS $group) {
+            $conf[$group['property']] = $group['value'];
+        }
     }
 
     // The following are unique
@@ -1056,7 +1145,7 @@ function &serendipity_fetchGroup($groupid) {
 function &serendipity_getGroups($authorid, $sequence = false) {
     global $serendipity;
 
-    $groups =& serendipity_db_query("SELECT g.id   AS confkey,
+    $_groups =& serendipity_db_query("SELECT g.id   AS confkey,
                                             g.name AS confvalue,
                                             g.id   AS id,
                                             g.name AS name
@@ -1064,8 +1153,10 @@ function &serendipity_getGroups($authorid, $sequence = false) {
                            LEFT OUTER JOIN {$serendipity['dbPrefix']}groups AS g
                                         ON g.id = ag.groupid
                                      WHERE ag.authorid = " . (int)$authorid, false, 'assoc');
-    if (!is_array($groups)) {
+    if (!is_array($_groups)) {
         $groups = array();
+    } else {
+        $groups =& $_groups;
     }
 
     if ($sequence) {
@@ -1239,9 +1330,12 @@ function serendipity_intersectGroup($checkuser = null, $myself = null) {
  * @param   int     The ID of the group to update
  * @param   array   The associative array of permission names
  * @param   array   The associative array of new values for the permissions. Needs the same associative keys like the $perms array.
+ * @param   bool    Indicates if an all new privilege should be inserted (true) or if an existing privilege is going to be checked
+ * @param   array   The associative array of plugin permission names
+ * @param   array   The associative array of plugin permission hooks
  * @return true
  */
-function serendipity_updateGroupConfig($groupid, &$perms, &$values) {
+function serendipity_updateGroupConfig($groupid, &$perms, &$values, $isNewPriv = false, $forbidden_plugins = null, $forbidden_hooks = null) {
     global $serendipity;
 
     if (!serendipity_checkPermission('adminUsersGroups')) {
@@ -1260,6 +1354,10 @@ function serendipity_updateGroupConfig($groupid, &$perms, &$values) {
 
     serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}groupconfig WHERE id = " . (int)$groupid);
     foreach ($perms AS $perm => $userlevels) {
+        if (substr($perm, 0, 2) == 'f_') {
+            continue;
+        }
+
         if (isset($values[$perm]) && $values[$perm] == 'true') {
             $value = 'true';
         } elseif (isset($values[$perm]) && $values[$perm] === 'false') {
@@ -1270,7 +1368,7 @@ function serendipity_updateGroupConfig($groupid, &$perms, &$values) {
             $value = 'false';
         }
 
-        if (!serendipity_checkPermission($perm)) {
+        if ($isNewPriv == false && !serendipity_checkPermission($perm)) {
             if (!isset($storage[$perm])) {
                 $value = 'false';
             } else {
@@ -1287,6 +1385,28 @@ function serendipity_updateGroupConfig($groupid, &$perms, &$values) {
         );
     }
 
+    if (is_array($forbidden_plugins)) {
+        foreach($forbidden_plugins AS $plugid) {
+            serendipity_db_query(
+                sprintf("INSERT INTO {$serendipity['dbPrefix']}groupconfig (id, property, value) VALUES (%d, '%s', 'true')",
+                    (int)$groupid,
+                    serendipity_db_escape_string('f_' . urldecode($plugid))
+                )
+            );
+        }
+    }
+
+    if (is_array($forbidden_hooks)) {
+        foreach($forbidden_hooks AS $hook) {
+            serendipity_db_query(
+                sprintf("INSERT INTO {$serendipity['dbPrefix']}groupconfig (id, property, value) VALUES (%d, '%s', 'true')",
+                    (int)$groupid,
+                    serendipity_db_escape_string('f_' . urldecode($hook))
+                )
+            );
+        }
+    }
+
     serendipity_db_query("UPDATE {$serendipity['dbPrefix']}groups SET name = '" . serendipity_db_escape_string($values['name']) . "' WHERE id = " . (int)$groupid);
 
     if (is_array($values['members'])) {
@@ -1357,9 +1477,10 @@ function serendipity_addDefaultGroup($name, $level) {
  * @param   string  The type of an artifact (category|entry)
  * @param   string  The type of access to grant (read|write)
  * @param   array   The ID of the group to grant access to
+ * @param   string  A variable option for an artifact
  * @return  boolean True if ACL was applied, false if not.
  */
-function serendipity_ACLGrant($artifact_id, $artifact_type, $artifact_mode, $groups) {
+function serendipity_ACLGrant($artifact_id, $artifact_type, $artifact_mode, $groups, $artifact_index = '') {
     global $serendipity;
 
     if (empty($groups) || !is_array($groups)) {
@@ -1368,15 +1489,16 @@ function serendipity_ACLGrant($artifact_id, $artifact_type, $artifact_mode, $gro
 
     // Delete all old existing relations.
     serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}access
-                                WHERE artifact_id   = " . (int)$artifact_id . "
-                                  AND artifact_type = '" . serendipity_db_escape_string($artifact_type) . "'
-                                  AND artifact_mode = '" . serendipity_db_escape_string($artifact_mode) . "'");
+                                WHERE artifact_id    = " . (int)$artifact_id . "
+                                  AND artifact_type  = '" . serendipity_db_escape_string($artifact_type) . "'
+                                  AND artifact_mode  = '" . serendipity_db_escape_string($artifact_mode) . "'
+                                  AND artifact_index = '" . serendipity_db_escape_string($artifact_index) . "'");
 
     $data = array(
         'artifact_id'    => (int)$artifact_id,
         'artifact_type'  => $artifact_type,
         'artifact_mode'  => $artifact_mode,
-        'artifact_index' => ''
+        'artifact_index' => $artifact_index
     );
 
     if (count($data) < 1) {
@@ -1404,16 +1526,18 @@ function serendipity_ACLGrant($artifact_id, $artifact_type, $artifact_mode, $gro
  * @param   int     The ID of the artifact to set the access
  * @param   string  The type of an artifact (category|entry)
  * @param   string  The type of access to check for (read|write)
+ * @param   string  A variable option for an artifact
  * @return  array   Returns an array of all groups that are allowed for this kind of access. You can then check if you are the member of any of the groups returned here.
  */
-function serendipity_ACLGet($artifact_id, $artifact_type, $artifact_mode) {
+function serendipity_ACLGet($artifact_id, $artifact_type, $artifact_mode, $artifact_index = '') {
     global $serendipity;
 
     $sql = "SELECT groupid, artifact_index FROM {$serendipity['dbPrefix']}access
-                    WHERE artifact_type = '" . serendipity_db_escape_string($artifact_type) . "'
-                      AND artifact_id   = '" . (int)$artifact_id . "'
-                      AND artifact_mode = '" . serendipity_db_escape_string($artifact_mode) . "'";
-    $rows = serendipity_db_query($sql, false, 'assoc');
+                    WHERE artifact_type  = '" . serendipity_db_escape_string($artifact_type) . "'
+                      AND artifact_id    = '" . (int)$artifact_id . "'
+                      AND artifact_mode  = '" . serendipity_db_escape_string($artifact_mode) . "'
+                      AND artifact_index = '" . serendipity_db_escape_string($artifact_index) . "'";
+    $rows =& serendipity_db_query($sql, false, 'assoc');
 
     if (!is_array($rows)) {
         return false;
@@ -1474,7 +1598,7 @@ function serendipity_ACLCheck($authorid, $artifact_id, $artifact_type, $artifact
                AND ( {$artifact_sql['where']} )
           GROUP BY result";
 
-    $res = serendipity_db_query($sql, true, 'assoc');
+    $res =& serendipity_db_query($sql, true, 'assoc');
     if (is_array($res) && !empty($res['result'])) {
         return true;
     }
@@ -1497,9 +1621,11 @@ function serendipity_ACLCheck($authorid, $artifact_id, $artifact_type, $artifact
  * @access private
  * @param   array       Associative array that holds the SQL part array to be used in other functions like serendipity_fetchEntries()
  * @param   boolean     Some queries do not need to joins categories. When ACLs need to be applied, this column is required, so if $append_category is set to true it will perform this missing JOIN.
+ * @param   string      The ACL type ('category', 'directory')
+ * @param   string      ACL mode
  * @return  true        True if ACLs were applied, false if not.
  */
-function serendipity_ACL_SQL(&$cond, $append_category = false) {
+function serendipity_ACL_SQL(&$cond, $append_category = false, $type = 'category', $mode = 'read') {
     global $serendipity;
 
     // A global configuration item controls whether the blog should apply ACLs or not!
@@ -1525,12 +1651,25 @@ function serendipity_ACL_SQL(&$cond, $append_category = false) {
                                        ON ec.categoryid = c.categoryid";
         }
 
+        switch($type) {
+            case 'directory':
+                $sql_artifact_column = 'i.path IS NULL OR
+                                        acl_acc.groupid IS NULL';
+                $sql_artifact = 'AND acl_acc.artifact_index = i.path';
+                break;
+
+            case 'category':
+                $sql_artifact_column = 'c.categoryid IS NULL';
+                $sql_artifact = 'AND acl_acc.artifact_id   = c.categoryid';
+                break;
+        }
+
         $cond['joins'] .= " LEFT JOIN {$serendipity['dbPrefix']}authorgroups AS acl_a
                                    ON acl_a.authorid = " . $read_id . "
                             LEFT JOIN {$serendipity['dbPrefix']}access AS acl_acc
-                                   ON (    acl_acc.artifact_mode = 'read'
-                                       AND acl_acc.artifact_type = 'category'
-                                       AND acl_acc.artifact_id   = c.categoryid
+                                   ON (    acl_acc.artifact_mode = '" . $mode . "'
+                                       AND acl_acc.artifact_type = '" . $type . "'
+                                       " . $sql_artifact . "
                                       )";
 
         if (empty($cond['and'])) {
@@ -1541,7 +1680,7 @@ function serendipity_ACL_SQL(&$cond, $append_category = false) {
 
         // When in Admin-Mode, apply readership permissions.
         $cond['and'] .= "    (
-                                 c.categoryid IS NULL
+                                 " . $sql_artifact_column . "
                                  OR ( acl_acc.groupid = " . $read_id_sql . ")
                                  OR ( acl_acc.artifact_id IS NULL
                                       " . (isset($serendipity['GET']['adminModule']) &&
@@ -1651,7 +1790,7 @@ function serendipity_reportXSRF($type = 0, $reset = true, $use_config = false) {
  * @see serendipity_setFormToken()
  * @return  boolean     Returns true, if XSRF attempt was found and the token was missing
  */
-function serendipity_checkFormToken() {
+function serendipity_checkFormToken($output = true) {
     global $serendipity;
 
     $token = '';
@@ -1662,20 +1801,19 @@ function serendipity_checkFormToken() {
     }
 
     if (empty($token)) {
-        echo serendipity_reportXSRF('token', false);
+        if ($output) echo serendipity_reportXSRF('token', false);
         return false;
     }
 
     if ($token != md5(session_id()) &&
         $token != md5($serendipity['COOKIE']['old_session'])) {
-        echo serendipity_reportXSRF('token', false);
+        if ($output) echo serendipity_reportXSRF('token', false);
         return false;
     }
 
     return true;
 }
 
-/**
 /**
  * Prevent XSRF attacks by setting a form token within HTTP Forms
  *
@@ -1705,4 +1843,59 @@ function serendipity_setFormToken($type = 'form') {
     }
 }
 
+function &serendipity_loadThemeOptions(&$template_config) {
+    global $serendipity;
+    $_template_vars =& serendipity_db_query("SELECT name, value FROM {$serendipity['dbPrefix']}options
+                                             WHERE okey = 't_" . serendipity_db_escape_string($serendipity['template']) . "'", false, 'assoc', false, 'name', 'value');
+    if (!is_array($_template_vars)) {
+        $template_vars = array();
+    } else {
+        $template_vars =& $_template_vars;
+    }
+
+    foreach($template_config AS $key => $item) {
+        if (!isset($template_vars[$item['var']])) {
+            $template_vars[$item['var']] = $item['default'];
+        }
+    }
+
+    return $template_vars;
+}
+
+function serendipity_hasPluginPermissions($plugin, $groupid = null) {
+    static $forbidden = null;
+    global $serendipity;
+
+    if (empty($serendipity['authorid'])) {
+        return true;
+    }
+
+    if ($forbidden === null || ($groupid !== null && !isset($forbidden[$groupid]))) {
+        $forbidden = array();
+        
+        if ($groupid === null) {
+            $groups =& serendipity_checkPermission(null, null, 'all');
+        } else {
+            $groups = array($groupid => serendipity_fetchGroup($groupid));
+        }
+
+        foreach($groups AS $idx => $group) {
+            if ($idx == 'membership') {
+                continue;
+            }
+            foreach($group AS $key => $val) {
+                if (substr($key, 0, 2) == 'f_') {
+                    $forbidden[$groupid][$key] = true;
+                }
+            }
+        }
+    }
+
+    if (isset($forbidden[$groupid]['f_' . $plugin])) {
+        return false;
+    } else {
+        return true;
+    }
+}
+
 /* vim: set sts=4 ts=4 expandtab : */
