@@ -1,4 +1,4 @@
-<?php # $Id: functions_entries.inc.php 1521 2006-11-30 21:34:33Z garvinhicking $
+<?php # $Id: functions_entries.inc.php 1661 2007-04-01 11:17:35Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -6,6 +6,11 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
+if (defined('S9Y_FRAMEWORK_ENTRIES')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_ENTRIES', true);
+
 /**
  * Delete a category or range of categories
  *
@@ -36,7 +41,7 @@ function serendipity_deleteCategory($category_range, $admin_category) {
 function serendipity_fetchCategoryRange($categoryid) {
     global $serendipity;
 
-    $res = serendipity_db_query("SELECT category_left, category_right FROM {$serendipity['dbPrefix']}category WHERE categoryid='". (int)$categoryid ."'");
+    $res =& serendipity_db_query("SELECT category_left, category_right FROM {$serendipity['dbPrefix']}category WHERE categoryid='". (int)$categoryid ."'");
     if (!is_array($res) || !isset($res[0]['category_left']) || !isset($res[0]['category_right'])) {
         $res = array(array('category_left' => 0, 'category_right' => 0));
     }
@@ -64,6 +69,10 @@ function serendipity_getMultiCategoriesSQL($cats, $invert = false) {
             $cat_sql_array[] = " (c.category_left " . ($invert ? " NOT " : "") . " BETWEEN " . implode(' AND ', serendipity_fetchCategoryRange($categoryid)) . ')';
         }
     }
+    
+    if (count($cat_sql_array) < 1) {
+        return '';
+    }
 
     return '(' . implode(($invert ? ' AND ' : ' OR '), $cat_sql_array) . ')';
 }
@@ -93,7 +102,7 @@ function serendipity_fetchCategoryInfo($categoryid, $categoryname = '') {
                     FROM {$serendipity['dbPrefix']}category AS c
                    WHERE category_name = '" . serendipity_db_escape_string($categoryname) . "'";
 
-        $ret = serendipity_db_query($query);
+        $ret =& serendipity_db_query($query);
         return $ret[0];
     } else {
         $query = "SELECT
@@ -106,7 +115,7 @@ function serendipity_fetchCategoryInfo($categoryid, $categoryname = '') {
                     FROM {$serendipity['dbPrefix']}category AS c
                    WHERE categoryid = " . (int)$categoryid;
 
-        $ret = serendipity_db_query($query);
+        $ret =& serendipity_db_query($query);
         return $ret[0];
     }
 }
@@ -118,7 +127,7 @@ function serendipity_fetchCategoryInfo($categoryid, $categoryname = '') {
  * @param   int     The ID of the entry
  * @return  array   The array of associated categories to that entry
  */
-function serendipity_fetchEntryCategories($entryid) {
+function &serendipity_fetchEntryCategories($entryid) {
   global $serendipity;
 
     if (is_numeric($entryid)) {
@@ -131,11 +140,13 @@ function serendipity_fetchEntryCategories($entryid) {
                     FROM {$serendipity['dbPrefix']}category AS c
               INNER JOIN {$serendipity['dbPrefix']}entrycat AS ec
                       ON ec.categoryid = c.categoryid
-                   WHERE ec.entryid = {$entryid}";
+                   WHERE ec.entryid = {$entryid}
+                ORDER BY c.category_name ASC";
 
-        $cat = serendipity_db_query($query);
+        $cat =& serendipity_db_query($query);
         if (!is_array($cat)) {
-            return array();
+            $arr = array();
+            return $arr;
         } else {
             return $cat;
         }
@@ -188,7 +199,7 @@ function serendipity_fetchEntryCategories($entryid) {
  * @param   string      If set to "array", the array of entries will be returned. "flat-array" will only return the articles without their entryproperties. "single" will only return a 1-dimensional array. "query" will only return the used SQL.
  * @return  array       Holds the super-array of all entries with all additional information
  */
-function serendipity_fetchEntries($range = null, $full = true, $limit = '', $fetchDrafts = false, $modified_since = false, $orderby = 'timestamp DESC', $filter_sql = '', $noCache = false, $noSticky = false, $select_key = null, $group_by = null, $returncode = 'array') {
+function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fetchDrafts = false, $modified_since = false, $orderby = 'timestamp DESC', $filter_sql = '', $noCache = false, $noSticky = false, $select_key = null, $group_by = null, $returncode = 'array') {
     global $serendipity;
 
     $cond = array();
@@ -304,9 +315,9 @@ function serendipity_fetchEntries($range = null, $full = true, $limit = '', $fet
 
     if (!isset($serendipity['GET']['adminModule']) && !serendipity_db_bool($serendipity['showFutureEntries'])) {
         if (!empty($cond['and'])) {
-            $cond['and'] .= " AND e.timestamp <= " . time();
+            $cond['and'] .= " AND e.timestamp <= " . serendipity_db_time();
         } else {
-            $cond['and'] = "WHERE e.timestamp <= " . time();
+            $cond['and'] = "WHERE e.timestamp <= " . serendipity_db_time();
         }
     }
 
@@ -382,7 +393,7 @@ function serendipity_fetchEntries($range = null, $full = true, $limit = '', $fet
         return $query;
     }
 
-    $ret = serendipity_db_query($query, $fetch_single, 'assoc');
+    $ret =& serendipity_db_query($query, $fetch_single, 'assoc');
 
     if (is_string($ret)) {
         die("Query failed: $ret");
@@ -439,7 +450,7 @@ function serendipity_fetchEntryData(&$ret) {
                WHERE " . serendipity_db_in_sql('ec.entryid', $search_ids) . "
             ORDER BY c.category_name ASC";
 
-    $search_ret = serendipity_db_query($query, false, 'assoc');
+    $search_ret =& serendipity_db_query($query, false, 'assoc');
 
     if (is_array($search_ret)) {
         foreach($search_ret AS $i => $entry) {
@@ -458,14 +469,14 @@ function serendipity_fetchEntryData(&$ret) {
  * @param   string      Indicates whether drafts should be fetched
  * @return
  */
-function serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false') {
+function &serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false') {
     global $serendipity;
 
     $cond = array();
     $cond['and'] = " "; // intentional dummy string to attach dummy AND parts to the WHERE clauses
 
     if ($fetchDrafts == 'false') {
-        $cond['and'] = " AND e.isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp <= " . time() : '');
+        $cond['and'] = " AND e.isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp <= " . serendipity_db_time() : '');
     }
 
     if (isset($serendipity['GET']['adminModule']) && $serendipity['GET']['adminModule'] == 'entries' && !serendipity_checkPermission('adminEntriesMaintainOthers')) {
@@ -491,6 +502,7 @@ function serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false'
                             e.moderate_comments,
 
                             a.realname AS author,
+                            a.username AS loginname,
                             a.email
                       FROM
                             {$serendipity['dbPrefix']}entries e
@@ -502,11 +514,15 @@ function serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false'
                             {$cond['and']}
                      LIMIT  1";
 
-    $ret = serendipity_db_query($querystring, true, 'assoc');
+    $ret =& serendipity_db_query($querystring, true, 'assoc');
 
     if (is_array($ret)) {
-        $ret['categories'] = serendipity_fetchEntryCategories($ret['id']);
-        $ret['properties'] = serendipity_fetchEntryProperties($ret['id']);
+        $ret['categories'] =& serendipity_fetchEntryCategories($ret['id']);
+        $ret['properties'] =& serendipity_fetchEntryProperties($ret['id']);
+        $stack     = array();
+        $stack[0]  = &$ret;
+        $assoc_ids = array($ret['id'] => 0);
+        serendipity_plugin_api::hook_event('frontend_entryproperties', $stack, $assoc_ids);
     }
 
     return $ret;
@@ -519,20 +535,22 @@ function serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false'
  * @param   int     The ID of the entry to fetch additonal data for
  * @return  array   The array of given properties to an entry
  */
-function serendipity_fetchEntryProperties($id) {
+function &serendipity_fetchEntryProperties($id) {
     global $serendipity;
 
     $parts = array();
     serendipity_plugin_api::hook_event('frontend_entryproperties_query', $parts);
 
-    $properties = serendipity_db_query("SELECT property, value FROM {$serendipity['dbPrefix']}entryproperties WHERE entryid = " . (int)$id . " " . $parts['and']);
-    if (!is_array($properties)) {
+    $_properties =& serendipity_db_query("SELECT property, value FROM {$serendipity['dbPrefix']}entryproperties WHERE entryid = " . (int)$id . " " . $parts['and']);
+    if (!is_array($_properties)) {
         $properties = array();
+    } else {
+        $properties =& $_properties;
     }
 
     $property = array();
     foreach($properties AS $idx => $row) {
-        $property[$row['property']] = $row['value'];
+        $property[$row['property']] =& $row['value'];
     }
 
     return $property;
@@ -548,7 +566,7 @@ function serendipity_fetchEntryProperties($id) {
  * @param   string  The ACL artifact condition. If set to "write" only categories will be shown that the author can write to. If set to "read", only categories will be show that the author can read or write to.
  * @return  array   Returns the array of categories
  */
-function serendipity_fetchCategories($authorid = null, $name = null, $order = null, $artifact_mode = 'write') {
+function &serendipity_fetchCategories($authorid = null, $name = null, $order = null, $artifact_mode = 'write') {
     global $serendipity;
 
     if ($name === null) {
@@ -568,10 +586,17 @@ function serendipity_fetchCategories($authorid = null, $name = null, $order = nu
     }
 
     $where = '';
+
+    if ($authorid === -1 OR $authorid === 0) {
+        $sql_groupid = '0';
+    } else {
+        $sql_groupid = 'ag.groupid';
+    }
+
     if ($authorid != 'all' && is_numeric($authorid)) {
         $sql_authorid = $authorid;
         if (!serendipity_checkPermission('adminCategoriesMaintainOthers', $authorid)) {
-            $where = " WHERE (c.authorid = $authorid OR c.authorid = 0)";
+            $where = " WHERE (c.authorid = $authorid OR c.authorid = 0) ";
             $where .= "OR (
                           acl.artifact_type = 'category'
                           AND acl.artifact_mode = '" . serendipity_db_escape_string($artifact_mode) . "'
@@ -611,6 +636,7 @@ function serendipity_fetchCategories($authorid = null, $name = null, $order = nu
                            c.parentid,
 
                            a.username,
+                           a.username AS loginname,
                            a.realname
                       FROM {$serendipity['dbPrefix']}category AS c
            LEFT OUTER JOIN {$serendipity['dbPrefix']}authors AS a
@@ -618,14 +644,14 @@ function serendipity_fetchCategories($authorid = null, $name = null, $order = nu
            LEFT OUTER JOIN {$serendipity['dbPrefix']}authorgroups AS ag
                         ON ag.authorid = $sql_authorid
            LEFT OUTER JOIN {$serendipity['dbPrefix']}access AS acl
-                        ON (ag.groupid = acl.groupid AND acl.artifact_id = c.categoryid)
+                        ON ($sql_groupid = acl.groupid AND acl.artifact_id = c.categoryid)
                            $where
                            $group";
     if (!empty($order)) {
         $querystring .= "\n ORDER BY $order";
     }
 
-    $ret = serendipity_db_query($querystring);
+    $ret =& serendipity_db_query($querystring);
     if (is_string($ret)) {
         echo "Query failed: $ret";
     }
@@ -667,7 +693,7 @@ function serendipity_rebuildCategoryTree($parent = 0, $left = 0) {
  * @param   int         Restrict the number of results [also uses $serendipity['GET']['page'] for pagination]
  * @return  array       Returns the superarray of entries found
  */
-function serendipity_searchEntries($term, $limit = '') {
+function &serendipity_searchEntries($term, $limit = '') {
     global $serendipity;
 
     if ($limit == '') {
@@ -704,7 +730,7 @@ function serendipity_searchEntries($term, $limit = '') {
         }
     }
 
-    $cond['and'] = " AND isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . time() : '');
+    $cond['and'] = " AND isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '');
     serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('source' => 'search', 'term' => $term));
 
     serendipity_ACL_SQL($cond, 'limited');
@@ -725,6 +751,8 @@ function serendipity_searchEntries($term, $limit = '') {
                             e.id,
                             e.authorid,
                             a.realname AS author,
+                            e.allow_comments,
+                            e.moderate_comments,
                             a.email,
                             e.timestamp,
                             e.comments,
@@ -738,7 +766,7 @@ function serendipity_searchEntries($term, $limit = '') {
                   ORDER BY  timestamp DESC
                     $limit";
 
-    $search = serendipity_db_query($querystring);
+    $search =& serendipity_db_query($querystring);
 
     if (is_array($search)) {
         serendipity_fetchEntryData($search);
@@ -752,14 +780,18 @@ function serendipity_searchEntries($term, $limit = '') {
  *
  * The list of total entries is calculated from the serendipity_getTotelEntries() function
  *
+ * @param string    suffix for URLs
+ * @param int       Amount of total entries
  * @access public
  * @see serendipity_getTotalEntries()
  * @return null
  */
-function serendipity_printEntryFooter() {
+function serendipity_printEntryFooter($suffix = '.html', $totalEntries = null) {
     global $serendipity;
 
-    $totalEntries = serendipity_getTotalEntries();
+    if ($totalEntries === null) {
+        $totalEntries = serendipity_getTotalEntries();
+    }
     $totalPages   = ceil($totalEntries / $serendipity['fetchLimit']);
 
     if (!isset($serendipity['GET']['page'])) {
@@ -773,7 +805,7 @@ function serendipity_printEntryFooter() {
     if ($serendipity['GET']['page'] > 1) {
         $uriArguments = $serendipity['uriArguments'];
         $uriArguments[] = 'P'. ($serendipity['GET']['page'] - 1);
-        $serendipity['smarty']->assign('footer_prev_page', serendipity_rewriteURL(implode('/', $uriArguments) .'.html'));
+        $serendipity['smarty']->assign('footer_prev_page', serendipity_rewriteURL(implode('/', $uriArguments) . $suffix));
     }
 
     $uriArguments = $serendipity['uriArguments'];
@@ -781,13 +813,13 @@ function serendipity_printEntryFooter() {
     $serendipity['smarty']->assign('footer_totalEntries', $totalEntries);
     $serendipity['smarty']->assign('footer_totalPages', $totalPages);
     $serendipity['smarty']->assign('footer_currentPage', $serendipity['GET']['page']);
-    $serendipity['smarty']->assign('footer_pageLink', serendipity_rewriteURL(implode('/', $uriArguments) . '.html'));
+    $serendipity['smarty']->assign('footer_pageLink', serendipity_rewriteURL(implode('/', $uriArguments) . $suffix));
     $serendipity['smarty']->assign('footer_info', sprintf(PAGE_BROWSE_ENTRIES, (int)$serendipity['GET']['page'], $totalPages, $totalEntries));
 
     if ($serendipity['GET']['page'] < $totalPages) {
         $uriArguments = $serendipity['uriArguments'];
         $uriArguments[] = 'P'. ($serendipity['GET']['page'] + 1);
-        $serendipity['smarty']->assign('footer_next_page', serendipity_rewriteURL(implode('/', $uriArguments) .'.html'));
+        $serendipity['smarty']->assign('footer_next_page', serendipity_rewriteURL(implode('/', $uriArguments) . $suffix));
     }
 }
 
@@ -811,7 +843,7 @@ function serendipity_getTotalEntries() {
         $querystring  = "SELECT count(distinct e.id) {$serendipity['fullCountQuery']}";
     }
 
-    $query = serendipity_db_query($querystring);
+    $query =& serendipity_db_query($querystring);
 
     if (is_array($query) && isset($query[0])) {
         if ($serendipity['dbType'] == 'sqlite') {
@@ -855,12 +887,20 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
         serendipity_plugin_api::hook_event('entry_display', $entries, $addData);
 
         if (isset($entries['clean_page']) && $entries['clean_page'] === true) {
-            $serendipity['smarty']->assign('plugin_clean_page', true);
+            if ($serendipity['view'] == '404') {
+                $serendipity['view'] = 'plugin';
+            }
+
+            $serendipity['smarty']->assign(array(
+                'plugin_clean_page' => true,
+                'view'              => $serendipity['view'])
+            );
             serendipity_smarty_fetch($smarty_block, 'entries.tpl', true);
             return; // no display of this item
         }
     }
 
+
     // We shouldn't return here, because we want Smarty to handle the output
     if (!is_array($entries) || $entries[0] == false || !isset($entries[0]['timestamp'])) {
         $entries = array();
@@ -903,6 +943,18 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
                 $entry['is_cached'] = true;
             }
 
+	    //--JAM: Highlight-span search terms
+	    if ($serendipity['action'] == 'search') {
+	        $searchterms = str_replace('"', '', $serendipity['GET']['searchterms']);
+	        $searchterms = explode($searchterms, ' ');
+		foreach($searchterms as $searchdx => $searchterm) {
+		    $searchclass = "foundterm foundterm".$searchdx;
+		    $entry['body'] = preg_replace('/('.$searchterm.')/mi',
+		        '<span class="'.$searchclass.'">\1</span>',
+			$entry['body']);
+		}
+	    }
+
             if (!empty($entry['properties']['ep_cache_extended'])) {
                 $entry['extended']  = &$entry['properties']['ep_cache_extended'];
                 $entry['is_cached'] = true;
@@ -933,9 +985,14 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
 
             $entry['link']      = serendipity_archiveURL($entry['id'], $entry['title'], 'serendipityHTTPPath', true, array('timestamp' => $entry['timestamp']));
             $entry['commURL']   = serendipity_archiveURL($entry['id'], $entry['title'], 'baseURL', false, array('timestamp' => $entry['timestamp']));
-            $entry['rdf_ident'] = serendipity_archiveURL($entry['id'], $entry['title'], 'baseURL', true, array('timestamp' => $entry['timestamp']));
+            $entry['html_title']= $entry['title'];
             $entry['title']     = htmlspecialchars($entry['title']);
 
+            $entry['title_rdf']          = preg_replace('@-{2,}@', '-', $entry['html_title']);
+            $entry['rdf_ident']          = serendipity_archiveURL($entry['id'], $entry['title_rdf'], 'baseURL', true, array('timestamp' => $entry['timestamp']));
+            $entry['link_rdf']           = serendipity_rewriteURL(PATH_FEEDS . '/ei_'. $entry['id'] .'.rdf');
+            $entry['title_rdf']          = htmlspecialchars($entry['title_rdf']);
+
             $entry['link_allow_comments']    = $serendipity['baseURL'] . 'comment.php?serendipity[switch]=enable&amp;serendipity[entry]=' . $entry['id'];
             $entry['link_deny_comments']     = $serendipity['baseURL'] . 'comment.php?serendipity[switch]=disable&amp;serendipity[entry]=' . $entry['id'];
             $entry['allow_comments']         = serendipity_db_bool($entry['allow_comments']);
@@ -945,7 +1002,6 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
             $entry['link_popup_trackbacks']  = $serendipity['serendipityHTTPPath'] .'comment.php?serendipity[entry_id]='. $entry['id'] .'&amp;serendipity[type]=trackbacks';
             $entry['link_edit']              = $serendipity['baseURL'] .'serendipity_admin.php?serendipity[action]=admin&amp;serendipity[adminModule]=entries&amp;serendipity[adminAction]=edit&amp;serendipity[id]='. $entry['id'];
             $entry['link_trackback']         = $serendipity['baseURL'] .'comment.php?type=trackback&amp;entry_id='. $entry['id'];
-            $entry['link_rdf']               = serendipity_rewriteURL(PATH_FEEDS . '/ei_'. $entry['id'] .'.rdf');
             $entry['link_viewmode_threaded'] = $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'] .'?url='. $entry['commURL'] .'&amp;serendipity[cview]='. VIEWMODE_THREADED;
             $entry['link_viewmode_linear']   = $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'] .'?url='. $entry['commURL'] .'&amp;serendipity[cview]='. VIEWMODE_LINEAR;
             $entry['link_author']            = serendipity_authorURL($authorData);
@@ -991,14 +1047,13 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
 
             /* IF WE ARE DISPLAYING A FULL ENTRY */
             if (isset($serendipity['GET']['id'])) {
-                $serendipity['smarty']->assign(
-                    array(
-                        'comments_messagestack' => (isset($serendipity['messagestack']['comments']) ? (array)$serendipity['messagestack']['comments'] : array()),
-                        'is_comment_added'      => (isset($serendipity['GET']['csuccess']) && $serendipity['GET']['csuccess'] == 'true' ? true: false),
-                        'is_comment_moderate'   => (isset($serendipity['GET']['csuccess']) && $serendipity['GET']['csuccess'] == 'moderate' ? true: false)
-                    )
+                $comment_add_data = array(
+                    'comments_messagestack' => (isset($serendipity['messagestack']['comments']) ? (array)$serendipity['messagestack']['comments'] : array()),
+                    'is_comment_added'      => (isset($serendipity['GET']['csuccess']) && $serendipity['GET']['csuccess'] == 'true' ? true: false),
+                    'is_comment_moderate'   => (isset($serendipity['GET']['csuccess']) && $serendipity['GET']['csuccess'] == 'moderate' ? true: false)
                 );
 
+                $serendipity['smarty']->assign($comment_add_data);
                 serendipity_displayCommentForm(
                     $entry['id'],
                     $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'] . '?url=' . $entry['commURL'],
@@ -1019,7 +1074,7 @@ function serendipity_printEntries($entries, $extended = 0, $preview = false, $sm
         serendipity_printEntryFooter();
     }
 
-    $serendipity['smarty']->assign('entries', $dategroup);
+    $serendipity['smarty']->assign_by_ref('entries', $dategroup);
     unset($entries, $dategroup);
 
     if (isset($serendipity['short_archives']) && $serendipity['short_archives']) {
@@ -1092,6 +1147,10 @@ function serendipity_updertEntry($entry) {
     $newEntry = 0;
     $exflag = 0;
 
+    if (isset($entry['properties'])) {
+        unset($entry['properties']);
+    }
+
     if (!is_numeric($entry['timestamp'])) {
         $entry['timestamp'] = time();
     }
@@ -1175,7 +1234,7 @@ function serendipity_updertEntry($entry) {
             }
         }
 
-        if ($entry['isdraft'] === 'false' && $_entry['isdraft'] === 'false') {
+        if (!serendipity_db_bool($entry['isdraft']) && !serendipity_db_bool($_entry['isdraft'])) {
             $entry['last_modified'] = time();
         }
 
@@ -1198,6 +1257,14 @@ function serendipity_updertEntry($entry) {
 
     serendipity_purgeEntry($entry['id'], $entry['timestamp']);
 
+    if (!serendipity_db_bool($entry['isdraft'])) {
+        // When saving an entry, first all references need to be gathered. But trackbacks to them
+        // shall only be send at the end of the execution flow. However, certain plugins depend on
+        // the existance of handled references. Thus we store the current references at this point,
+        // execute the plugins and then reset the found references to the original state.
+        serendipity_handle_references($entry['id'], $serendipity['blogTitle'], $drafted_entry['title'], $drafted_entry['body'] . $drafted_entry['extended'], true);
+    }
+
     // Send publish tags if either a new article has been inserted from scratch, or if the entry was previously
     // stored as draft and is now published
     $entry['categories'] =& $categories;
@@ -1208,7 +1275,9 @@ function serendipity_updertEntry($entry) {
     }
 
     if (!serendipity_db_bool($entry['isdraft'])) {
-        serendipity_handle_references($entry['id'], $serendipity['blogTitle'], $drafted_entry['title'], $drafted_entry['body'] . $drafted_entry['extended'], $newEntry);
+        // Now that plugins are executed, we go ahead into the Temple of Doom and send possibly failing trackbacks.
+        // First, original list of references is restored (inside the function call)
+        serendipity_handle_references($entry['id'], $serendipity['blogTitle'], $drafted_entry['title'], $drafted_entry['body'] . $drafted_entry['extended'], false);
     }
 
     return (int)$entry['id'];
@@ -1243,7 +1312,7 @@ function serendipity_deleteEntry($id) {
     serendipity_db_query("DELETE FROM {$serendipity["dbPrefix"]}entrycat WHERE entryid=$id");
     serendipity_db_query("DELETE FROM {$serendipity["dbPrefix"]}entryproperties WHERE entryid=$id");
     serendipity_db_query("DELETE FROM {$serendipity["dbPrefix"]}comments WHERE entry_id=$id");
-    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}references WHERE entry_id='$id'");
+    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}references WHERE entry_id='$id' AND type = ''");
     serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}permalinks WHERE entry_id='$id'");
 }
 
@@ -1350,6 +1419,7 @@ function serendipity_updateEntryCategories($postid, $categories) {
  *
  * The archives are created according to the current timestamp and show the current year.
  * $serendipity['GET']['category'] is honoured like in serendipity_fetchEntries()
+ * $serendipity['GET']['viewAuthor'] is honoured like in serendipity_fetchEntries()
  *
  * @access public
  * @return null
@@ -1366,12 +1436,12 @@ function serendipity_printArchives() {
             $thisYear   = date('Y', serendipity_serverOffsetHour());
             $thisMonth  = date('m', serendipity_serverOffsetHour());
             break;
-        case 'jalali-utf8':
+        case 'persian-utf8':
             require_once S9Y_INCLUDE_PATH . 'include/functions_calendars.inc.php';
-            $lastYear   = jalali_date_utf('Y', serendipity_serverOffsetHour($f[0][0]));
-            $lastMonth  = jalali_date_utf('m', serendipity_serverOffsetHour($f[0][0]));
-            $thisYear   = jalali_date_utf('Y', serendipity_serverOffsetHour());
-            $thisMonth  = jalali_date_utf('m', serendipity_serverOffsetHour());
+            $lastYear   = persian_date_utf('Y', serendipity_serverOffsetHour($f[0][0]));
+            $lastMonth  = persian_date_utf('m', serendipity_serverOffsetHour($f[0][0]));
+            $thisYear   = persian_date_utf('Y', serendipity_serverOffsetHour());
+            $thisMonth  = persian_date_utf('m', serendipity_serverOffsetHour());
             break;
     }
     $max = 0;
@@ -1384,6 +1454,12 @@ function serendipity_printArchives() {
         $cat_get = '';
     }
 
+    if (isset($serendipity['GET']['viewAuthor'])) {
+        $author_get = '/A' . (int)$serendipity['GET']['viewAuthor'];
+    } else {
+        $author_get = '';
+    }
+
     $output = array();
     for ($y = $thisYear; $y >= $lastYear; $y--) {
         $output[$y]['year'] = $y;
@@ -1405,14 +1481,14 @@ function serendipity_printArchives() {
                     $s = serendipity_serverOffsetHour(mktime(0, 0, 0, $m, 1, $y), true);
                     $e = serendipity_serverOffsetHour(mktime(23, 59, 59, $m, date('t', $s), $y), true);
                     break;
-                case 'jalali-utf8':
+                case 'persian-utf8':
                     require_once S9Y_INCLUDE_PATH . 'include/functions_calendars.inc.php';
-                    $s = serendipity_serverOffsetHour(jalali_mktime(0, 0, 0, $m, 1, $y), true);
-                    $e = serendipity_serverOffsetHour(jalali_mktime(23, 59, 59, $m, date('t', $s), $y), true);
+                    $s = serendipity_serverOffsetHour(persian_mktime(0, 0, 0, $m, 1, $y), true);
+                    $e = serendipity_serverOffsetHour(persian_mktime(23, 59, 59, $m, date('t', $s), $y), true);
                     break;
             }
 
-            $entries = serendipity_db_query("SELECT count(id)
+            $entries =& serendipity_db_query("SELECT count(id)
                                                FROM {$serendipity['dbPrefix']}entries e
                                           LEFT JOIN {$serendipity['dbPrefix']}entrycat ec
                                                  ON e.id = ec.entryid
@@ -1421,8 +1497,9 @@ function serendipity_printArchives() {
                                               WHERE isdraft = 'false'
                                                 AND timestamp >= $s
                                                 AND timestamp <= $e "
-                                                    . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . time() : '')
-                                                    . (!empty($cat_sql) ? ' AND ' . $cat_sql : '') . "
+                                                    . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : '')
+                                                    . (!empty($cat_sql) ? ' AND ' . $cat_sql : '')
+                                                    . (!empty($serendipity['GET']['viewAuthor']) ? ' AND e.authorid = ' . (int)$serendipity['GET']['viewAuthor'] : '') . "
                                            GROUP BY ec.entryid", false, 'assoc');
             if (is_array($entries)) {
                 $entry_count = count($entries);
@@ -1437,14 +1514,15 @@ function serendipity_printArchives() {
 
             $data = array();
             $data['entry_count']    = $entry_count;
-            $data['link']           = serendipity_archiveDateUrl($y . '/'. sprintf('%02s', $m) . $cat_get);
-            $data['link_summary']   = serendipity_archiveDateUrl($y . '/'. sprintf('%02s', $m) . $cat_get, true);
+            $data['link']           = serendipity_archiveDateUrl($y . '/'. sprintf('%02s', $m) . $cat_get . $author_get);
+            $data['link_summary']   = serendipity_archiveDateUrl($y . '/'. sprintf('%02s', $m) . $cat_get . $author_get, true);
             $data['date']           = $s;
             $output[$y]['months'][] = $data;
         }
     }
-    $serendipity['smarty']->assign(array('archives' => $output,
-                                         'max_entries' => $max));
+
+    $serendipity['smarty']->assign_by_ref('archives', $output);
+    $serendipity['smarty']->assign_by_ref('max_entries', $max);
 
     serendipity_smarty_fetch('ARCHIVES', 'entries_archives.tpl', true);
 }
@@ -1464,20 +1542,20 @@ function serendipity_getTotalCount($what) {
             $res = serendipity_db_query("SELECT SUM(e.comments) AS sum
                                            FROM {$serendipity['dbPrefix']}entries AS e
                                           WHERE e.isdraft = 'false'
-                                                " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp  <= " . time() : ''), true, 'assoc');
+                                                " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp  <= " . serendipity_db_time() : ''), true, 'assoc');
             return $res['sum'];
         case 'trackbacks':
             $res = serendipity_db_query("SELECT SUM(e.trackbacks) AS sum
                                            FROM {$serendipity['dbPrefix']}entries AS e
                                           WHERE e.isdraft = 'false'
-                                                " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp  <= " . time() : ''), true, 'assoc');
+                                                " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp  <= " . serendipity_db_time() : ''), true, 'assoc');
             return $res['sum'];
         case 'entries':
             $res = serendipity_db_query("SELECT COUNT(e.id) AS sum
                                            FROM {$serendipity['dbPrefix']}entries AS e
                                           WHERE e.isdraft = 'false'
-                                                " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp  <= " . time() : ''), true, 'assoc');
+                                                " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND e.timestamp  <= " . serendipity_db_time() : ''), true, 'assoc');
             return $res['sum'];
 
     }
-}
\ No newline at end of file
+}
