@@ -6,7 +6,14 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
-include_once(S9Y_INCLUDE_PATH . "include/functions_trackbacks.inc.php");
+if (defined('S9Y_FRAMEWORK_ENTRIES_ADMIN')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_ENTRIES_ADMIN', true);
+
+if (!defined('S9Y_FRAMEWORK_TRACKBACKS')) {
+    include(S9Y_INCLUDE_PATH . "include/functions_trackbacks.inc.php");
+}
 
 /**
  * Prints the form for editing/creating new blog entries
@@ -117,7 +124,7 @@ function serendipity_printEntryForm($targetURL, $hiddens = array(), $entry = arr
 ?>
         <div class="serendipityAdminMsgError"><?php echo $errMsg; ?></div>
 <?php } ?>
-        <form <?php echo $entry['entry_form']; ?> action="<?php echo $targetURL; ?>" method="post" <?php echo ($serendipity['XHTML11'] ? 'id' : 'name'); ?>="serendipityEntry" style="margin-top: 0px; margin-bottom: 0px; padding-top: 0px; padding-bottom: 0px">
+        <form <?php echo $entry['entry_form']; ?> action="<?php echo $targetURL; ?>" method="post" id="serendipityEntry" style="margin-top: 0px; margin-bottom: 0px; padding-top: 0px; padding-bottom: 0px">
         <?php echo $hidden; ?>
 
         <table class="serendipityEntryEdit" border="0" width="100%">
