@@ -1,4 +1,4 @@
-<?php # $Id: functions_installer.inc.php 1521 2006-11-30 21:34:33Z garvinhicking $
+<?php # $Id: functions_installer.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -6,6 +6,11 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
+if (defined('S9Y_FRAMEWORK_INSTALLER')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_INSTALLER', true);
+
 /**
  * Convert a PHP Ini setting to a boolean flag
  *
@@ -105,6 +110,9 @@ function serendipity_updateLocalConfig($dbName, $dbPrefix, $dbHost, $dbUser, $db
     fwrite($configfp, "\t\$serendipity['dbPass']            = '" . addslashes($dbPass) . "';\n");
     fwrite($configfp, "\t\$serendipity['dbType']            = '" . addslashes($dbType) . "';\n");
     fwrite($configfp, "\t\$serendipity['dbPersistent']      = ". (serendipity_db_bool($dbPersistent) ? 'true' : 'false') .";\n");
+    if ($serendipity['dbNames']) {
+        fwrite($configfp, "\t\$serendipity['dbCharset']         = '" . addslashes(SQL_CHARSET) . "';\n");
+    }
 
     if (is_array($privateVariables) && count($privateVariables) > 0) {
         foreach($privateVariables AS $p_idx => $p_val) {
@@ -384,7 +392,7 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
             break;
 
         case 'multilist':
-            echo '<select name="'. $name .'[]" multiple="multiple">';
+            echo '<select name="'. $name .'[]" multiple="multiple" size="5">';
             foreach ((array)$default as $k => $v) {
                 print_r($v);
                 $selected = false;
@@ -420,6 +428,10 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
             echo '<input type="file" size="30" name="' . $name . '" />';
             break;
 
+        case 'textarea':
+            echo '<textarea rows="5" cols="40" name="' . $name . '">' . htmlspecialchars($value) . '</textarea>';
+            break;
+
         default:
             echo '<input type="text" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
             break;
@@ -439,9 +451,6 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
  */
 function serendipity_printConfigTemplate($config, $from = false, $noForm = false, $folded = true, $allowToggle = true) {
     global $serendipity;
-    if (!isset($serendipity['XHTML11'])) {
-        $serendipity['XHTML11'] = FALSE;
-    }
     if ( $allowToggle ) {
 ?>
 <script type="text/javascript" language="JavaScript">
@@ -564,7 +573,7 @@ function showConfigAll(count) {
                                 <span style="color: #5E7A94; font-size: 8pt;"><?php echo $item['description']; ?></span>
                             </td>
                             <td style="border-bottom: 1px #000000 solid; font-size: 8pt" align="left" valign="middle" width="25%">
-                                <?php echo ($serendipity['XHTML11'] ? '<span style="white-space: nowrap">' : '<nobr>'); ?><?php echo serendipity_guessInput($item['type'], $item['var'], $value, $item['default']); ?><?php echo ($serendipity['XHTML11'] ? '</span>' : '</nobr>'); ?>
+                                <span style="white-space: nowrap"><?php echo serendipity_guessInput($item['type'], $item['var'], $value, $item['default']); ?></span>
                             </td>
                         </tr>
 <?php
@@ -767,6 +776,7 @@ function serendipity_installFiles($serendipity_core = '') {
         $htaccess_cgi = '';
     }
 
+
     /* Detect comptability with php_value directives */
     if ($htaccess_cgi == '') {
         $response = '';
@@ -841,6 +851,7 @@ function serendipity_installFiles($serendipity_core = '') {
                    '{PAT_DELETE}', '{PATH_DELETE}',
                    '{PAT_APPROVE}', '{PATH_APPROVE}',
                    '{PAT_SEARCH}', '{PATH_SEARCH}',
+                   '{PAT_COMMENTS}', '{PATH_COMMENTS}',
                    '{PAT_CSS}',
                    '{PAT_PERMALINK}',
                    '{PAT_PERMALINK_AUTHORS}',
@@ -862,6 +873,7 @@ function serendipity_installFiles($serendipity_core = '') {
                    trim($PAT['DELETE'], '@/i'),      $serendipity['permalinkDeletePath'],
                    trim($PAT['APPROVE'], '@/i'),     $serendipity['permalinkApprovePath'],
                    trim($PAT['SEARCH'], '@/i'),      $serendipity['permalinkSearchPath'],
+                   trim($PAT['COMMENTS'], '@/i'),    $serendipity['permalinkCommentsPath'],
                    trim(PAT_CSS, '@/i'),
                    trim($PAT['PERMALINK'], '@/i'),
                    trim($PAT['PERMALINK_AUTHORS'], '@/i'),
