@@ -6,6 +6,11 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
+if (defined('S9Y_FRAMEWORK_PERMALINKS')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_PERMALINKS', true);
+
 /**
  * Converts a string into a filename that can be used safely in HTTP URLs
  *
@@ -220,6 +225,10 @@ function serendipity_initPermalinks() {
         $serendipity['permalinkSearchPath'] = 'search';
     }
 
+    if (!isset($serendipity['permalinkCommentsPath'])) {
+        $serendipity['permalinkCommentsPath'] = 'comments';
+    }
+
     /* URI paths
      * These could be defined in the language headers, except that would break
      * backwards URL compatibility
@@ -234,6 +243,7 @@ function serendipity_initPermalinks() {
     @define('PATH_PLUGIN',      $serendipity['permalinkPluginPath']);
     @define('PATH_ADMIN',       $serendipity['permalinkAdminPath']);
     @define('PATH_SEARCH',      $serendipity['permalinkSearchPath']);
+    @define('PATH_COMMENTS',    $serendipity['permalinkCommentsPath']);
 
     /* URI patterns
      * Note that it's important to use @ as the pattern delimiter. DO NOT use shortcuts
@@ -241,10 +251,11 @@ function serendipity_initPermalinks() {
      * If you add new patterns, remember to add the new rules to the *.tpl files and
      * function serendipity_installFiles().
      */
-    @define('PAT_FILENAME',   '0-9a-z\.\_!;,\+\-');
-    @define('PAT_CSS',        '@/(serendipity\.css|serendipity_admin\.css)@');
-    @define('PAT_FEED',       '@/(index|atom[0-9]*|rss|b2rss|b2rdf).(rss|rdf|rss2|xml)@');
-    @define('PAT_COMMENTSUB', '@/([0-9]+)[_\-][' . PAT_FILENAME . ']*\.html@i');
+    @define('PAT_FILENAME',       '0-9a-z\.\_!;,\+\-\%');
+    @define('PAT_FILENAME_MATCH', '[' . PAT_FILENAME . ']+');
+    @define('PAT_CSS',            '@/(serendipity\.css|serendipity_admin\.css)@');
+    @define('PAT_FEED',           '@/(index|atom[0-9]*|rss|b2rss|b2rdf).(rss|rdf|rss2|xml)@');
+    @define('PAT_COMMENTSUB',     '@/([0-9]+)[_\-][' . PAT_FILENAME . ']*\.html@i');
 
     return true;
 }
@@ -271,6 +282,9 @@ function &serendipity_permalinkPatterns($return = false) {
     $PAT['CATEGORIES']               = '@/'  . $serendipity['permalinkCategoriesPath'].'/([0-9;]+)@';
     $PAT['PLUGIN']                   = '@/('  . $serendipity['permalinkPluginPath'] . '|plugin)/(.*)@';
     $PAT['SEARCH']                   = '@/'  . $serendipity['permalinkSearchPath'] . '/(.*)@';
+    $PAT['COMMENTS']                 = '@/'  . $serendipity['permalinkCommentsPath'] . '/(.*)@';
+    // PATCH FOR UPCOMING 1.2:
+    // $PAT['PERMALINK']             = '@('   . serendipity_makePermalinkRegex($serendipity['permalinkStructure'], 'entry') . ')/?@i';
     $PAT['PERMALINK']                = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkStructure'], 'entry') . '@i';
     $PAT['PERMALINK_CATEGORIES']     = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkCategoryStructure'], 'category') . '@i';
     $PAT['PERMALINK_FEEDCATEGORIES'] = '@'   . serendipity_makePermalinkRegex($serendipity['permalinkFeedCategoryStructure'], 'category') . '@i';
@@ -307,11 +321,15 @@ function serendipity_searchPermalink($struct, $url, $default, $type = 'entry') {
 
     if (stristr($struct, '%id%') === FALSE) {
         $url = preg_replace('@^(' . preg_quote($serendipity['serendipityHTTPPath'], '@') . '(' . preg_quote($serendipity['indexFile'], '@') . ')?\??(url=)?/?)([^&?]+).*@', '\4', $url);
-
         // If no entryid is submitted, we rely on a new DB call to fetch the permalink.
         $pq = "SELECT entry_id, data
                  FROM {$serendipity['dbPrefix']}permalinks
-                WHERE permalink = '" . serendipity_db_escape_string($url) . "'
+                WHERE (permalink = '" . serendipity_db_escape_string($url) . "'
+                       "
+                       // PATCH FOR 1.2:
+                       // . "OR permalink = '" . serendipity_db_escape_string($default) . "'"
+                       . "
+                      )
                   AND type      = '" . serendipity_db_escape_string($type) . "'
                   AND entry_id  > 0
                 LIMIT 1";
@@ -551,13 +569,13 @@ function serendipity_makePermalink($format, $data, $type = 'entry') {
  */
 function serendipity_makePermalinkRegex($format, $type = 'entry') {
     static $entryKeys           = array('%id%',     '%title%',              '%day%',      '%month%',    '%year%');
-    static $entryRegexValues    = array('([0-9]+)', '[0-9a-z\.\_!;,\+\-]+', '[0-9]{1,2}', '[0-9]{1,2}', '[0-9]{4}');
+    static $entryRegexValues    = array('([0-9]+)', PAT_FILENAME_MATCH, '[0-9]{1,2}', '[0-9]{1,2}', '[0-9]{4}');
 
     static $authorKeys          = array('%id%',     '%username%',           '%realname%',           '%email%');
-    static $authorRegexValues   = array('([0-9]+)', '[0-9a-z\.\_!;,\+\-]+', '[0-9a-z\.\_!;,\+\-]+', '[0-9a-z\.\_!;,\+\-]+');
+    static $authorRegexValues   = array('([0-9]+)', PAT_FILENAME_MATCH, PAT_FILENAME_MATCH, PAT_FILENAME_MATCH);
 
     static $categoryKeys        = array('%id%',     '%name%',               '%description%');
-    static $categoryRegexValues = array('([0-9;]+)', '[0-9a-z\.\_!;,\+\-]+', '[0-9a-z\.\_!;,\+\-]+');
+    static $categoryRegexValues = array('([0-9;]+)', PAT_FILENAME_MATCH, PAT_FILENAME_MATCH);
 
     switch($type) {
         case 'entry':
@@ -685,7 +703,7 @@ function serendipity_archiveDateUrl($range, $summary=false, $key='baseURL') {
  * @access public
  * @return string   the current URL
  */
-function serendipity_currentURL() {
+function serendipity_currentURL($strict = false) {
     global $serendipity;
 
     // All that URL getting humpty-dumpty is necessary to allow a user to change the template in the
@@ -697,7 +715,7 @@ function serendipity_currentURL() {
     if (!empty($uri['query'])) {
         $qst = '&amp;' . str_replace('&', '&amp;', $uri['query']);
     }
-    $uri['path'] = preg_replace('@^' . preg_quote($serendipity['serendipityHTTPPath']) . '@i', '', $uri['path']);
+    $uri['path'] = preg_replace('@^' . preg_quote($serendipity['serendipityHTTPPath']) . '@i', ($strict ? '/' : ''), $uri['path']);
     $uri['path'] = preg_replace('@^(&amp;)?' . preg_quote($serendipity['indexFile']) . '(&amp;)@i', '', $uri['path']);
     $url = $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'] . '?' . $uri['path'] . $qst;
     $url = str_replace(
@@ -707,7 +725,7 @@ function serendipity_currentURL() {
             "'",
             '<',
             '>',
-            '`',
+            '`'
         ),
 
         array(
@@ -720,6 +738,10 @@ function serendipity_currentURL() {
 
         $url); // Kill possible looped repitions and bad characters which could occur
 
+    if ($strict) {
+        $url = preg_replace('@(//+)@', '/', $url);
+    }
+
     return $url;
 }
 
