@@ -6,6 +6,11 @@ if (IN_serendipity !== true) {
     die ("Don't hack!");
 }
 
+if (defined('S9Y_FRAMEWORK_PLUGINS_ADMIN')) {
+    return;
+}
+@define('S9Y_FRAMEWORK_PLUGINS_ADMIN', true);
+
 /**
  * Returns the name of a usergroup.
  *
@@ -47,39 +52,101 @@ function serendipity_pluginListSort($x, $y) {
  * @param  boolean  Indicates if event plugins (TRUE) or sidebar plugins (FALSE) shall be shown
  * @return null
  */
-function show_plugins($event_only = false)
+function show_plugins($event_only = false, $sidebars = null)
 {
+    static $opts = array(
+                    'event'  => PLUGIN_ACTIVE,
+                    'eventh' => PLUGIN_INACTIVE
+    );
+
     global $serendipity;
-?>
-    <form action="?serendipity[adminModule]=plugins" method="post">
-        <?php echo serendipity_setFormToken(); ?>
-        <table border="0" cellpadding="5" cellspacing="0" width="100%">
-            <tr>
-                <td colspan="2">&nbsp;</td>
-                <td><strong><?php echo TITLE; ?></strong></td>
-                <td><strong><?php echo PERMISSIONS; ?></strong></td>
-<?php
+
+    $sql_filter = '';
+    if (is_array($sidebars)) {
+        foreach($sidebars AS $sidebar) {
+            $up = strtoupper($sidebar);
+            if ($sidebar == 'hide') {
+                $opts[$sidebar] = HIDDEN;
+            } elseif (defined('SIDEBAR_' . $up)) {
+                $opts[$sidebar] = constant('SIDEBAR_' . $up);
+            } elseif (defined($up)) {
+                $opts[$sidebar] = constant($up);
+            } else {
+                $opts[$sidebar] = $up;
+            }
+            $sql_filter .= "AND placement != '" . serendipity_db_escape_string($sidebar) . "' ";
+        }
+    }
+
     if (!$event_only) {
+        $sql   = "SELECT * from {$serendipity['dbPrefix']}plugins
+                   WHERE placement != 'event'
+                     AND placement != 'eventh'
+                         " . $sql_filter;
+        $invisible_plugins = serendipity_db_query($sql);
+        if (is_array($invisible_plugins)) {
+            $sidebars[]   = 'NONE';
+            $opts['NONE'] = NONE;
+        }
+    }
+
+    $eyecandy = !isset($serendipity['eyecandy']) || serendipity_db_bool($serendipity['eyecandy']);
+    if (!$eyecandy) {
+        echo '    <form action="?serendipity[adminModule]=plugins" method="post">';
+    } elseif (!$event_only) {
+        echo '<script type="text/javascript"> function templatePluginMoverInit() { ';
+        $is_first = true;
+        foreach($sidebars AS $sidebar) {
 ?>
-                <td colspan="3" align="center"><strong><?php echo PLACEMENT; ?></strong></td>
+    <?php echo ($is_first ? 'var ' : ''); ?> list = document.getElementById("<?php echo $sidebar; ?>_col");
+    DragDrop.makeListContainer(list, 'g1');
+    list.onDragOver = function() { this.style["border"] = "1px solid #4d759b"; };
+    list.onDragOut = function() { this.style["border"] = "none"; };
 <?php
+            $is_first = false;
+        }
+        echo ' } addLoadEvent(templatePluginMoverInit);</script>';
+        echo '    <form action="?serendipity[adminModule]=plugins" method="post" onsubmit="pluginMovergetSort(); return true">';
+        echo '        <input type="hidden" name="serendipity[pluginorder]" id="order" value="" />';
+
     } else {
+        echo '<script type="text/javascript">addLoadEvent(pluginMoverInitEvent);</script>';
+        echo '    <form action="?serendipity[adminModule]=plugins" method="post" onsubmit="pluginMovergetSortEvent(); return true">';
+        echo '        <input type="hidden" name="serendipity[pluginorder]" id="eventorder" value="" />';
+    }
+
+    echo serendipity_setFormToken();
 ?>
-                <td colspan="2">&nbsp;</dd>
-<?php } ?>
-            </tr>
+    <table class="pluginmanager" border="0" cellpadding="5" cellspacing="3" width="100%">
+        <tr>
 <?php
     $errors     = array();
 
     /* Block display the plugins per placement location. */
     if ($event_only) {
-        $plugin_placements = array('event');
+        $plugin_placements = array('event', 'eventh');
     } else {
-        $plugin_placements = array('left', 'right', 'hide');
+        $plugin_placements = $sidebars;
     }
 
+    $total = 0;
     foreach ($plugin_placements as $plugin_placement) {
-        $plugins = serendipity_plugin_api::enum_plugins($plugin_placement);
+        if (!$event_only && $plugin_placement == 'NONE') {
+            $is_invisible     = true;
+        } else {
+            $is_invisible     = false;
+        }
+        $ptitle = $opts[$plugin_placement];
+        $pid    = $plugin_placement;
+
+        echo '<td class="pluginmanager_side">';
+        echo '<div class="heading">' . $ptitle . '</div>';
+        echo '<ol id="' . $pid . '_col" class="pluginmanager_container">';
+        if ($is_invisible) {
+            $plugins = $invisible_plugins;
+        } else {
+            $plugins = serendipity_plugin_api::enum_plugins($plugin_placement);
+        }
 
         if (!is_array($plugins)) {
             continue;
@@ -87,8 +154,10 @@ function show_plugins($event_only = false)
 
         $sort_idx = 0;
         foreach ($plugins as $plugin_data) {
-            $plugin =& serendipity_plugin_api::load_plugin($plugin_data['name'], $plugin_data['authorid']);
-            $key    = urlencode($plugin_data['name']);
+            $total++;
+            $plugin  =& serendipity_plugin_api::load_plugin($plugin_data['name'], $plugin_data['authorid']);
+            $key     = urlencode($plugin_data['name']);
+            $css_key = 's9ycid' . str_replace('%', '-', $key);
             $is_plugin_owner    = ($plugin_data['authorid'] == $serendipity['authorid'] || serendipity_checkPermission('adminPluginsMaintainOthers'));
             $is_plugin_editable = ($is_plugin_owner || $plugin_data['authorid'] == '0');
 
@@ -116,10 +185,10 @@ function show_plugins($event_only = false)
             }
 
             if ($event_only) {
-                $place = '<input type="hidden" name="serendipity[placement][' . $plugin_data['name'] . ']" value="event" />';
+                $place = placement_box('serendipity[placement][' . $plugin_data['name'] . ']', $plugin_data['placement'], $is_plugin_editable, true, $opts);
                 $event_only_uri = '&amp;serendipity[event_plugin]=true';
             } else {
-                $place = placement_box('serendipity[placement][' . $plugin_data['name'] . ']', $plugin_data['placement'], $is_plugin_editable);
+                $place = placement_box('serendipity[placement][' . $plugin_data['name'] . ']', $plugin_data['placement'], $is_plugin_editable, false, $opts);
                 $event_only_uri = '';
             }
 
@@ -133,50 +202,50 @@ function show_plugins($event_only = false)
             if ($sort_idx == (count($plugins)-1)) {
                 $movedown = '&nbsp;';
             } else {
-                $movedown = ($moveup != '' ? '&nbsp;' : '') . '<a href="?' . serendipity_setFormToken('url') . '&amp;serendipity[adminModule]=plugins&amp;submit=move+down&serendipity[plugin_to_move]=' . $key . $event_only_uri . '" style="border: 0"><img src="' . serendipity_getTemplateFile('admin/img/downarrow.png') . '" height="16" width="16" alt="'. DOWN .'" border="0" /></a>';
+                $movedown = ($moveup != '' ? '&nbsp;' : '') . '<a href="?' . serendipity_setFormToken('url') . '&amp;serendipity[adminModule]=plugins&amp;submit=move+down&amp;serendipity[plugin_to_move]=' . $key . $event_only_uri . '" style="border: 0"><img src="' . serendipity_getTemplateFile('admin/img/downarrow.png') . '" height="16" width="16" alt="'. DOWN .'" border="0" /></a>';
             }
 ?>
-            <tr>
-                <td style="border-bottom: 1px solid #000000">
-                    <div>
-                    <?php if ($is_plugin_editable) { ?>
-                        <input type="checkbox" name="serendipity[plugin_to_remove][]" value="<?php echo $plugin_data['name']; ?>" />
-                    <?php } else { ?>
-                        &nbsp;
-                    <?php } ?>
-                    </div>
-                </td>
-                <td style="border-bottom: 1px solid #000000" width="16">
-                <?php if ( $can_configure ) { ?>
-                    <a href="?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=<?php echo $key ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/configure.png') ?>" style="border: 0; vertical-align: bottom;"></a>
-                <?php } else { ?>
-                    &nbsp;
+            <li class="pluginmanager_item_<?php echo ($sort_idx % 2 ? 'even' : 'uneven'); ?>" id="<?php echo $css_key; ?>">
+                <div id="g<?php echo $css_key; ?>" class="pluginmanager_grablet">
+                    <a href="#" id="grab<?php echo $css_key; ?>"></a>
+                </div>
+                <?php if ($is_plugin_editable) { ?>
+                    <input type="checkbox" name="serendipity[plugin_to_remove][]" value="<?php echo $plugin_data['name']; ?>" />
                 <?php } ?>
-                </td>
-                <td style="border-bottom: 1px solid #000000"><strong>
+
+                <?php if ( $can_configure ) { ?>
+                    <a class="pluginmanager_configure" href="?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=<?php echo $key ?>"><img src="<?php echo serendipity_getTemplateFile('admin/img/configure.png') ?>" style="border: 0; vertical-align: bottom;" alt="[C]" /></a>
+                <?php } ?>
+
+                    <span class="pluginmanager_title">
                 <?php if ( $can_configure ) { ?>
                     <a href="?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=<?php echo $key ?>"><?php echo $title; ?></a>
                 <?php } else { ?>
                     <?php echo $title; ?>
-                <?php } ?></strong><br />
-                    <div style="font-size: 8pt"><?php echo $desc; ?></div>
-                </td>
-                <td style="border-bottom: 1px solid #000000" nowrap="nowrap"><?php ownership($plugin_data['authorid'], $plugin_data['name'], $is_plugin_owner); ?></td>
-            <?php if ( !$event_only ) { ?>
-                <td style="border-bottom: 1px solid #000000" nowrap="nowrap"><?php echo $place ?></td>
-            <?php } ?>
-                <td style="border-bottom: 1px solid #000000"><?php echo $moveup ?></td>
-                <td style="border-bottom: 1px solid #000000"><?php echo $movedown ?></td>
-            </tr>
+                <?php } ?></span><br />
+                    <div class="pluginmanager_description" style="font-size: 8pt"><?php echo $desc; ?></div>
+                    <div class="pluginmanager_ownership"><?php ownership($plugin_data['authorid'], $plugin_data['name'], $is_plugin_owner); ?></div>
+                    <?php echo ($eyecandy ? '<noscript>' : ''); ?>
+                    <div class="pluginmanager_place"><?php echo $place; ?></div>
+                    <div class="pluginmanager_move"><?php echo $moveup ?> <?php echo $movedown ?></div>
+                    <?php echo ($eyecandy ? '</noscript>' : ''); ?>
+            </li>
 <?php
             $sort_idx++;
         }
+
+        echo '</ol></td>';
     }
+
 ?>
+        </tr>
+        <tr>
+            <td colspan="3" align="right"><?php printf(PLUGIN_AVAILABLE_COUNT, $total); ?></td>
+        </tr>
         </table>
         <br />
         <div>
-            <input type="submit" name="REMOVE" title="<?php echo REMOVE_TICKED_PLUGINS; ?>"  value="<?php echo DELETE; ?>" class="serendipityPrettyButton" />
+            <input type="submit" name="REMOVE" title="<?php echo DELETE; ?>"  value="<?php echo REMOVE_TICKED_PLUGINS; ?>" class="serendipityPrettyButton" />
             <input type="submit" name="SAVE"   title="<?php echo SAVE_CHANGES_TO_LAYOUT; ?>" value="<?php echo SAVE; ?>" class="serendipityPrettyButton" />
         </div>
 </form>
@@ -237,18 +306,32 @@ function ownership($authorid, $name, $is_plugin_owner = false) {
  * @param  string   plugin name
  * @param  string   current position of the plugin
  * @param  boolean  Toggle whether a plugin is editable (depends on authorid and permissions)
+ * @param  boolean  Toggle whether a plugin is an event plugin
  * @return string   HTML code for placement select box
  */
-function placement_box($name, $val, $is_plugin_editable = false)
+function placement_box($name, $val, $is_plugin_editable = false, $is_event = false, $opts = null)
 {
-    static $opts = array(
-                    'left'  => LEFT,
-                    'right' => RIGHT,
-                    'hide'  => HIDDEN
+    if ($opts === null) {
+        $opts = array(
+            'left'  => LEFT,
+            'right' => RIGHT,
+            'hide'  => HIDDEN
         );
+    }
+
+    static $event_opts = array(
+                    'event'     => PLUGIN_ACTIVE,
+                    'eventh' => PLUGIN_INACTIVE,
+    );
+
+    if ($is_event) {
+        $gopts =& $event_opts;
+    } else {
+        $gopts =& $opts;
+    }
 
     $x = "\n<select name=\"$name\">\n";
-    foreach ($opts as $k => $v) {
+    foreach ($gopts as $k => $v) {
         if (!$is_plugin_editable && $k == 'hide') {
             continue;
         }
@@ -495,6 +578,13 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
                 ?><tr><td colspan="2"><?php echo $cbag->get('default'); ?></td></tr><?php
                 break;
 
+            case 'custom':
+                ?><tr><td colspan="2">
+                    <input type="hidden" id="config_<?php echo $postKey; ?>_<?php echo $config_item; ?>" name="serendipity[<?php echo $postKey; ?>][<?php echo $config_item; ?>]" value="<?php echo $hvalue; ?>" size="30" />
+                    <?php echo $cbag->get('custom'); ?>
+                  </td></tr><?php
+                break;
+
             case 'hidden':
                 ?><tr><td colspan="2"><input class="direction_<?php echo $lang_direction; ?>" type="hidden" name="serendipity[<?php echo $postKey; ?>][<?php echo $config_item; ?>]" value="<?php echo $cbag->get('value'); ?>" /></td></tr><?php
                 break;
