@@ -1,4 +1,4 @@
-<?php # $Id: config_local.inc.php 778 2005-12-14 14:32:28Z garvinhicking $
+<?php # $Id: config_local.inc.php 1409 2006-08-23 13:51:56Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -62,7 +62,14 @@
                                           'type'        => 'bool',
                                           'default'     => false,
                                           'permission'  => 'siteConfiguration',
-                                          'flags'       => array('nosave'))
+                                          'flags'       => array('nosave')),
+
+                                    array('var'         => 'dbNames',
+                                          'title'       => INSTAL_DB_UTF8,
+                                          'description' => INSTAL_DB_UTF8_DESC,
+                                          'type'        => 'bool',
+                                          'default'     => true,
+                                          'permission'  => 'siteConfiguration')
                                 ));
 
     $res['paths'] =
@@ -258,6 +265,14 @@
                                           'permission'  => 'siteConfiguration',
                                           'flags'       => array('ifEmpty')),
 
+                                    array('var'         => 'permalinkCommentsPath',
+                                          'title'       => INSTALL_PERMALINK_COMMENTSPATH,
+                                          'description' => '',
+                                          'type'        => 'string',
+                                          'default'     => 'comments',
+                                          'permission'  => 'siteConfiguration',
+                                          'flags'       => array('ifEmpty')),
+
                     )
             );
 
@@ -362,6 +377,13 @@
                                           'type'        => 'bool',
                                           'default'     => false,
                                           'permission'  => 'blogConfiguration'),
+
+                                    array('var'         => 'enablePluginACL',
+                                          'title'       => PERMISSION_FORBIDDEN_ENABLE,
+                                          'description' => PERMISSION_FORBIDDEN_ENABLE_DESC,
+                                          'type'        => 'bool',
+                                          'default'     => false,
+                                          'permission'  => 'blogConfiguration'),
                             ));
 
     $res['display'] =
@@ -374,6 +396,20 @@
                                           'default'     => 15,
                                           'permission'  => 'blogConfiguration'),
 
+                                    array('var'         => 'RSSfetchLimit',
+                                          'title'       => INSTALL_RSSFETCHLIMIT,
+                                          'description' => INSTALL_RSSFETCHLIMIT_DESC,
+                                          'type'        => 'int',
+                                          'default'     => 15,
+                                          'permission'  => 'blogConfiguration'),
+
+                                    array('var'         => 'enforce_RFC2616',
+                                          'title'       => SYNDICATION_RFC2616,
+                                          'description' => SYNDICATION_RFC2616_DESC,
+                                          'type'        => 'bool',
+                                          'default'     => false,
+                                          'permission'  => 'blogConfiguration'),
+
                                     array('var'         => 'useGzip',
                                           'title'       => INSTALL_USEGZIP,
                                           'description' => INSTALL_USEGZIP_DESC,
@@ -389,13 +425,6 @@
                                           'permission'  => 'blogConfiguration',
                                           'flags'       => array('simpleInstall', 'installOnly')),
 
-                                    array('var'         => 'XHTML11',
-                                          'title'       => INSTALL_XHTML11,
-                                          'description' => INSTALL_XHTML11_DESC,
-                                          'type'        => 'bool',
-                                          'permission'  => 'siteConfiguration',
-                                          'default'     => true),
-
                                     array('var'         => 'enablePopup',
                                           'title'       => INSTALL_POPUP,
                                           'description' => INSTALL_POPUP_DESC,
@@ -492,6 +521,62 @@
                                           'type'        => 'int',
                                           'permission'  => 'siteConfiguration',
                                           'default'     => 110),
+
+                                    array('var'         => 'maxFileSize',
+                                          'title'       => MEDIA_UPLOAD_SIZE,
+                                          'description' => MEDIA_UPLOAD_SIZE_DESC,
+                                          'type'        => 'int',
+                                          'permission'  => 'blogConfiguration',
+                                          'default'     => ''),
+
+                                    array('var'         => 'maxImgWidth',
+                                          'title'       => MEDIA_UPLOAD_MAXWIDTH,
+                                          'description' => MEDIA_UPLOAD_MAXWIDTH_DESC,
+                                          'type'        => 'int',
+                                          'permission'  => 'blogConfiguration',
+                                          'default'     => ''),
+
+                                    array('var'         => 'maxImgHeight',
+                                          'title'       => MEDIA_UPLOAD_MAXHEIGHT,
+                                          'description' => MEDIA_UPLOAD_MAXHEIGHT_DESC,
+                                          'type'        => 'int',
+                                          'permission'  => 'blogConfiguration',
+                                          'default'     => ''),
+
+                                    array('var'         => 'onTheFlySynch',
+                                          'title'       => ONTHEFLYSYNCH,
+                                          'description' => ONTHEFLYSYNCH_DESC,
+                                          'type'        => 'bool',
+                                          'permission'  => 'siteConfiguration',
+                                          'default'     => true),
+
+                                    array('var'         => 'dynamicResize',
+                                          'title'       => MEDIA_DYN_RESIZE,
+                                          'description' => MEDIA_DYN_RESIZE_DESC,
+                                          'type'        => 'bool',
+                                          'permission'  => 'siteConfiguration',
+                                          'default'     => false),
+
+                                    array('var'         => 'mediaExif',
+                                          'title'       => MEDIA_EXIF,
+                                          'description' => MEDIA_EXIF_DESC,
+                                          'type'        => 'bool',
+                                          'permission'  => 'siteConfiguration',
+                                          'default'     => true),
+
+                                    array('var'         => 'mediaProperties',
+                                          'title'       => MEDIA_PROP,
+                                          'description' => MEDIA_PROP_DESC . MEDIA_PROP_MULTIDESC,
+                                          'type'        => 'string',
+                                          'permission'  => 'blogConfiguration',
+                                          'default'     => 'DPI:IMAGE;RUN_LENGTH:VIDEO:AUDIO;DATE;COPYRIGHT;TITLE;COMMENT1:MULTI;COMMENT2:MULTI'),
+
+                                    array('var'         => 'mediaKeywords',
+                                          'title'       => MEDIA_KEYWORDS,
+                                          'description' => MEDIA_KEYWORDS_DESC,
+                                          'type'        => 'textarea',
+                                          'permission'  => 'blogConfiguration',
+                                          'default'     => ''),
                             ));
 
     return $res;
