@@ -1,4 +1,4 @@
-<?php # $Id: index.php 1500 2006-11-14 09:22:36Z garvinhicking $
+<?php # $Id: index.php 1519 2006-11-28 14:48:59Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -20,12 +20,22 @@ header('HTTP/1.0 200');
 
 // Session are needed to also remember an autologin user on the frontend
 ob_start();
-include_once('serendipity_config.inc.php');
+include('serendipity_config.inc.php');
 header('Content-Type: text/html; charset='. LANG_CHARSET);
+
 if ($serendipity['expose_s9y']) {
     header('X-Blog: Serendipity'); // Used for installer detection
 }
-    
+
+if ($serendipity['CacheControl']) {
+    if (!empty($HTTP_SERVER_VARS['SERVER_SOFTWARE']) && strstr($HTTP_SERVER_VARS['SERVER_SOFTWARE'], 'Apache/2')) {
+        header('Cache-Control: no-cache, pre-check=0, post-check=0');
+    } else {
+        header('Cache-Control: private, pre-check=0, post-check=0, max-age=0');
+    }
+    header('Expires: 0');
+    header('Pragma: no-cache');
+}
 $track_referer = true;
 $uri = $_SERVER['REQUEST_URI'];
 
@@ -96,6 +106,9 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 $serendipity['GET']['category'] = $cat;
                 unset($_args[$k]);
             }
+        } elseif ($v{0} == 'A') { /* Author */
+            $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)substr($v, 1);
+            unset($_args[$k]);
         } elseif ($v{0} == 'W') { /* Week */
             $week = substr($v, 1);
             if (is_numeric($week)) {
@@ -154,7 +167,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
             }
             break;
 
-        case 'jalali-utf8':
+        case 'persian-utf8':
             require_once S9Y_INCLUDE_PATH . 'include/functions_calendars.inc.php';
             $gday = 1;
             if ($week) {
@@ -175,26 +188,26 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                     }
                 }
 
-                $tm = jalali_mktime(0, 0, 0, $i, $day, $year);
-                $ts = jalali_mktime(0, 0, 0, jalali_date_utf('m', $tm), jalali_date_utf('j', $tm), $year);
-                $te = jalali_mktime(23, 59, 59, jalali_date_utf('m', $tm), jalali_date_utf('j', $tm)+7, $year);
+                $tm = persian_mktime(0, 0, 0, $i, $day, $year);
+                $ts = persian_mktime(0, 0, 0, persian_date_utf('m', $tm), persian_date_utf('j', $tm), $year);
+                $te = persian_mktime(23, 59, 59, persian_date_utf('m', $tm), persian_date_utf('j', $tm)+7, $year);
                 $date = serendipity_formatTime(WEEK .' '. $week .'، %Y', $ts, false);
             } else {
                 if ($day) {
-                    $ts = jalali_mktime(0, 0, 0, $month, $day, $year);
-                    $te = jalali_mktime(23, 59, 59, $month, $day, $year);
+                    $ts = persian_mktime(0, 0, 0, $month, $day, $year);
+                    $te = persian_mktime(23, 59, 59, $month, $day, $year);
                     $date = serendipity_formatTime(DATE_FORMAT_ENTRY, $ts, false);
                 } else {
-                    $ts = jalali_mktime(0, 0, 0, $month, $gday, $year);
+                    $ts = persian_mktime(0, 0, 0, $month, $gday, $year);
                     if (!isset($gday2)) {
-                        $gday2 = jalali_date_utf('t', $ts);
+                        $gday2 = persian_date_utf('t', $ts);
                     }
-                    $te = jalali_mktime(23, 59, 59, $month, $gday2, $year);
+                    $te = persian_mktime(23, 59, 59, $month, $gday2, $year);
                     $date = serendipity_formatTime('%B %Y', $ts, false);
                 }
             }
 
-            list($year, $month, $day) = j2g ($year, $month, $day);
+            list($year, $month, $day) = p2g ($year, $month, $day);
             break;
     }
 
@@ -209,7 +222,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     }
 
     ob_start();
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
     $data = ob_get_contents();
     ob_end_clean();
 
@@ -223,6 +236,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
 } else if ( preg_match(PAT_COMMENTSUB, $uri, $matches) ||
             preg_match(PAT_PERMALINK, $uri, $matches) ) {
     $serendipity['view'] = 'entry';
+
     $matches[1] = serendipity_searchPermalink($serendipity['permalinkStructure'], $uri, $matches[1], 'entry');
     serendipity_rememberComment();
 
@@ -235,7 +249,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
         $comment['parent_id'] = $serendipity['POST']['replyTo'];
         if (!empty($comment['comment'])) {
             if (serendipity_saveComment($serendipity['POST']['entry_id'], $comment, 'NORMAL')) {
-                $sc_url = $_SERVER['REQUEST_URI'] . (strstr($_SERVER['REQUEST_URI'], '?') ? '&' : '?') . 'serendipity[csuccess]=' . (isset($serendipity['csuccess']) ? $serendipity['csuccess'] : 'true');
+                $sc_url = ($_SERVER['HTTPS'] == 'on' ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] . (strstr($_SERVER['REQUEST_URI'], '?') ? '&' : '?') . 'serendipity[csuccess]=' . (isset($serendipity['csuccess']) ? $serendipity['csuccess'] : 'true');
                 if (serendipity_isResponseClean($sc_url)) {
                     header('Location: ' . $sc_url);
                 }
@@ -256,14 +270,14 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $_GET['serendipity']['action'] = 'read';
     $_GET['serendipity']['id']     = $id;
 
-    $title = serendipity_db_query("SELECT title FROM {$serendipity['dbPrefix']}entries WHERE id=$id AND isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . time() : ''), true);
+    $title = serendipity_db_query("SELECT title FROM {$serendipity['dbPrefix']}entries WHERE id=$id AND isdraft = 'false' " . (!serendipity_db_bool($serendipity['showFutureEntries']) ? " AND timestamp <= " . serendipity_db_time() : ''), true);
     if (is_array($title)) {
         $serendipity['head_title']    = htmlspecialchars($title[0]);
         $serendipity['head_subtitle'] = htmlspecialchars($serendipity['blogTitle']);
     }
 
     ob_start();
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
     $data = ob_get_contents();
     ob_end_clean();
 
@@ -277,7 +291,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $serendipity['view'] = 'feed';
     header('Content-Type: text/html; charset=utf-8');
 
-    if (preg_match('@/(index|atom[0-9]*|rss|comments|opml)\.(rss[0-9]?|rdf|rss|xml|atom)@', $uri, $vmatches)) {
+    if (preg_match('@/(index|atom[0-9]*|rss|comments|trackbacks|comments_and_trackbacks|opml)\.(rss[0-9]?|rdf|rss|xml|atom)@', $uri, $vmatches)) {
         list($_GET['version'], $_GET['type']) = serendipity_discover_rss($vmatches[1], $vmatches[2]);
     }
 
@@ -298,7 +312,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     }
 
     ob_start();
-    include_once(S9Y_INCLUDE_PATH . 'rss.php');
+    include(S9Y_INCLUDE_PATH . 'rss.php');
     $data = ob_get_contents();
     ob_end_clean();
 
@@ -321,7 +335,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     header("Location: {$base}serendipity_admin.php");
     exit;
 } else if (preg_match(PAT_ARCHIVE, $uri)) {
-    $serendipity['view'] = 'archives';
+    $serendipity['view'] = 'archive';
     $serendipity['GET']['action'] = 'archives';
     $_args = $serendipity['uriArguments'];
     /* Attempt to locate hidden variables within the URI */
@@ -336,10 +350,13 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 $serendipity['GET']['category'] = $cat;
                 unset($_args[$k]);
             }
+        } elseif ($v{0} == 'A') { /* Author */
+            $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)substr($v, 1);
+            unset($_args[$k]);
         }
     }
 
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else if (preg_match(PAT_PLUGIN, $uri, $matches)) {
     $serendipity['view'] = 'plugin';
     serendipity_plugin_api::hook_event('external_plugin', $matches[2]);
@@ -374,6 +391,9 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
                 unset($_args[$k]);
                 unset($serendipity['uriArguments'][$k]);
             }
+        } elseif ($v{0} == 'A') { /* Author */
+            $serendipity['GET']['viewAuthor'] = $_GET['viewAuthor'] = (int)substr($v, 1);
+            unset($_args[$k]);
         }
     }
 
@@ -386,7 +406,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $serendipity['head_title']    = $cInfo['category_name'];
     $serendipity['head_subtitle'] = $serendipity['blogTitle'];
 
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else if ($is_multiauth || preg_match(PAT_PERMALINK_AUTHORS, $uri, $matches)) {
     $serendipity['view'] = 'authors';
 
@@ -425,7 +445,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     $serendipity['head_title']    = sprintf(ENTRIES_BY, $uInfo[0]['realname']);
     $serendipity['head_subtitle'] = $serendipity['blogTitle'];
 
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else if (preg_match(PAT_SEARCH, $uri, $matches)) {
     $serendipity['view'] = 'search';
     $_args = $serendipity['uriArguments'];
@@ -451,12 +471,69 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
 
     $serendipity['GET']['action']     = 'search';
     $serendipity['GET']['searchTerm'] = urldecode(htmlspecialchars(strip_tags(implode(' ', $search))));
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } elseif (preg_match(PAT_CSS, $uri, $matches)) {
     $serendipity['view'] = 'css';
     $css_mode = $matches[1];
-    include_once(S9Y_INCLUDE_PATH . 'serendipity.css.php');
+    include(S9Y_INCLUDE_PATH . 'serendipity.css.php');
     exit;
+} else if (preg_match(PAT_COMMENTS, $uri, $matches)) {
+    $serendipity['view'] = 'comments';
+    $_args = serendipity_getUriArguments($uri, true); // Need to also match "." character
+    $timedesc = array();
+
+    /* Attempt to locate hidden variables within the URI */
+    $search = array();
+    foreach ($_args as $k => $v){
+        if ($v == PATH_COMMENTS) {
+            continue;
+        }
+
+        if ($v{0} == 'P') { /* Page */
+            $page = substr($v, 1);
+            if (is_numeric($page)) {
+                $serendipity['GET']['page'] = $page;
+                unset($_args[$k]);
+                unset($serendipity['uriArguments'][$k]);
+            }
+        } elseif (preg_match('@^(last|f|t|from|to)[\s_-]*([\d-/ ]+)$@', strtolower(urldecode($v)), $m)) {
+            if ($m[1] == 'last') {
+                $usetime = time() - ($m[2]*86400);
+                $serendipity['GET']['commentStartTime'] = $usetime;
+                $timedesc['start'] = serendipity_strftime(DATE_FORMAT_SHORT, $usetime);
+                continue;
+            }
+
+            $date = strtotime($m[2]);
+            if ($date < 1) {
+                continue;
+            }
+
+            if ($m[1] == 'f' || $m[1] == 'from') {
+                $serendipity['GET']['commentStartTime'] = $date;
+                $timedesc['start'] = serendipity_strftime(DATE_FORMAT_SHORT, $date);
+            } else {
+                $serendipity['GET']['commentEndTime'] = $date;
+                $timedesc['end'] = serendipity_strftime(DATE_FORMAT_SHORT, $date);
+            }
+        } elseif ($v == 'trackbacks' || $v == 'comments_and_trackbacks' || $v == 'comments') {
+            $serendipity['GET']['commentMode'] = $v;
+        } elseif (!empty($v)) {
+            $serendipity['GET']['viewCommentAuthor'] .= urldecode($v);
+        }
+    }
+
+    $serendipity['head_title']    = COMMENTS_FROM . ' ' . htmlspecialchars($serendipity['GET']['viewCommentAuthor']);
+    if (isset($timedesc['start']) && isset($timedesc['end'])) {
+        $serendipity['head_title'] .= ' (' . $timedesc['start'] . ' - ' . $timedesc['end'] . ')';
+    } elseif (isset($timedesc['start'])) {
+        $serendipity['head_title'] .= ' (&gt; ' . $timedesc['start'] . ')';
+    } elseif (isset($timedesc['end'])) {
+        $serendipity['head_title'] .= ' (&lt; ' . $timedesc['end'] . ')';
+    }
+    $serendipity['head_subtitle'] = $serendipity['blogTitle'];
+    $serendipity['GET']['action']     = 'comments';
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else if (preg_match('@/(index(\.php|\.html)?)|'. preg_quote($serendipity['indexFile']) .'@', $uri) ||
            preg_match('@^/' . preg_quote(trim($serendipity['serendipityHTTPPath'], '/')) . '/?(\?.*)?$@', $uri)) {
 
@@ -469,12 +546,11 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
         $serendipity['uriArguments'][] = PATH_ARCHIVES;
     }
 
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
 } else {
     $serendipity['view'] = '404';
-
     header('HTTP/1.0 404 Not found');
-    include_once(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
+    include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
     // printf('<div class="serendipity_msg_important">' . DOCUMENT_NOT_FOUND . '</div>', $uri);
 }
 
@@ -485,7 +561,7 @@ if ($track_referer) {
 if (!defined('NO_EXIT')) {
     $raw_data = ob_get_contents();
     ob_end_clean();
-    $serendipity['smarty']->assign('raw_data', $raw_data);
+    $serendipity['smarty']->assign_by_ref('raw_data', $raw_data);
     if (empty($serendipity['smarty_file'])) {
         $serendipity['smarty_file'] = '404.tpl';
     }
