@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_es.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_es.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Luis Cervantes <LuisCervantes@ono.com>,
@@ -10,12 +10,19 @@
 
 @define('LANG_CHARSET', 'UTF-8');
 @define('SQL_CHARSET', 'utf8');
-@define('DATE_LOCALES', 'es_ES.ISO_8859-15, es_ES.UTF8, es_ES.ISO_8859-1, es_ES.ISO8859-1, spanish, sp, es, es_ES, es-ES');
+@define('DATE_LOCALES', 'es_ES.UTF8, es_ES.ISO8859-1, spanish, sp, es, es_ES, es-ES, es_ES.ISO_8859-15, es_ES.ISO_8859-1');
 @define('DATE_FORMAT_ENTRY', '%A, %e de %B del %Y');
 @define('DATE_FORMAT_SHORT', '%d.%m.%Y %H:%M');
 @define('WYSIWYG_LANG', 'es-utf');
 @define('LANG_DIRECTION', 'ltr');
 
+/* rlazo[20061114]: dado que el español tiene varias traducciones para ciertas
+ * palabras sería bueno mantener una misma traducción para ciertas
+ * palabras comunes (tratando de seguir http://es.tldp.org/ORCA/glosario.html):
+ *
+ * password -> contraseña
+ * file -> fichero¿? (se podría utilizar archivo para referirse a las entradas pasadas)
+ */
 @define('SERENDIPITY_ADMIN_SUITE', 'Suite de Administración de Serendipity');
 @define('HAVE_TO_BE_LOGGED_ON', 'Debes identificarte para ver esta página');
 @define('APPEARANCE', 'Apariencia');
@@ -216,7 +223,7 @@
 @define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Altura de la imagen');
 @define('SYNDICATION_PLUGIN_WEBMASTER_DESC', 'Correo electrónico del webmaster, si está disponible. (déjalo vacío para no mostrarlo) [RSS 2.0]');
 @define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Correo electrónico del editor, si está disponible. (déjalo vacío para no mostrarlo) [RSS 2.0]');
-@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de una imagen en formato GIF/JPEG/PNG, si está disponible. (dejándolo vacío se usara el logo de Serendipity)');
+@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de una imagen en formato GIF/JPEG/PNG, si está disponible. (dejándolo vacío se usara el símbolo de Serendipity)');
 @define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'en pixels, max. 144');
 @define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'en pixels, max. 400');
 @define('SYNDICATION_PLUGIN_TTL', 'Campo "ttl" (time-to-live)');
@@ -515,7 +522,7 @@
 @define('COMMENTS_FILTER_ALL', 'Todo');
 @define('COMMENTS_FILTER_APPROVED_ONLY', 'Sólo lo aprobado');
 @define('COMMENTS_FILTER_NEED_APPROVAL', 'Pendiente de aprobación');
-@define('RSS_IMPORT_BODYONLY', 'Pon todo el texto importado en el "cuerpo" y no lo separes en la sección "entrada extendida".');
+@define('RSS_IMPORT_BODYONLY', 'Coloca todo el texto importado en el "cuerpo" y no lo separes en la sección "entrada extendida".');
 @define('SYNDICATION_PLUGIN_FULLFEED', 'Mostrar los artículos completos con la entrada extendida dentro del feed RSS');
 @define('MT_DATA_FILE', 'fichero de datos de Movable Type');
 @define('FORCE', 'Forzar');
@@ -560,7 +567,7 @@
 @define('IMPORT_DONE', 'Importación completada con éxito');
 @define('IMPORT_WEBLOG_APP', 'Aplicación weblog');
 @define('EXPORT_FEED', 'Exportar la sindicación RSS completa');
-@define('STATUS', 'Estatus después de importar');
+@define('STATUS', 'Estado después de importar');
 @define('IMPORT_GENERIC_RSS', 'Importar RSS genérico');
 @define('ACTIVATE_AUTODISCOVERY', 'Enviar referencias a los enlaces encontrados en la entrada');
 @define('WELCOME_TO_ADMIN', 'Bienvenido a la Suite de Administración de Serendipity.');
@@ -666,7 +673,7 @@
 @define('USERCONF_REALNAME_DESC', 'El nombre completo del autor. Este es el nombre que verán los lectores.');
 @define('HOTLINK_DONE', 'Fichero como recurso externo enlazado.<br />Hecho.');
 @define('ENTER_MEDIA_URL_METHOD', 'Método de obtención:');
-@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imágenes externas sin almacernalas localmente. Si escoges esto, asegúrate de que tienes permiso para hacerlo en el servidor externo o bien el servidor es tuyo.');
+@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imágenes externas sin almacenarlas localmente. Si escoges esto, asegúrate de que tienes permiso para hacerlo en el servidor externo o bien el servidor es tuyo.');
 @define('MEDIA_HOTLINKED', 'enlazado externamente');
 @define('FETCH_METHOD_IMAGE', 'Descargar imagen a tu servidor');
 @define('FETCH_METHOD_HOTLINK', 'Enlazar externamente al servidor');
@@ -686,16 +693,16 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Estructura URL de los enlaces permanentes al autor');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aquí puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierto autor sean accesibles. Puedes utilizar las variables %id%, %realname%, %username%, %email% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Estructura URL de los enlaces permanentes a categorías');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aquí puedes definir la estrutura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categoría sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
-@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estructura URL de los enlaces permanentes al RSS-Feed de las categorías');
-@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aquí puedes definir la estrutura URL relativa desde la URL base hasta donde los RSS-feeds de ciertas categorías sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aquí puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categoría sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
+@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estructura URL de los enlaces permanentes a la sindicación RSS de las categorías');
+@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aquí puedes definir la estructura URL relativa desde la URL base hasta donde las sindicaciones RSS de ciertas categorías sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Ruta a los archivos');
 @define('INSTALL_PERMALINK_ARCHIVEPATH', 'Ruta para archivar');
 @define('INSTALL_PERMALINK_CATEGORIESPATH', 'Ruta a las categorías');
 @define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Ruta para desinscribirse de los comentarios'); //check later
 @define('INSTALL_PERMALINK_DELETEPATH', 'Ruta para eliminar comentarios');
 @define('INSTALL_PERMALINK_APPROVEPATH', 'Ruta para aprobar comentarios');
-@define('INSTALL_PERMALINK_FEEDSPATH', 'Ruta a los RSS Feeds');
+@define('INSTALL_PERMALINK_FEEDSPATH', 'Ruta a las sindicaciones RSS');
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Ruta a extensión');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Ruta a admin');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Ruta para buscar');
@@ -783,34 +790,34 @@
 @define('CHARSET_NATIVE', 'Nativo');
 @define('INSTALL_CHARSET', 'Selección del juego de caracteres');
 @define('INSTALL_CHARSET_DESC', 'Aquí puedes activar la codificación de caracteres UTF-8 o nativo (ISO, EUC, ...). Algunos lenguajes sólo tienen traducciones UTF-8 así que colocar la codificación en "nativo" no tendrá efectos. Se sugiere UTF-8 en nuevas instalaciones. No alteres la configuración si ya has hecho entradas con caracteres especiales ya que podría conllevar una corrupción de caracteres. Asegúrate de leer más sobre este problema en  http://www.s9y.org/index.php?node=46.');
-@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Habilitar API de conecciones de las extensiones');
-@define('CALENDAR_EXTEVENT_DESC', 'Si está habilitada, esta opción permite que las extensiones se conecten con el calendario para mostrar sus eventos resaltados. Utilizalo sólo si has instalado extensiones que lo necesitan, de otra forma sólo disminuye el desempeño.');
+@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Habilitar API de conexiones de las extensiones');
+@define('CALENDAR_EXTEVENT_DESC', 'Si está habilitada, esta opción permite que las extensiones se conecten con el calendario para mostrar sus eventos resaltados. Utilízalo sólo si has instalado extensiones que lo necesitan, de otra forma sólo disminuye el desempeño.');
 
 
 /*
 Melvin TODO [20060128]: Reorganize (perhaps) next constants in the order they belong
 Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 */
-@define('XMLRPC_NO_LONGER_BUNDLED', 'El API de la interface XML-RPC en Serendipity no está incluida debido a problemas de seguridad que hay en curso con este API, además del hecho que no es usada con mucha frecuencia. De esta forma, usted necesita instalar el plugin XML-RPC para utilizar API de XML-RPC. Las URL que usa en sus aplicaciones NO cambiarán y tan pronto como instale el plugin podrá usar el API.');
+@define('XMLRPC_NO_LONGER_BUNDLED', 'El API de la interfase XML-RPC en Serendipity no está incluido debido a problemas de seguridad que hay en curso con este API, además del hecho que no es usada con mucha frecuencia. De esta forma, usted necesita instalar la extensión XML-RPC para utilizar API de XML-RPC. Las URL que usa en sus aplicaciones NO cambiarán y tan pronto como instale la extensión podrá usar el API.');
 @define('PERM_READ', 'Permiso de lectura');
 @define('PERM_WRITE', 'Permiso de escritura');
 @define('PERM_DENIED', 'Permiso denegado.');
 @define('INSTALL_ACL', 'Aplicar permisos de lectura por categorías');
 @define('INSTALL_ACL_DESC', 'Cuando se activa, son aplicados los permisos para grupos de usuarios que estén configurados cuando los usuarios registrados vean el Blog. Cuando se desactiva, los permisos de lectura de las categorías NO son aplicadas, con el efecto positivo que el Blog carga un poco más rápido. Si no necesitas permisos de lectura para múltiples usuarios, deshabilita esta opción.');
-@define('PLUGIN_API_VALIDATE_ERROR', 'Sintaxis erronea en la configuración de la opción "%s". Se requiere contenido de tipo "%s".');
+@define('PLUGIN_API_VALIDATE_ERROR', 'Sintaxis errónea en la configuración de la opción "%s". Se requiere contenido de tipo "%s".');
 @define('USERCONF_CHECK_PASSWORD', 'Contraseña actual');
 @define('USERCONF_CHECK_PASSWORD_DESC', 'Si cambias la contraseña en el campo de arriba, debes escribir la contraseña actual en este campo.');
-@define('USERCONF_CHECK_PASSWORD_ERROR', 'No especificaste una clave actual correcta, por lo tanto no estas autorizado para establecer una nueva clave. Tus cambios no fueron guardados.');
-@define('ERROR_XSRF', 'To navegador no envió una cadena válida de HTTP-Referrer. Esto puede deberse a una mala configuración del navegador/proxy o por un "Cross Site Request Forgery (XSRF)" dirigido a ti. La acción solicitada no pudo ser completada.');
-@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Aquí puedes definir la estructura relativa de URLs comenzando por tu URL base hasta incluso los RSS-Feeds de usuarios específicos que puedan ser vistos. Puedes usar las variables %id%, %realname%, %username%, %email% y cualquier otro carácter.');
-@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Estructura de los Permalinks para los RSS-Feed de autores');
+@define('USERCONF_CHECK_PASSWORD_ERROR', 'No especificaste correctamente la contraseña actual, por lo tanto no estas autorizado para establecer una nueva. Tus cambios no fueron guardados.');
+@define('ERROR_XSRF', 'Tu navegador no envió una cadena válida de HTTP-Referrer. Esto puede deberse a una mala configuración del navegador/proxy o por un "Cross Site Request Forgery (XSRF)" dirigido a ti. La acción solicitada no pudo ser completada.');
+@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Aquí puedes definir la estructura relativa de URLs comenzando por tu URL base hasta incluso las sindicaciones RSS de usuarios específicos que puedan ser vistos. Puedes usar las variables %id%, %realname%, %username%, %email% y cualquier otro carácter.');
+@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Estructura de los Enlaces Permanentes para las sindicaciones RSS de autores');
 @define('INSTALL_PERMALINK_AUTHORSPATH', 'Ruta para los autores');
 @define('AUTHORS', 'Autores');
 @define('AUTHORS_ALLOW_SELECT', 'Permitir a los visitantes mostrar múltiples autores al mismo tiempo?');
-@define('AUTHORS_ALLOW_SELECT_DESC', 'Si esta opción es activada, un checkbox estará al lado de cada autor en en el plugin lateral. Los usuarios pueden seleccionar estas casillas para ver las entradas de acuerdo a su selección.');
+@define('AUTHORS_ALLOW_SELECT_DESC', 'Si esta opción es activada, un checkbox estará al lado de cada autor en en la extensión lateral. Los usuarios pueden seleccionar estas casillas para ver las entradas de acuerdo a su selección.');
 @define('AUTHOR_PLUGIN_DESC', 'Muestra una lista de autores');
 @define('CATEGORY_PLUGIN_TEMPLATE', 'Activar Smarty-Templates?');
-@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Si esta opción es activada, el plugin utiliza las características de Smarty-Templating para producir el contenido del listado de las categorías. Si activas esto, puedes cambiar el diseño a través del archivo "plugin_categories.tpl". Toma en cuenta que esta opción tendrá un impacto en el desempeño, si no necesitas diseños particulares, déjalo deshabilitado.');
+@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Si esta opción es activada, la extensión utiliza las características de Smarty-Templating para producir el contenido del listado de las categorías. Si activas esto, puedes cambiar el diseño a través del fichero "plugin_categories.tpl". Toma en cuenta que esta opción tendrá un impacto en el desempeño, si no necesitas diseños particulares, déjalo deshabilitado.');
 @define('CATEGORY_PLUGIN_SHOWCOUNT', 'Mostrar número de entradas por categoría?');
 @define('AUTHORS_SHOW_ARTICLE_COUNT', 'Mostrar número de artículos del autor?');
 @define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Si esta opción es activada, el número de artículos del autor se muestra al lado del nombre del autor en paréntesis.');
@@ -821,3 +828,80 @@ Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 @define('CATEGORIES_HIDE_PARENT', 'Ocular la categoría padre seleccionada?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'Si restringes el listado de categorías a una categoría especifica, por defecto verás la categoría padre (superior) dentro del listado generado. Si deshabilitas esta opción, el nombre de la categoría padre no será mostrado.');
 @define('WARNING_NO_GROUPS_SELECTED', 'Advertencia: No haz seleccionado ningún grupo de miembros. Esto efectivamente te dejaría fuera de la gerencia del grupo de usuarios, por lo tanto, tu membresía de grupo no fue cambiada.');
+@define('INSTALL_RSSFETCHLIMIT', 'Entradas a mostrar en las sindicaciones');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'Número de entradas a mostrar por cada página.');
+@define('INSTAL_DB_UTF8', 'Activar conversión del juego de caracteres en la BD');
+@define('INSTAL_DB_UTF8_DESC', 'Envía una consulta MySQL "SET NAMES" para definir el juego de caracteres requerido por la base de datos. Actívalo o desactívalo sí ves caracteres extraños en tu blog.');
+@define('ONTHEFLYSYNCH', 'Activar sincronización de medios al-vuelo');
+@define('ONTHEFLYSYNCH_DESC', 'Si lo activas, Serendipity comparará la base de datos de medios con los archivos almacenados en tu servidor y sincronizará la base de datos con el contenido del directorio.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'No puedes dejar el nombre de usuario en blanco.');
+@define('FURTHER_LINKS', 'Más enlaces');
+@define('FURTHER_LINKS_S9Y', 'Página principal de Serendipity');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Documentación de Serendipity');
+@define('FURTHER_LINKS_S9Y_BLOG', 'Blog oficial');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'Foros');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(Comentario eliminado)');
+@define('CURRENT_AUTHOR', 'Autor actual');
+@define('WORD_NEW', 'Nuevo');
+@define('SHOW_MEDIA_TOOLBAR', '¿Mostrar la barra de herramientas dentro de la ventana emergente selección de medios?');
+@define('MEDIA_KEYWORDS', 'Palabras claves de medios');
+@define('MEDIA_KEYWORDS_DESC', 'Ingresa una lista palabras separadas por ";" que quisieras utilizar como palabras clave predefinidas para los elementos de medios.');
+@define('MEDIA_EXIF', 'Importar información de imágenes EXIF/JPEG');
+@define('MEDIA_EXIF_DESC', 'Si lo activas, la metadata de las imágenes EXIF/JPEG existentes será analizada y almacenada en la base de datos para ser mostrada en la galería de medios.');
+@define('MEDIA_PROP', 'Propiedades de Medios');
+@define('GO_ADD_PROPERTIES', 'Ir & ingresar propiedades');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', 'Comentario corto');
+@define('MEDIA_PROPERTY_COMMENT2', 'Comentario extendido');
+@define('MEDIA_PROPERTY_TITLE', 'Título');
+@define('MEDIA_PROP_DESC', 'Ingresa una lista de campos de propiedades separados por ";" que te gustaría definir por cada archivo de medios');
+@define('MEDIA_PROP_MULTIDESC', '(Puedes añadir al final de cualquier item ":MULTI" para indicar que contendrá una descripción larga en ves de sólo algunos caracteres)');
+@define('STYLE_OPTIONS_NONE', 'Este tema/estilo no tiene opciones específicas. Para ver como tu plantilla puede especificar opciones, lee la documentación técnica en www.s9y.org acerca de "Configuración de las opciones de los estilos".');
+@define('STYLE_OPTIONS', 'Opciones de Tema/estilo');
+@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d extensiones.');
+@define('SYNDICATION_RFC2616', 'Activar seguimiento estricto de la norma RFC2616 para sindicaciones RSS');
+@define('SYNDICATION_RFC2616_DESC', 'NO forzar el seguimiento de RFC2616 significa que todos los GETs condicionales a Serendipity regresarán entradas modificadas desde la fecha de la última solicitud. Con esa característica definida a "false", tus visitantes obtendrán todos los artículos desde su última solicitud, lo cual es considerado algo bueno. Sin embargo, algunos agentes como Planet tienen un comportamiento extraño, dado viola la norma RFC2616. De esta manera, si defines esta opción como "TRUE" estarás cumpliendo con la norma, pero los lectores de tus sindicaciones RSS quizás pierdan algunas entradas en sus días de ausencia. De cualquier forma, o evitas un funcionamiento adecuado de agregadores como Planet, o dañas a tus lectores reales. Si estás enfrentando quejas de cualquiera de los dos, puedes cambiar esta opción. Rerefencia: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('MEDIA_PROPERTY_DATE', 'Fecha Asociada');
+
+/*Translate*/
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
+/**/
+@define('FILENAME_REASSIGNED', 'Nombre asignado automágicamente al nuevo fichero: %s');
+@define('MEDIA_UPLOAD_SIZE', 'Tamaño máximo de los ficheros');//'upload' removed [rlazo]
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Ingresa el tamaño máximo en bytes de los ficheros que puedes subir al servidor. Esta opción puede ser sobreescrita por la configuración en el servidor en PHP.ini: upload_max_filesize, post_max_size, max_input_time, todas las anteriores tiene precedencia sobre esta opción. Si la dejas en blanco se usarán sólo los límites definidos en el servidor.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'Error: ¡No puedes subir ficheros de más de %s bytes!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Ancho máximo de las imágenes'); //'upload' removed [rlazo]
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Ingresa la anchura máxima de las imágenes que se pueden subir al servidor en pixels.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Altura máxima de las imágenes');//'upload' removed [rlazo]
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Ingresa la altura máxima de las imágenes que se pueden subir al servidor en pixels.');
+@define('MEDIA_UPLOAD_DIMERROR', 'Error: ¡No puedes subir imágenes de más de %s x %s pixels!');
+@define('MEDIA_TARGET', 'Objetivo de este enlace');
+@define('MEDIA_TARGET_JS', 'Ventana emergente (a través de JavaScript, tamaño adaptativo)');
+@define('MEDIA_ENTRY', 'Entrada aislada');
+@define('MEDIA_TARGET_BLANK', 'Ventana emergente (a través de target=_blank)');
+@define('MEDIA_DYN_RESIZE', '¿Permitir redimensionar dinámicamente las imágenes?');
+@define('MEDIA_DYN_RESIZE_DESC', 'Si lo activas, el selector de medios puede regresar imágenes en cualquier tamaño solicitado a través de una variable GET. Los resultados se colocan en la caché, de esta manera puedes crear una base de ficheros muy grande si es que haces un uso intensivo de esta característica.');
+@define('MEDIA_DIRECTORY_MOVED', 'El directorio y los ficheros fueron exitosamente movidos a %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', '¡El directorio y los ficheros no pudieron ser movidos a %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'En bases de datos distintas a MySQL, iterar sobre cada artículo para reemplazar el URL del directorio antiguo con la nueva dirección no es posible. Necesitarás que arreglar tus entradas de manera manual. También puedes regresar tu directorio a su ubicación original si hacer todo aquello te resulta muy incómodo.');
+/*translate*/
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Activa');
+@define('PLUGIN_INACTIVE', 'Inactiva');
+@define('PREFERENCE_USE_JS', '¿Activar el uso avanzado de JS?');
+@define('PREFERENCE_USE_JS_DESC', 'Si lo activas, las secciones de JavaScript avanzado serán activadas para una mejor usabilidad, como la extensión de configuración donde puedes utilizar el método de arrastrar y soltar para reordenar las extensiones.');
+@define('PREFERENCE_USE_JS_WARNING', '(Esta página hace uso de JavaScripting avanzado. Si estás teniendo problemas de funcionalidad, por favor desactiva el uso de JS avanzado en tus preferencias personales o desactiva el soporte para JavaScript de tu navegador)');
+/*rlazo [20060722] spell checked*/
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Ruta a los comentarios');
+@define('PERM_SET_CHILD', 'Define los mismos permisos en todos los directorios hijos');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Extensiones prohibidas');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Eventos prohibidos');
+@define('PERMISSION_FORBIDDEN_ENABLE', '¿Activar la extesión ACL para grupos de usuarios?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Si la opción "Extensión ACL para grupos de usuarios" es activada en la configuración, puedes especificar que grupos de usuarios son capaces de ejecutar ciertas extensiones/eventos.');
+@define('DELETE_SELECTED_ENTRIES', 'Eliminar las entradas seleccionadas');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Sólo mostrar aquellos autores con al menos X artículos');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
