@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_nl.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_nl.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Christiaan Heerze <webmaster@heimp.nl>
@@ -52,9 +52,9 @@
 @define('SAVE', 'Opslaan');
 @define('UP', 'OP');
 @define('DOWN', 'NEER');
-@define('ENTRIES', 'inzendingen');
-@define('NEW_ENTRY', 'Nieuwe inzending');
-@define('EDIT_ENTRIES', 'Bewerk inzendingen');
+@define('ENTRIES', 'bijdragen');
+@define('NEW_ENTRY', 'Nieuwe bijdrage');
+@define('EDIT_ENTRIES', 'Bewerk bijdragen');
 @define('CATEGORIES', 'Categorieën');
 @define('WARNING_THIS_BLAHBLAH', "WAARSCHUWING:\\nDit kan veel tijd in beslag nemen als er veel grote afbeeldingen zijn, zonder index-afbeelding.");
 @define('CREATE_THUMBS', 'Creëer nieuwe index-afbeeldingen');
@@ -65,20 +65,20 @@
 @define('COMMENT', 'Reactie');
 @define('REMEMBER_INFO', 'Onthoud Informatie? ');
 @define('SUBMIT_COMMENT', 'Reactie plaatsen');
-@define('NO_ENTRIES_TO_PRINT', 'Er zijn geen inzendingen af te drukken');
+@define('NO_ENTRIES_TO_PRINT', 'Er zijn geen bijdragen af te drukken');
 @define('COMMENTS', 'Reacties');
 @define('ADD_COMMENT', 'Reactie toevoegen');
 @define('NO_COMMENTS', 'Geen reacties');
 @define('POSTED_BY', 'Geplaatst door');
-@define('ON', 'aan');
-@define('A_NEW_COMMENT_BLAHBLAH', 'Er is een nieuwe reactie geplaatst op uw Weblog "%s", op inzending met onderwerp "%s".');
-@define('A_NEW_TRACKBACK_BLAHBLAH', 'Een nieuwe trackback naar uw website is aangemaakt naar uw Weblog-inzending met onderwerp "%s".');
+@define('ON', 'op');
+@define('A_NEW_COMMENT_BLAHBLAH', 'Er is een nieuwe reactie geplaatst op uw Weblog "%s", op bijdrage met onderwerp "%s".');
+@define('A_NEW_TRACKBACK_BLAHBLAH', 'Een nieuwe trackback naar uw website is aangemaakt naar uw Weblog-bijdrage met onderwerp "%s".');
 @define('NO_CATEGORY', 'Geen categorie');
-@define('ENTRY_BODY', 'Verkorte inzending');
-@define('EXTENDED_BODY', 'Uitgebreide inzending');
+@define('ENTRY_BODY', 'Verkorte bijdrage');
+@define('EXTENDED_BODY', 'Uitgebreide bijdrage');
 @define('CATEGORY', 'Categorie');
 @define('EDIT', 'Bewerk');
-@define('NO_ENTRIES_BLAHBLAH', 'Er zijn geen inzendingen gevonden voor zoekopdracht %s' . "\n");
+@define('NO_ENTRIES_BLAHBLAH', 'Er zijn geen bijdragen gevonden voor zoekopdracht %s' . "\n");
 @define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Uw zoekopdracht naar %s heeft %s zoekresultaten opgeleverd:');
 @define('IMAGE', 'Afbeelding');
 @define('ERROR_FILE_NOT_EXISTS', 'Fout: Oude bestandsnaam bestaat niet!');
@@ -95,7 +95,7 @@
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hier kunt u de grootte van de afbeelding aanpassen. Als u de afbeeldingsverhoudingen wilt behouden, voer dan in één van de velden een waarde in en druk op de TAB-toets -- Het programma zal dan zelf de andere grootte berekenen zodat de verhoudingen hetzelfde blijven</p>');
 @define('QUICKJUMP_CALENDAR', 'Quickjump Kalender');
 @define('QUICKSEARCH', 'Zoeken');
-@define('SEARCH_FOR_ENTRY', 'Zoek naar een inzending');
+@define('SEARCH_FOR_ENTRY', 'Zoek naar een bijdrage');
 @define('ARCHIVES', 'Archief');
 @define('BROWSE_ARCHIVES', 'Doorzoek het archief, per maand');
 @define('TOP_REFERRER', 'Top Referrer');
@@ -127,22 +127,22 @@
 @define('IN', 'in');
 @define('EXCERPT', 'Uittreksel');
 @define('TRACKED', 'Gevolgd');
-@define('LINK_TO_ENTRY', 'Link naar inzending');
-@define('LINK_TO_REMOTE_ENTRY', 'Link naar externe inzending');
+@define('LINK_TO_ENTRY', 'Link naar bijdrage');
+@define('LINK_TO_REMOTE_ENTRY', 'Link naar externe bijdrage');
 @define('IP_ADDRESS', 'IP-adres');
 @define('USER', 'Gebruiker');
 @define('THUMBNAIL_USING_OWN', 'Behoud %s als zijn eigen index-afbeelding, verkleinen is niet nodig.');
 @define('THUMBNAIL_FAILED_COPY', '%s kon niet gekopieërd worden en kan dus niet als index-afbeelding gebruikt worden!');
 @define('AUTHOR', 'Auteur');
 @define('LAST_UPDATED', 'Laatst bewerkt');
-@define('TRACKBACK_SPECIFIC', 'Trackback is een specifieke link naar deze inzending');
-@define('DIRECT_LINK', 'Directe link naar deze inzending');
+@define('TRACKBACK_SPECIFIC', 'Trackback URI voor deze bijdrage');
+@define('DIRECT_LINK', 'Directe link naar deze bijdrage');
 @define('COMMENT_ADDED', 'Uw reactie is succesvol toegevoegd. ');
 @define('COMMENT_ADDED_CLICK', 'Klik %shier%s om terug te keren naar de reacties, of klik %shier%s om dit scherm af te sluiten.');
 @define('COMMENT_NOT_ADDED_CLICK', 'Klik %shier%s om terug te keren naar de reacties, of klik %shier%s om dit scherm af te sluiten.');
-@define('COMMENTS_DISABLE', 'Sta geen reacties toe op deze inzending');
-@define('COMMENTS_ENABLE', 'Sta reacties toe op deze inzending');
-@define('COMMENTS_CLOSED', 'De auteur staat het niet toe te reageren op deze inzending');
+@define('COMMENTS_DISABLE', 'Sta geen reacties toe op deze bijdrage');
+@define('COMMENTS_ENABLE', 'Sta reacties toe op deze bijdrage');
+@define('COMMENTS_CLOSED', 'De auteur staat het niet toe te reageren op deze bijdrage');
 @define('EMPTY_COMMENT', 'Uw reactie bevatte geen tekst, gaat u alstublieft %sterug%s en probeer opnieuw');
 @define('ENTRIES_FOR', 'Inzendingen voor %s');
 @define('DOCUMENT_NOT_FOUND', 'Het document %s is helaas niet gevonden.');
@@ -157,14 +157,14 @@
 @define('SAVE_CHANGES_TO_LAYOUT', 'Bewaar veranderingen in ontwerp');
 @define('COMMENTS_FROM', 'Reactie van');
 @define('ERROR', 'Fout');
-@define('ENTRY_SAVED', 'Uw inzending is bewaard');
-@define('DELETE_SURE', 'Weet u zeker dat u inzending #%s definitief wilt verwijderen?');
+@define('ENTRY_SAVED', 'Uw bijdrage is bewaard');
+@define('DELETE_SURE', 'Weet u zeker dat u bijdrage #%s definitief wilt verwijderen?');
 @define('NOT_REALLY', 'Niet echt...');
 @define('DUMP_IT', 'Verwijder!');
 @define('RIP_ENTRY', 'Inzending #%s is verwijderd');
-@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categorie #%s is verwijderd. Aanwezige inzendingen zijn verplaatst naar categorie #%s');
+@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categorie #%s is verwijderd. Aanwezige bijdragen zijn verplaatst naar categorie #%s');
 @define('CATEGORY_DELETED', 'Categorie #%s is verwijderd.');
-@define('CATEGORY_REMAINING', 'Verwijder deze categorie en verplaats de inzendingen naar categorie: %s');
+@define('CATEGORY_REMAINING', 'Verwijder deze categorie en verplaats de bijdragen naar categorie: %s');
 @define('INVALID_CATEGORY', 'Er is geen categorie opgegeven om te verwijderen');
 @define('CATEGORY_SAVED', 'Categorie is opgeslagen');
 @define('SELECT_TEMPLATE', 'Selecteer een template dat u wenst te gebruiken voor uw weblog');
@@ -178,7 +178,7 @@
 @define('COULDNT_SELECT_DB', 'Kan de volgende database niet selecteren: %s.');
 @define('COULDNT_SELECT_USER_INFO', 'Kan de volgende gebruikers informatie niet selecteren: %s.');
 @define('COULDNT_SELECT_CATEGORY_INFO', 'Kan de volgende categorie niet selecteren: %s.');
-@define('COULDNT_SELECT_ENTRY_INFO', 'Kan de volgende inzendingen niet selecteren: %s.');
+@define('COULDNT_SELECT_ENTRY_INFO', 'Kan de volgende bijdragen niet selecteren: %s.');
 @define('COULDNT_SELECT_COMMENT_INFO', 'Kan de volgende reactie niet selecteren: %s.');
 @define('YES', 'Ja');
 @define('NO', 'Nee');
@@ -217,11 +217,11 @@
 @define('REALLY_SCALE_IMAGE', 'Wilt u de afbeelding echt aanpassen? Dit kan namelijk niet meer ongedaan gemaakt worden!');
 @define('TOGGLE_ALL', 'Alles uit- of inklappen');
 @define('TOGGLE_OPTION', 'Uit/Inklap opties');
-@define('SUBSCRIBE_TO_THIS_ENTRY', 'Abonneer op deze inzending');
-@define('UNSUBSCRIBE_OK', "%s is nu geabonneerd op deze inzending");
-@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nieuwe reactie op geabonneerde inzending "%s"');
-@define('SUBSCRIPTION_MAIL', "Geachte %s,\n\nEen nieuwe reactie is geplaatst op \"%s\", op inzending \"%s\"\nDe persoon die gereageerd heeft is: %s\n\nU kunt de inzending hier vinden: %s\n\nU kunt zich uitschrijven door op deze link te klikken: %s\n");
-@define('SUBSCRIPTION_TRACKBACK_MAIL', "Geachte %s,\n\nEen nieuwe trackback is toegevoegd op\"%s\", op inzending \"%s\"\nDe persoon die gereageerd heeft is: %s\n\nU kunt de inzending hier vinden: %s\n\nU kunt zich uitschrijven door op deze link te klikken: %s\n");
+@define('SUBSCRIBE_TO_THIS_ENTRY', 'Abonneer op deze bijdrage');
+@define('UNSUBSCRIBE_OK', "%s is nu geabonneerd op deze bijdrage");
+@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Nieuwe reactie op geabonneerde bijdrage "%s"');
+@define('SUBSCRIPTION_MAIL', "Geachte %s,\n\nEen nieuwe reactie is geplaatst op \"%s\", op bijdrage \"%s\"\nDe persoon die gereageerd heeft is: %s\n\nU kunt de bijdrage hier vinden: %s\n\nU kunt zich uitschrijven door op deze link te klikken: %s\n");
+@define('SUBSCRIPTION_TRACKBACK_MAIL', "Geachte %s,\n\nEen nieuwe trackback is toegevoegd op\"%s\", op bijdrage \"%s\"\nDe persoon die gereageerd heeft is: %s\n\nU kunt de bijdrage hier vinden: %s\n\nU kunt zich uitschrijven door op deze link te klikken: %s\n");
 @define('SIGNATURE', "\n-- \n%s is powered by Serendipity.\nEén van de beste weblogs. U kunt het ook gebruiken.\nGa naar <http://s9y.org> om uit te vinden hoe.");
 @define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
 @define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@@ -241,7 +241,7 @@
 @define('SYNDICATION_PLUGIN_TTL', 'Field "ttl" (time-to-live)');
 @define('SYNDICATION_PLUGIN_TTL_DESC', 'Aantal minuten nadat uw weblog niet meer gecached mag worden door buitenlandse sites/applicaties (empty: hidden) [RSS 2.0]');
 @define('SYNDICATION_PLUGIN_PUBDATE', 'Field "pubDate"');
-@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Moet het "pubDate"-veld worden geintegreerd in uw RSS-channel, om zo de dag van de laatste inzending te tonen?');
+@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Moet het "pubDate"-veld worden geintegreerd in uw RSS-channel, om zo de dag van de laatste bijdrage te tonen?');
 @define('CONTENT', 'Inhoud');
 @define('TYPE', 'Type');
 @define('DRAFT', 'Concept');
@@ -254,13 +254,13 @@
 @define('ALL_AUTHORS', 'Alle auteurs');
 @define('CATEGORIES_TO_FETCH', 'Op te halen categorieën');
 @define('CATEGORIES_TO_FETCH_DESC', 'Categorieën op van welke auteur inzien?');
-@define('PAGE_BROWSE_ENTRIES', 'Pagina %s van %s, totaal %s inzendingen');
+@define('PAGE_BROWSE_ENTRIES', 'Pagina %s van %s, totaal %s bijdragen');
 @define('PREVIOUS_PAGE', 'vorige pagina');
 @define('NEXT_PAGE', 'volgende pagina');
 @define('ALL_CATEGORIES', 'Alle categorieën');
 @define('DO_MARKUP', 'Voer tekstopmaak veranderingen uit');
 @define('GENERAL_PLUGIN_DATEFORMAT', 'Datum opmaak');
-@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'De echte datum van de inzending, gebruikmakend van de PHPs strftime() variabelen. (Standaard: "%s")');
+@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'De echte datum van de bijdrage, gebruikmakend van de PHPs strftime() variabelen. (Standaard: "%s")');
 @define('ERROR_TEMPLATE_FILE', 'Kan de template niet openen, update u alstublieft Serendipity!');
 @define('ADVANCED_OPTIONS', 'Geavanceerde Opties');
 @define('EDIT_ENTRY', 'Bewerk Inzending');
@@ -303,10 +303,10 @@
 @define('CREATED_USER', '%s is aangemaakt als nieuwe gebruiker');
 @define('MODIFIED_USER', 'De eigenschappen van gebruiker, %s, zijn gewijzigd');
 @define('USER_LEVEL', 'Gebruikersniveau');
-@define('DELETE_USER', 'U staat op het punt de volgende gebruiker te verwijderen: #%d %s. Weet u zeker dat u deze gebruiker wilt verwijderen? Wanneer u dit doet zullen de inzendingen van deze gebruiker niet meer worden weergegeven.');
+@define('DELETE_USER', 'U staat op het punt de volgende gebruiker te verwijderen: #%d %s. Weet u zeker dat u deze gebruiker wilt verwijderen? Wanneer u dit doet zullen de bijdragen van deze gebruiker niet meer worden weergegeven.');
 @define('DELETED_USER', 'Gebruiker, #%d %s, is verwijderd.');
 @define('LIMIT_TO_NUMBER', 'Hoeveel items moeten er worden weergegeven?');
-@define('ENTRIES_PER_PAGE', 'inzendingen per pagina');
+@define('ENTRIES_PER_PAGE', 'bijdragen per pagina');
 @define('XML_IMAGE_TO_DISPLAY', 'XML Button');
 @define('XML_IMAGE_TO_DISPLAY_DESC','Deze afbeelding laat u uw XML Feeds weergeven. Laat het veld leeg voor de standaard instellingen, voer \'none\' in om het uit te schakellen.');
 
@@ -331,7 +331,7 @@
 @define('TOP_LEVEL', 'Top level');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', 'Toegangsrechten');
-@define('SETTINGS_SAVED_AT', 'De instellingen zijn opgeslagen in %s');
+@define('SETTINGS_SAVED_AT', 'De instellingen zijn opgeslagen om %s');
 
 /* DATABASE SETTINGS */
 @define('INSTALL_CAT_DB', 'Database instellingen');
@@ -377,9 +377,9 @@
 @define('INSTALL_EMAIL', 'E-mailadres van beheerder');
 @define('INSTALL_EMAIL_DESC', 'E-mailadres van de beheerder van het weblog');
 @define('INSTALL_SENDMAIL', 'Verstuur e-mails naar beheerder?');
-@define('INSTALL_SENDMAIL_DESC', 'Wilt een e-mail ontvangen wanneer er een reactie geplaatst is op een van uw inzendingen?');
-@define('INSTALL_SUBSCRIBE', 'Abonneren op inzendingen?');
-@define('INSTALL_SUBSCRIBE_DESC', 'Maak het mogelijk voor gebruikers om zich te abonneren op uw inzendingen? Gebruikers zullen dan een e-mail ontvangen wanneer er een reactie geplaatst is op deze inzending');
+@define('INSTALL_SENDMAIL_DESC', 'Wilt een e-mail ontvangen wanneer er een reactie geplaatst is op een van uw bijdragen?');
+@define('INSTALL_SUBSCRIBE', 'Abonneren op bijdragen?');
+@define('INSTALL_SUBSCRIBE_DESC', 'Maak het mogelijk voor gebruikers om zich te abonneren op uw bijdragen? Gebruikers zullen dan een e-mail ontvangen wanneer er een reactie geplaatst is op deze bijdrage');
 @define('INSTALL_BLOGNAME', 'Weblog naam');
 @define('INSTALL_BLOGNAME_DESC', 'De naam van uw weblog');
 @define('INSTALL_BLOGDESC', 'Omschrijving weblog');
@@ -427,7 +427,7 @@
 @define('USERCONF_EMAIL', 'Uw e-mailadres');
 @define('USERCONF_EMAIL_DESC', 'Uw eigen e-mailadres');
 @define('USERCONF_SENDCOMMENTS', 'Bericht bij reacties?');
-@define('USERCONF_SENDCOMMENTS_DESC', 'Wilt u een e-mail ontvangen wanneer er reacties geplaatst worden op uw inzendingen?');
+@define('USERCONF_SENDCOMMENTS_DESC', 'Wilt u een e-mail ontvangen wanneer er reacties geplaatst worden op uw bijdragen?');
 @define('USERCONF_SENDTRACKBACKS', 'Verstuur trackback bericht?');
 @define('USERCONF_SENDTRACKBACKS_DESC', 'Wilt u een e-mail ontvangen wanneer er een trackback naar een van uw berichten is gemaakt?');
 @define('USERCONF_ALLOWPUBLISH', 'Toestaan berichten te plaatsen?');
@@ -438,10 +438,10 @@
 @define('POWERED_BY_SHOW_IMAGE', 'Toon "Serendipity" logo');
 @define('POWERED_BY_SHOW_IMAGE_DESC', 'Toont het Serendipity logo');
 @define('PLUGIN_ITEM_DISPLAY', 'Waar moeten de items worden weergegeven?');
-@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Alleen uitgebreide inzendingen');
+@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Alleen uitgebreide bijdragen');
 @define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Alleen overzichtspagina');
 @define('PLUGIN_ITEM_DISPLAY_BOTH', 'Altijd');
-@define('RSS_IMPORT_CATEGORY', 'Gebruik deze categorie gebruiken om ongelijke inzendingen in op te slaan');
+@define('RSS_IMPORT_CATEGORY', 'Gebruik deze categorie gebruiken om ongelijke bijdragen in op te slaan');
 
 @define('COMMENTS_WILL_BE_MODERATED', 'Ingestuurde reacties zullen eerst worden gecontroleerd voor deze geplaatst worden.');
 @define('YOU_HAVE_THESE_OPTIONS', 'U heeft de volgende opties tot uw beschikking:');
@@ -462,14 +462,14 @@
 @define('COMMENT_EDITED', 'De reactie is aangepast');
 @define('HIDE', 'Verbergen');
 @define('VIEW_EXTENDED_ENTRY', 'Ga door met lezen van "%s"');
-@define('TRACKBACK_SPECIFIC_ON_CLICK', 'De link is niet bedoeld om aangeklikt te worden. Het bevat een trackback URL voor deze inzending. U kunt deze URL gebruiken om ping- & trackbacks te versturen van uw weblog naar deze inzending. Om deze URL te kopiëren klikt u op de rechter muisknop, "Copy Shortcut" voor Internet Explorer gebruikers of "Copy Link Location" voor Mozilla gebruikers.');
+@define('TRACKBACK_SPECIFIC_ON_CLICK', 'De link is niet bedoeld om aangeklikt te worden. Het bevat een trackback URL voor deze bijdrage. U kunt deze URL gebruiken om ping- & trackbacks te versturen van uw weblog naar deze bijdrage. Om deze URL te kopiëren klikt u op de rechter muisknop, "Copy Shortcut" voor Internet Explorer gebruikers of "Copy Link Location" voor Mozilla gebruikers.');
 @define('PLUGIN_SUPERUSER_HTTPS', 'Gebruik HTTPS om aan te melden');
 @define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Laat de aanmelding via https verlopen. Uw webserver moet dit echter wel ondersteunen!');
 @define('INSTALL_SHOW_EXTERNAL_LINKS', 'Maak externe links aanklikbaar?');
 @define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nee": Niet gecontroleerde externe links (Top Exits, Top Referrers, User comments) worden niet getoond of getoond als gewone tekst om spam vanuit zoekmachines te voorkomen. (aanbevolen). "ja": Niet gecontroleerde externe links worden gewoon getoond als links. De Sidebar plugin configuratie kan dit beïnvloeden!');
 @define('PAGE_BROWSE_COMMENTS', 'Pagina %s van de %s, in totaal %s reactie(s)');
 @define('FILTERS', 'Filters');
-@define('FIND_ENTRIES', 'Zoek inzendingen');
+@define('FIND_ENTRIES', 'Zoek bijdragen');
 @define('FIND_COMMENTS', 'Zoek reacties');
 @define('FIND_MEDIA', 'Zoek media');
 @define('FILTER_DIRECTORY', 'Map');
@@ -501,11 +501,11 @@
 @define('COMMENT_DELETE_CONFIRM', 'Weet u zeker dat u de reactie #%d, geschreven door %s wilt verwijderen?');
 @define('DELETE_SELECTED_COMMENTS', 'Verwijder geselecteerde reacties');
 @define('VIEW_COMMENT', 'Bekijk reactie');
-@define('VIEW_ENTRY', 'Bekijk inzending');
+@define('VIEW_ENTRY', 'Bekijk bijdrage');
 @define('DELETE_FILE_FAIL' , 'Kan bestand <b>%s</b> niet verwijderen');
 @define('DELETE_THUMBNAIL', 'Verwijder index-afbeelding <b>%s</b>');
 @define('DELETE_FILE', 'Verwijder bestand genaamd <b>%s</b>');
-@define('ABOUT_TO_DELETE_FILE', 'U staat op het punt om bestand <b>%s</b></p><br/> te verwijderen. Als u dit bestand in een van uw inzendingen gebruikt, zal dit leiden tot niet werkende links of afbeeldingen.<br />Weet u zeker dat u door wilt gaan?<br /><br />');
+@define('ABOUT_TO_DELETE_FILE', 'U staat op het punt om bestand <b>%s</b></p><br/> te verwijderen. Als u dit bestand in een van uw bijdragen gebruikt, zal dit leiden tot niet werkende links of afbeeldingen.<br />Weet u zeker dat u door wilt gaan?<br /><br />');
 @define('TRACKBACK_SENDING', 'Verstuur een trackback naar %s...');
 @define('TRACKBACK_SENT', 'Trackback succesvol');
 @define('TRACKBACK_FAILED', 'Trackback functioneert niet: %s');
@@ -521,8 +521,8 @@
 @define('COMMENTS_FILTER_ALL', 'Alles');
 @define('COMMENTS_FILTER_APPROVED_ONLY', 'Alleen geäutoriseerden');
 @define('COMMENTS_FILTER_NEED_APPROVAL', 'Wacht op autorisatie');
-@define('RSS_IMPORT_BODYONLY', 'Voeg alle geïmporteerde teksten in de "verkorte inzendingen"-sectie en splits deze niet op in de "uitgebreide inzendingen"-sectie.');
-@define('SYNDICATION_PLUGIN_FULLFEED', 'Geef volledige inzendingen weer in het RSS feed');
+@define('RSS_IMPORT_BODYONLY', 'Voeg alle geïmporteerde teksten in de "verkorte bijdragen"-sectie en splits deze niet op in de "uitgebreide bijdragen"-sectie.');
+@define('SYNDICATION_PLUGIN_FULLFEED', 'Geef volledige bijdragen weer in het RSS feed');
 @define('WEEK', 'Week');
 @define('WEEKS', 'Weken');
 @define('MONTHS', 'Maanden');
@@ -537,16 +537,16 @@
 @define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klik hier om een nieuwe %s te installeren');
 @define('VERSION', 'versie');
 @define('INSTALL', 'Installeren');
-@define('ALREADY_INSTALLED', 'Reed geïnstalleerd');
+@define('ALREADY_INSTALLED', 'Reeds geïnstalleerd');
 @define('SELECT_A_PLUGIN_TO_ADD', 'Selecteer welke plugin u wenst te installeren');
 @define('INSTALL_OFFSET', 'Aanpassing servertijd');
 @define('STICKY_POSTINGS', 'Post-it\'s');
 @define('INSTALL_FETCHLIMIT', 'Inzendingen die weergegeven moeten worden');
-@define('INSTALL_FETCHLIMIT_DESC', 'Aantal inzendingen die weergeven moeten worden voor elke pagina');
-@define('IMPORT_ENTRIES', 'Importeer inzendingen');
-@define('EXPORT_ENTRIES', 'Exporteer inzendingen');
+@define('INSTALL_FETCHLIMIT_DESC', 'Aantal bijdragen die weergeven moeten worden voor elke pagina');
+@define('IMPORT_ENTRIES', 'Importeer bijdragen');
+@define('EXPORT_ENTRIES', 'Exporteer bijdragen');
 @define('IMPORT_WELCOME', 'Welkom bij de Serendipity import utility');
-@define('IMPORT_WHAT_CAN', 'Hier kunt u inzendingen uit andere weblog software importeren');
+@define('IMPORT_WHAT_CAN', 'Hier kunt u bijdragen uit andere weblog software importeren');
 @define('IMPORT_SELECT', 'Selecteer alstublieft uit welk type weblog u de gegevens wilt importeren');
 @define('IMPORT_PLEASE_ENTER', 'Voert u alstublieft de gegevens in die hieronder gevraagd worden');
 @define('IMPORT_NOW', 'Importeer nu!');
@@ -557,14 +557,14 @@
 @define('EXPORT_FEED', 'Exporteer volledige RSS feed');
 @define('STATUS', 'Status na importeren');
 @define('IMPORT_GENERIC_RSS', 'Algemene RSS import');
-@define('ACTIVATE_AUTODISCOVERY', 'Verstuur trackbacks naar links gevonden in deze inzending');
+@define('ACTIVATE_AUTODISCOVERY', 'Verstuur trackbacks naar links gevonden in deze bijdrage');
 @define('WELCOME_TO_ADMIN', 'Welkom bij Serendipity Beheer.');
 @define('PLEASE_ENTER_CREDENTIALS', 'Voert u alstublieft hieronder uw gegevens in.');
 @define('ADMIN_FOOTER_POWERED_BY', 'Powered by Serendipity %s en PHP %s');
 @define('INSTALL_USEGZIP', 'Maak gebruik van gzip gecomprimeerde paginas');
 @define('INSTALL_USEGZIP_DESC', 'Om de verzending van pagina\'s te versnellen, kunnen de pagina\'s gecomprimeerd worden. Dit is alleen mogelijk als zijn/haar browser dit aan kan. Het word echter aangeraden');
-@define('INSTALL_SHOWFUTURE', 'Bekijk toekomstige inzendingen');
-@define('INSTALL_SHOWFUTURE_DESC', 'Wanneer dit is ingeschakeld zal het alle toekomstige inzendingen, reeds aanwezig in uw weblog, weergeven. Standaard staat deze ingesteld om de inzendingen pas te vertonen wanneer de publicatiedatum bereikt is.');
+@define('INSTALL_SHOWFUTURE', 'Bekijk toekomstige bijdragen');
+@define('INSTALL_SHOWFUTURE_DESC', 'Wanneer dit is ingeschakeld zal het alle toekomstige bijdragen, reeds aanwezig in uw weblog, weergeven. Standaard staat deze ingesteld om de bijdragen pas te vertonen wanneer de publicatiedatum bereikt is.');
 @define('INSTALL_DBPERSISTENT', 'Gebruik altijd openstaande verbindingen');
 @define('INSTALL_DBPERSISTENT_DESC', 'Laat de verbinding met uw database openstaan, hierover kunt u meer lezen op <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">deze pagina</a>. Dit is normaliter niet aangeraden');
 @define('NO_IMAGES_FOUND', 'Geen afbeeldingen gevonden');
@@ -612,7 +612,7 @@
 @define('PROBLEM_PERMISSIONS_HOWTO', 'Toegansrechten kunnen gezet worden met de volgende commando: `<em>%s</em>` op de mislukte map, of door het wijzigen via een FTP programma');
 @define('WARNING_TEMPLATE_DEPRECATED', 'Waarschuwing: Uw huidige template gebruikte een oude template methode. U wordt geadviseerd om indien mogelijk te upgraden.');
 @define('ENTRY_PUBLISHED_FUTURE', 'Dit interessegebied is nog niet gepubliceerd');
-@define('ENTRIES_BY', 'Interessegebieden naar %s');
+@define('ENTRIES_BY', 'Blog posts van %s');
 @define('PREVIOUS', 'Vorige');
 @define('NEXT', 'Volgende');
 @define('APPROVE', 'Goedkeuren');
@@ -679,7 +679,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Permanente link Auteur URL structuur');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hier kunt u de relatieve URL structuur bepalen, startend van je basis URL tot wanneer de RSS-feeds van bepaalde auteurs kunnen vrijkomen. U kunt gebruik maken van de volgende varibelen %id%, %realname%, %username%, %email% en andere karakters.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Permanente link Categorie URL structuur');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hier kunt u de relatieve URL structuur, startend van je basis URL tot wanneer de inzendingen van bepaalde categorieën beschikbaar worden. U kunt gebruik maken van de volgende variabelen %id%, %name%, %description% en andere karakters.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hier kunt u de relatieve URL structuur, startend van je basis URL tot wanneer de bijdragen van bepaalde categorieën beschikbaar worden. U kunt gebruik maken van de volgende variabelen %id%, %name%, %description% en andere karakters.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permanente link RSS-Feed Categorie URL structuur');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hier kunt u de relatieve URL structuur bepalen, startend van je basis URL tot wanneer de RSS-feeds van bepaalde categorieën vrijkomen. U kunt gebruik maken van de volgende varibelen %id%, %name%, %description% en andere karakters.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Zoekpad naar archieven');
@@ -800,9 +800,93 @@
 @define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'If this option is enabled, the number of articles by this author is shown next to the authors name in parentheses.');
 @define('CUSTOM_ADMIN_INTERFACE', 'Custom admin interface available');
 
-@define('COMMENT_NOT_ADDED', 'Uw reactie kon niet worden toegevoegd omdat deze functie voor deze inzending is uitgeschakeld. '); // Retranslate: 'Your comment could not be added, because comments for this entry have either been disabled, you entered invalid data, or your comment was caught by anti-spam measurements.'
+@define('COMMENT_NOT_ADDED', 'Uw reactie kon niet worden toegevoegd omdat deze functie voor deze bijdrage is uitgeschakeld. '); // Retranslate: 'Your comment could not be added, because comments for this entry have either been disabled, you entered invalid data, or your comment was caught by anti-spam measurements.'
 @define('INSTALL_TRACKREF', 'Enable referrer tracking?');
 @define('INSTALL_TRACKREF_DESC', 'Enabling the referrer tracking will show you which sites refer to your articles. Today this is often abused for spamming, so you can disable it if you want.');
 @define('CATEGORIES_HIDE_PARENT', 'Hide the selected parent category?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'If you restrict the listing of categories to a specific category, by default you will see that parent category within the output listing. If you disable this option, the parent category name will not be displayed.');
 @define('WARNING_NO_GROUPS_SELECTED', 'Warning: You did not select any group memberships. This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
+@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
+@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
+@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
+@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
+@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
+@define('FURTHER_LINKS', 'Further Links');
+@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
+@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(Comment removed)');
+
+@define('CURRENT_AUTHOR', 'Current author');
+
+@define('WORD_NEW', 'New');
+@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
+@define('MEDIA_KEYWORDS', 'Media keywords');
+@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
+@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
+@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
+@define('MEDIA_PROP', 'Media properties');
+
+
+@define('GO_ADD_PROPERTIES', 'Go & enter properties');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
+@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
+@define('MEDIA_PROPERTY_TITLE', 'Title');
+@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
+@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');
+
+@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
+@define('STYLE_OPTIONS', 'Theme/Style options');
+
+@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');
+
+@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
+@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also vioaltes RFC2616. So if you set this option to "TRUE" you will compliy with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('MEDIA_PROPERTY_DATE', 'Associated Date');
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
+@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
+@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
+@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');
+
+@define('MEDIA_TARGET', 'Target for this link');
+@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
+@define('MEDIA_ENTRY', 'Isolated Entry');
+@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
+@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');
+
+@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Active');
+@define('PLUGIN_INACTIVE', 'Inactive');
+@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
+@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
