@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -775,7 +775,8 @@ $i18n_unknown = 'tw';
 @define('INSTALL_CHARSET_DESC', '這裡可以讓您轉換 UTF-8 或預設語系 (ISO, EUC, ...)。有些語言只有 UTF-8 語系檔，所以換成預設語系不會改變任何東西。新安裝的網誌建議使用 UTF-8 語系。記得不要改變這個設定如果您已經發佈了文章。詳情請看 http://www.s9y.org/index.php?node=46。');
 @define('CALENDAR_ENABLE_EXTERNAL_EVENTS', '開啟外掛 API');
 @define('CALENDAR_EXTEVENT_DESC', '如果開啟，外掛可以在日曆內以顏色突顯它的事件。如果沒有使用這些特殊的外掛，建議不要使用。');
-@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API 功能已不加在 s9y 的安裝裡，因為漏洞和不多人使用的關係。所以您必須安裝 XML-RPC 的外掛如果要使用 XML-RPC API。所有的 URL 不會因此改變，安裝這個外掛後可以馬上使用。');@define('PERM_READ', 'Read permission');
+@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API 功能已不加在 s9y 的安裝裡，因為漏洞和不多人使用的關係。所以您必須安裝 XML-RPC 的外掛如果要使用 XML-RPC API。所有的 URL 不會因此改變，安裝這個外掛後可以馬上使用。');
+@define('PERM_READ', 'Read permission');
 @define('PERM_READ', '讀取權限');
 @define('PERM_WRITE', '寫入權限');
 
@@ -806,4 +807,87 @@ $i18n_unknown = 'tw';
 @define('INSTALL_TRACKREF_DESC', '開啟記錄來源會顯示哪個網站引用了您的文章。您可以關閉這個功能如果收到太多垃圾廣告。');
 @define('CATEGORIES_HIDE_PARENT', '隱藏選擇的類別？');
 @define('CATEGORIES_HIDE_PARENT_DESC', '當您限制類別顯示的列表，預設是會顯示母類別的名稱。如果您關閉這個功能，母類別的名稱將不會顯示。');
-@define('WARNING_NO_GROUPS_SELECTED', '警告：您沒有選擇會員群組。這會將您登出群組的管理，會員的群組不會被改變。');
\ No newline at end of file
+@define('WARNING_NO_GROUPS_SELECTED', '警告：您沒有選擇會員群組。這會將您登出群組的管理，會員的群組不會被改變。');
+@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'RSS Feed 頁面裡顯示的文章數量。');
+@define('INSTAL_DB_UTF8', '開啟資料庫的編碼轉換');
+@define('INSTAL_DB_UTF8_DESC', '使用 MySQL 的 "SET NAMES" 查詢來設定編碼。如果文章出現亂碼可以將這個設定打開或關閉。');
+@define('ONTHEFLYSYNCH', '開啟即時的媒體同步');
+@define('ONTHEFLYSYNCH_DESC', '如果開啟，Serendipity 會比較資料庫和媒體目錄內的檔案，然後進行資料同步。');
+@define('USERCONF_CHECK_USERNAME_ERROR', '帳號不能空白。');
+@define('FURTHER_LINKS', '更多連結');
+@define('FURTHER_LINKS_S9Y', 'Serendipity 首頁');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity 說明文件');
+@define('FURTHER_LINKS_S9Y_BLOG', '官方網誌');
+@define('FURTHER_LINKS_S9Y_FORUMS', '論壇');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(迴響已被移除)');
+
+@define('CURRENT_AUTHOR', '目前的作者');
+
+@define('WORD_NEW', '新');
+@define('SHOW_MEDIA_TOOLBAR', '在選擇媒體的視窗裡顯示工具欄？');
+@define('MEDIA_KEYWORDS', '媒體的關鍵字');
+@define('MEDIA_KEYWORDS_DESC', '輸入預設的媒體關鍵字，用 ";" 來分開每個關鍵字。');
+@define('MEDIA_EXIF', '輸入 EXIF/JPEG 圖片資料');
+@define('MEDIA_EXIF_DESC', '如果開啟，EXIF/JPEG 圖檔裡的 metadata 會自動儲存到資料庫。');
+@define('MEDIA_PROP', '媒體內容');
+
+
+@define('GO_ADD_PROPERTIES', '輸入內容');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', '版權');
+@define('MEDIA_PROPERTY_COMMENT1', '短介紹');
+@define('MEDIA_PROPERTY_COMMENT2', '長介紹');
+@define('MEDIA_PROPERTY_TITLE', '標題');
+@define('MEDIA_PROP_DESC', '輸入媒體使用的內容欄位，用 ";" 來分開每個欄位的名稱');
+@define('MEDIA_PROP_MULTIDESC', '(您可以在名稱後面加上 ":MULTI" 來設定加大它的文字限制)');
+
+@define('STYLE_OPTIONS_NONE', '這個佈景沒有特別的選項。如果要在您的佈景裡加上選項，請看 www.s9y.org 內的 Technical Documentation，然後 "Configuration of Theme options"。');
+@define('STYLE_OPTIONS', '佈景選項');
+
+@define('PLUGIN_AVAILABLE_COUNT', '總共： %d 個外掛。');
+
+@define('SYNDICATION_RFC2616', '開啟依照嚴格的 RFC2616 RSS-Feed');
+@define('SYNDICATION_RFC2616_DESC', '不強制 RFC2616 表示全部有條件的 GETs 到 Serendipity 只會傳回最後修改的文章。如果設定為 "false" 表示訪客會接收全部的文章。不過，一些網誌的蒐集軟體像 Planet 會出現奇怪現象。如果出現奇怪現象表示它違反了 RFC2616 的標準。所以設定為 "TRUE" 表示你遵從 RFC 的標準，但是訪客可能會讀取不到全部的文章。整體來說，不管怎樣都無法顧到兩方。相關資訊：https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('MEDIA_PROPERTY_DATE', '相關日期');
+@define('MEDIA_PROPERTY_RUN_LENGTH', '長度');
+@define('FILENAME_REASSIGNED', '自動指定新檔案的名稱： %s');
+@define('MEDIA_UPLOAD_SIZE', '檔案大小的上限');
+@define('MEDIA_UPLOAD_SIZE_DESC', '輸入檔案的最大值。這個設定也可以從主機內的 PHP.ini 檔案改變： upload_max_filesize, post_max_size, max_input_time 全部都能讓這裡的設定無效。如果不輸入表示遵從主機的限制。');
+@define('MEDIA_UPLOAD_SIZEERROR', '錯誤：您不能上傳大於 %s 位元組的檔案！');
+@define('MEDIA_UPLOAD_MAXWIDTH', '圖片的最大寬度');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', '輸入上傳的圖片的最大寬度。');
+@define('MEDIA_UPLOAD_MAXHEIGHT', '圖片的最大長度');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', '輸入上傳的圖片的最大長度。');
+@define('MEDIA_UPLOAD_DIMERROR', '錯誤：您不能上傳大於 %s x %s 的圖片！');
+
+@define('MEDIA_TARGET', '連結的目標');
+@define('MEDIA_TARGET_JS', '彈出視窗 (使用 JavaScript)');
+@define('MEDIA_ENTRY', '隔離文章');
+@define('MEDIA_TARGET_BLANK', '彈出視窗 (使用 target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', '允許改變圖片大小？');
+@define('MEDIA_DYN_RESIZE_DESC', '如果開啟，媒體的選擇視窗裡會顯示依照 GET 變數所設定的圖片大小。圖片會儲存於快取的記憶體內，所以常使用會佔用主機的空間。');
+@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Active');
+@define('PLUGIN_INACTIVE', 'Inactive');
+@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
+@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
