@@ -1,14 +1,16 @@
-<?php # $Id: serendipity_lang_bg.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_bg.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Bogomil Shopov <bogomil@spisanie.com>
 # http://www.purplerain.org/nb/
 # Ognyan Kulev <ogi@fmi.uni-sofia.bg>, 2005
+# Ivan Cenov <JWalker@hotmail.bg>, 2005-2006
 /* vim: set sts=4 ts=4 expandtab : */
 
 @define('LANG_CHARSET', 'windows-1251');
 @define('SQL_CHARSET', 'cp1251');
-@define('DATE_LOCALES', 'bg_BG');
+//@define('DATE_LOCALES', 'bg_BG');
+@define('DATE_LOCALES', 'bulgarian, bg, bg_BG');
 @define('DATE_FORMAT_ENTRY', '%A, %e %B %Y');
 @define('WYSIWYG_LANG', 'en');
 @define('LANG_DIRECTION', 'ltr');
@@ -747,8 +749,8 @@
 @define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync:   ');
 @define('PERMISSION_ADMINCOMMENTS', 'adminComments:   ');
 @define('PERMISSION_ADMINTEMPLATES', 'adminTemplates:   ');
-@define('INSTALL_BLOG_EMAIL', '.  ');
-@define('INSTALL_BLOG_EMAIL_DESC', '  .,       "From"   .  ,   ,      ,    -         From.');
+@define('INSTALL_BLOG_EMAIL', '   ');
+@define('INSTALL_BLOG_EMAIL_DESC', '   ,       "From"   .  ,   ,      ,    -         From.');
 @define('CATEGORIES_PARENT_BASE', '     -...');
 @define('CATEGORIES_PARENT_BASE_DESC', '    ,        .');
 @define('CATEGORIES_HIDE_PARALLEL', '  ,        ');
@@ -791,3 +793,86 @@
 @define('CATEGORIES_HIDE_PARENT', '     ?');
 @define('CATEGORIES_HIDE_PARENT_DESC', '        ,       .    ,      .');
 @define('WARNING_NO_GROUPS_SELECTED', ':       ,    .             ,     ,   .          .');
+@define('ONTHEFLYSYNCH', '     ');
+@define('ONTHEFLYSYNCH_DESC', '  , Serendipity       ,             .');
+@define('INSTALL_RSSFETCHLIMIT', '       RSS ');
+@define('INSTALL_RSSFETCHLIMIT_DESC', '  ,         RSS .');
+@define('INSTAL_DB_UTF8', '        MySQL  ');
+@define('INSTAL_DB_UTF8_DESC', '  MySQL.  \'\'  \'SET NAMES\',         .     ,      .');
+@define('USERCONF_CHECK_USERNAME_ERROR', '       .');
+@define('FURTHER_LINKS', '');
+@define('FURTHER_LINKS_S9Y', '   Serendipity');
+@define('FURTHER_LINKS_S9Y_DOCS', '  Serendipity');
+@define('FURTHER_LINKS_S9Y_BLOG', ' ');
+@define('FURTHER_LINKS_S9Y_FORUMS', '');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(  )');
+
+@define('CURRENT_AUTHOR', ' ');
+
+@define('WORD_NEW', '');
+@define('SHOW_MEDIA_TOOLBAR', '            ?');
+@define('MEDIA_KEYWORDS', '    ');
+@define('MEDIA_KEYWORDS_DESC', '   ,   \';\',            .');
+@define('MEDIA_EXIF', '  EXIF/JPEG   ');
+@define('MEDIA_EXIF_DESC', '  ,  EXIF/JPEG           .           .');
+@define('MEDIA_PROP', '   ');
+
+@define('GO_ADD_PROPERTIES', '    ');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', ' ');
+@define('MEDIA_PROPERTY_COMMENT2', ' ');
+@define('MEDIA_PROPERTY_TITLE', '');
+@define('MEDIA_PROP_DESC', '   ,   \';\',        .');
+@define('MEDIA_PROP_MULTIDESC', '(   ":MULTI"       ,          )');
+
+@define('STYLE_OPTIONS_NONE', '    .          ,     www.s9y.org  "Configuration of Theme options".');
+@define('STYLE_OPTIONS', '  ');
+
+@define('PLUGIN_AVAILABLE_COUNT', ': %d .');
+
+@define('MEDIA_PROPERTY_DATE', ' ');
+@define('MEDIA_PROPERTY_RUN_LENGTH', ' (    )');
+@define('SYNDICATION_RFC2616', '     RFC2616 RSS-');
+@define('SYNDICATION_RFC2616_DESC', '  RFC2616 ,    GET   Serendipity   ,      .    \'\'          ,          .     Planet ,  .    ,      RFC2616.  ,      \'\',     RFC2616,     RSS           ().              Planet,          .       ,    .  : https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('FILENAME_REASSIGNED', '     : %s');
+@define('MEDIA_UPLOAD_SIZE', '     ');
+@define('MEDIA_UPLOAD_SIZE_DESC', '       .         .  PHP.ini: upload_max_filesize, post_max_size, max_input_time     .           .');
+@define('MEDIA_UPLOAD_SIZEERROR', ':     , -  %s !');
+@define('MEDIA_UPLOAD_MAXWIDTH', '     ');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', '       ,    .');
+@define('MEDIA_UPLOAD_MAXHEIGHT', '     ');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', '      ,    .');
+@define('MEDIA_UPLOAD_DIMERROR', ':     , -  %s x %s .');
+
+@define('MEDIA_TARGET', ' (target)   ');
+@define('MEDIA_TARGET_JS', '  ( JavaScript,   )');
+@define('MEDIA_ENTRY', ' ');
+@define('MEDIA_TARGET_BLANK', '  ( target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', '        ?');
+@define('MEDIA_DYN_RESIZE_DESC', '  ,                GET.             .');
+
+@define('MEDIA_DIRECTORY_MOVED', '       %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', '       %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', ' -MySQL  ,        URL      URL (  )   .      ,     URL.           ,   ,       .');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'URL       %s .');
+@define('PLUGIN_ACTIVE', '');
+@define('PLUGIN_INACTIVE', '');
+@define('PREFERENCE_USE_JS', '     JavaScript ?');
+@define('PREFERENCE_USE_JS_DESC', '      JavaScript,    Serendipity     .          drag-and-drop    .');
+
+@define('PREFERENCE_USE_JS_WARNING', '(   JavaScript.   ,      JavaScript       JavaScript  .)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', '  ');
+@define('PERM_SET_CHILD', '      ');
+@define('PERMISSION_FORBIDDEN_PLUGINS', ' ');
+@define('PERMISSION_FORBIDDEN_HOOKS', ' ');
+@define('PERMISSION_FORBIDDEN_ENABLE', '  Plugin ACL    ?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', '  "Plugin ACL   "  ,                .');
+@define('DELETE_SELECTED_ENTRIES', '   ');
+@define('PLUGIN_AUTHORS_MINCOUNT', '     - X ');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
