@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_es.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_es.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Luis Cervantes <LuisCervantes@ono.com>,
@@ -10,12 +10,19 @@
 
 @define('LANG_CHARSET', 'ISO-8859-15');
 @define('SQL_CHARSET', 'latin2');
-@define('DATE_LOCALES', 'es_ES.ISO_8859-15, es_ES.ISO8859-15, es_ES.ISO_8859-1, es_ES.ISO8859-1, spanish, sp, es, es_ES, es-ES');
+@define('DATE_LOCALES', 'es_ES.ISO8859-15, es_ES.ISO8859-1, spanish, sp, es, es_ES, es-ES, es_ES.ISO_8859-15, es_ES.ISO_8859-1');
 @define('DATE_FORMAT_ENTRY', '%A, %e de %B del %Y');
 @define('DATE_FORMAT_SHORT', '%d.%m.%Y %H:%M');
 @define('WYSIWYG_LANG', 'es');
 @define('LANG_DIRECTION', 'ltr');
 
+/* rlazo[20061114]: dado que el espaol tiene varias traducciones para ciertas
+ * palabras sera bueno mantener una misma traduccin para ciertas
+ * palabras comunes (tratando de seguir http://es.tldp.org/ORCA/glosario.html):
+ *
+ * password -> contrasea
+ * file -> fichero? (se podra utilizar archivo para referirse a las entradas pasadas)
+ */
 @define('SERENDIPITY_ADMIN_SUITE', 'Suite de Administracin de Serendipity');
 @define('HAVE_TO_BE_LOGGED_ON', 'Debes identificarte para ver esta pgina');
 @define('APPEARANCE', 'Apariencia');
@@ -216,7 +223,7 @@
 @define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Altura de la imagen');
 @define('SYNDICATION_PLUGIN_WEBMASTER_DESC', 'Correo electrnico del webmaster, si est disponible. (djalo vaco para no mostrarlo) [RSS 2.0]');
 @define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'Correo electrnico del editor, si est disponible. (djalo vaco para no mostrarlo) [RSS 2.0]');
-@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de una imagen en formato GIF/JPEG/PNG, si est disponible. (dejndolo vaco se usara el logo de Serendipity)');
+@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de una imagen en formato GIF/JPEG/PNG, si est disponible. (dejndolo vaco se usara el smbolo de Serendipity)');
 @define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'en pixels, max. 144');
 @define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'en pixels, max. 400');
 @define('SYNDICATION_PLUGIN_TTL', 'Campo "ttl" (time-to-live)');
@@ -515,7 +522,7 @@
 @define('COMMENTS_FILTER_ALL', 'Todo');
 @define('COMMENTS_FILTER_APPROVED_ONLY', 'Slo lo aprobado');
 @define('COMMENTS_FILTER_NEED_APPROVAL', 'Pendiente de aprobacin');
-@define('RSS_IMPORT_BODYONLY', 'Pon todo el texto importado en el "cuerpo" y no lo separes en la seccin "entrada extendida".');
+@define('RSS_IMPORT_BODYONLY', 'Coloca todo el texto importado en el "cuerpo" y no lo separes en la seccin "entrada extendida".');
 @define('SYNDICATION_PLUGIN_FULLFEED', 'Mostrar los artculos completos con la entrada extendida dentro del feed RSS');
 @define('MT_DATA_FILE', 'fichero de datos de Movable Type');
 @define('FORCE', 'Forzar');
@@ -560,7 +567,7 @@
 @define('IMPORT_DONE', 'Importacin completada con xito');
 @define('IMPORT_WEBLOG_APP', 'Aplicacin weblog');
 @define('EXPORT_FEED', 'Exportar la sindicacin RSS completa');
-@define('STATUS', 'Estatus despus de importar');
+@define('STATUS', 'Estado despus de importar');
 @define('IMPORT_GENERIC_RSS', 'Importar RSS genrico');
 @define('ACTIVATE_AUTODISCOVERY', 'Enviar referencias a los enlaces encontrados en la entrada');
 @define('WELCOME_TO_ADMIN', 'Bienvenido a la Suite de Administracin de Serendipity.');
@@ -666,7 +673,7 @@
 @define('USERCONF_REALNAME_DESC', 'El nombre completo del autor. Este es el nombre que vern los lectores.');
 @define('HOTLINK_DONE', 'Fichero como recurso externo enlazado.<br />Hecho.');
 @define('ENTER_MEDIA_URL_METHOD', 'Mtodo de obtencin:');
-@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imgenes externas sin almacernalas localmente. Si escoges esto, asegrate de que tienes permiso para hacerlo en el servidor externo o bien el servidor es tuyo.');
+@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Enlazar recursos externos te permite usar imgenes externas sin almacenarlas localmente. Si escoges esto, asegrate de que tienes permiso para hacerlo en el servidor externo o bien el servidor es tuyo.');
 @define('MEDIA_HOTLINKED', 'enlazado externamente');
 @define('FETCH_METHOD_IMAGE', 'Descargar imagen a tu servidor');
 @define('FETCH_METHOD_HOTLINK', 'Enlazar externamente al servidor');
@@ -686,16 +693,16 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Estructura URL de los enlaces permanentes al autor');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierto autor sean accesibles. Puedes utilizar las variables %id%, %realname%, %username%, %email% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Estructura URL de los enlaces permanentes a categoras');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqu puedes definir la estrutura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categora sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
-@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estructura URL de los enlaces permanentes al RSS-Feed de las categoras');
-@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqu puedes definir la estrutura URL relativa desde la URL base hasta donde los RSS-feeds de ciertas categoras sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categora sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
+@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estructura URL de los enlaces permanentes a la sindicacin RSS de las categoras');
+@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las sindicaciones RSS de ciertas categoras sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Ruta a los archivos');
 @define('INSTALL_PERMALINK_ARCHIVEPATH', 'Ruta para archivar');
 @define('INSTALL_PERMALINK_CATEGORIESPATH', 'Ruta a las categoras');
 @define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Ruta para desinscribirse de los comentarios'); //check later
 @define('INSTALL_PERMALINK_DELETEPATH', 'Ruta para eliminar comentarios');
 @define('INSTALL_PERMALINK_APPROVEPATH', 'Ruta para aprobar comentarios');
-@define('INSTALL_PERMALINK_FEEDSPATH', 'Ruta a los RSS Feeds');
+@define('INSTALL_PERMALINK_FEEDSPATH', 'Ruta a las sindicaciones RSS');
 @define('INSTALL_PERMALINK_PLUGINPATH', 'Ruta a extensin');
 @define('INSTALL_PERMALINK_ADMINPATH', 'Ruta a admin');
 @define('INSTALL_PERMALINK_SEARCHPATH', 'Ruta para buscar');
@@ -783,34 +790,34 @@
 @define('CHARSET_NATIVE', 'Nativo');
 @define('INSTALL_CHARSET', 'Seleccin del juego de caracteres');
 @define('INSTALL_CHARSET_DESC', 'Aqu puedes activar la codificacin de caracteres UTF-8 o nativo (ISO, EUC, ...). Algunos lenguajes slo tienen traducciones UTF-8 as que colocar la codificacin en "nativo" no tendr efectos. Se sugiere UTF-8 en nuevas instalaciones. No alteres la configuracin si ya has hecho entradas con caracteres especiales ya que podra conllevar una corrupcin de caracteres. Asegrate de leer ms sobre este problema en  http://www.s9y.org/index.php?node=46.');
-@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Habilitar API de conecciones de las extensiones');
-@define('CALENDAR_EXTEVENT_DESC', 'Si est habilitada, esta opcin permite que las extensiones se conecten con el calendario para mostrar sus eventos resaltados. Utilizalo slo si has instalado extensiones que lo necesitan, de otra forma slo disminuye el desempeo.');
+@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Habilitar API de conexiones de las extensiones');
+@define('CALENDAR_EXTEVENT_DESC', 'Si est habilitada, esta opcin permite que las extensiones se conecten con el calendario para mostrar sus eventos resaltados. Utilzalo slo si has instalado extensiones que lo necesitan, de otra forma slo disminuye el desempeo.');
 
 
 /*
 Melvin TODO [20060128]: Reorganize (perhaps) next constants in the order they belong
 Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 */
-@define('XMLRPC_NO_LONGER_BUNDLED', 'El API de la interface XML-RPC en Serendipity no est incluida debido a problemas de seguridad que hay en curso con este API, adems del hecho que no es usada con mucha frecuencia. De esta forma, usted necesita instalar el plugin XML-RPC para utilizar API de XML-RPC. Las URL que usa en sus aplicaciones NO cambiarn y tan pronto como instale el plugin podr usar el API.');
+@define('XMLRPC_NO_LONGER_BUNDLED', 'El API de la interfase XML-RPC en Serendipity no est incluido debido a problemas de seguridad que hay en curso con este API, adems del hecho que no es usada con mucha frecuencia. De esta forma, usted necesita instalar la extensin XML-RPC para utilizar API de XML-RPC. Las URL que usa en sus aplicaciones NO cambiarn y tan pronto como instale la extensin podr usar el API.');
 @define('PERM_READ', 'Permiso de lectura');
 @define('PERM_WRITE', 'Permiso de escritura');
 @define('PERM_DENIED', 'Permiso denegado.');
 @define('INSTALL_ACL', 'Aplicar permisos de lectura por categoras');
 @define('INSTALL_ACL_DESC', 'Cuando se activa, son aplicados los permisos para grupos de usuarios que estn configurados cuando los usuarios registrados vean el Blog. Cuando se desactiva, los permisos de lectura de las categoras NO son aplicadas, con el efecto positivo que el Blog carga un poco ms rpido. Si no necesitas permisos de lectura para mltiples usuarios, deshabilita esta opcin.');
-@define('PLUGIN_API_VALIDATE_ERROR', 'Sintaxis erronea en la configuracin de la opcin "%s". Se requiere contenido de tipo "%s".');
+@define('PLUGIN_API_VALIDATE_ERROR', 'Sintaxis errnea en la configuracin de la opcin "%s". Se requiere contenido de tipo "%s".');
 @define('USERCONF_CHECK_PASSWORD', 'Contrasea actual');
 @define('USERCONF_CHECK_PASSWORD_DESC', 'Si cambias la contrasea en el campo de arriba, debes escribir la contrasea actual en este campo.');
-@define('USERCONF_CHECK_PASSWORD_ERROR', 'No especificaste una clave actual correcta, por lo tanto no estas autorizado para establecer una nueva clave. Tus cambios no fueron guardados.');
-@define('ERROR_XSRF', 'To navegador no envi una cadena vlida de HTTP-Referrer. Esto puede deberse a una mala configuracin del navegador/proxy o por un "Cross Site Request Forgery (XSRF)" dirigido a ti. La accin solicitada no pudo ser completada.');
-@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Aqu puedes definir la estructura relativa de URLs comenzando por tu URL base hasta incluso los RSS-Feeds de usuarios especficos que puedan ser vistos. Puedes usar las variables %id%, %realname%, %username%, %email% y cualquier otro carcter.');
-@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Estructura de los Permalinks para los RSS-Feed de autores');
+@define('USERCONF_CHECK_PASSWORD_ERROR', 'No especificaste correctamente la contrasea actual, por lo tanto no estas autorizado para establecer una nueva. Tus cambios no fueron guardados.');
+@define('ERROR_XSRF', 'Tu navegador no envi una cadena vlida de HTTP-Referrer. Esto puede deberse a una mala configuracin del navegador/proxy o por un "Cross Site Request Forgery (XSRF)" dirigido a ti. La accin solicitada no pudo ser completada.');
+@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Aqu puedes definir la estructura relativa de URLs comenzando por tu URL base hasta incluso las sindicaciones RSS de usuarios especficos que puedan ser vistos. Puedes usar las variables %id%, %realname%, %username%, %email% y cualquier otro carcter.');
+@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Estructura de los Enlaces Permanentes para las sindicaciones RSS de autores');
 @define('INSTALL_PERMALINK_AUTHORSPATH', 'Ruta para los autores');
 @define('AUTHORS', 'Autores');
 @define('AUTHORS_ALLOW_SELECT', 'Permitir a los visitantes mostrar mltiples autores al mismo tiempo?');
-@define('AUTHORS_ALLOW_SELECT_DESC', 'Si esta opcin es activada, un checkbox estar al lado de cada autor en en el plugin lateral. Los usuarios pueden seleccionar estas casillas para ver las entradas de acuerdo a su seleccin.');
+@define('AUTHORS_ALLOW_SELECT_DESC', 'Si esta opcin es activada, un checkbox estar al lado de cada autor en en la extensin lateral. Los usuarios pueden seleccionar estas casillas para ver las entradas de acuerdo a su seleccin.');
 @define('AUTHOR_PLUGIN_DESC', 'Muestra una lista de autores');
 @define('CATEGORY_PLUGIN_TEMPLATE', 'Activar Smarty-Templates?');
-@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Si esta opcin es activada, el plugin utiliza las caractersticas de Smarty-Templating para producir el contenido del listado de las categoras. Si activas esto, puedes cambiar el diseo a travs del archivo "plugin_categories.tpl". Toma en cuenta que esta opcin tendr un impacto en el desempeo, si no necesitas diseos particulares, djalo deshabilitado.');
+@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Si esta opcin es activada, la extensin utiliza las caractersticas de Smarty-Templating para producir el contenido del listado de las categoras. Si activas esto, puedes cambiar el diseo a travs del fichero "plugin_categories.tpl". Toma en cuenta que esta opcin tendr un impacto en el desempeo, si no necesitas diseos particulares, djalo deshabilitado.');
 @define('CATEGORY_PLUGIN_SHOWCOUNT', 'Mostrar nmero de entradas por categora?');
 @define('AUTHORS_SHOW_ARTICLE_COUNT', 'Mostrar nmero de artculos del autor?');
 @define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Si esta opcin es activada, el nmero de artculos del autor se muestra al lado del nombre del autor en parntesis.');
@@ -821,3 +828,80 @@ Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 @define('CATEGORIES_HIDE_PARENT', 'Ocular la categora padre seleccionada?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'Si restringes el listado de categoras a una categora especifica, por defecto vers la categora padre (superior) dentro del listado generado. Si deshabilitas esta opcin, el nombre de la categora padre no ser mostrado.');
 @define('WARNING_NO_GROUPS_SELECTED', 'Advertencia: No haz seleccionado ningn grupo de miembros. Esto efectivamente te dejara fuera de la gerencia del grupo de usuarios, por lo tanto, tu membresa de grupo no fue cambiada.');
+@define('INSTALL_RSSFETCHLIMIT', 'Entradas a mostrar en las sindicaciones');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'Nmero de entradas a mostrar por cada pgina.');
+@define('INSTAL_DB_UTF8', 'Activar conversin del juego de caracteres en la BD');
+@define('INSTAL_DB_UTF8_DESC', 'Enva una consulta MySQL "SET NAMES" para definir el juego de caracteres requerido por la base de datos. Actvalo o desactvalo s ves caracteres extraos en tu blog.');
+@define('ONTHEFLYSYNCH', 'Activar sincronizacin de medios al-vuelo');
+@define('ONTHEFLYSYNCH_DESC', 'Si lo activas, Serendipity comparar la base de datos de medios con los archivos almacenados en tu servidor y sincronizar la base de datos con el contenido del directorio.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'No puedes dejar el nombre de usuario en blanco.');
+@define('FURTHER_LINKS', 'Ms enlaces');
+@define('FURTHER_LINKS_S9Y', 'Pgina principal de Serendipity');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Documentacin de Serendipity');
+@define('FURTHER_LINKS_S9Y_BLOG', 'Blog oficial');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'Foros');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(Comentario eliminado)');
+@define('CURRENT_AUTHOR', 'Autor actual');
+@define('WORD_NEW', 'Nuevo');
+@define('SHOW_MEDIA_TOOLBAR', 'Mostrar la barra de herramientas dentro de la ventana emergente seleccin de medios?');
+@define('MEDIA_KEYWORDS', 'Palabras claves de medios');
+@define('MEDIA_KEYWORDS_DESC', 'Ingresa una lista palabras separadas por ";" que quisieras utilizar como palabras clave predefinidas para los elementos de medios.');
+@define('MEDIA_EXIF', 'Importar informacin de imgenes EXIF/JPEG');
+@define('MEDIA_EXIF_DESC', 'Si lo activas, la metadata de las imgenes EXIF/JPEG existentes ser analizada y almacenada en la base de datos para ser mostrada en la galera de medios.');
+@define('MEDIA_PROP', 'Propiedades de Medios');
+@define('GO_ADD_PROPERTIES', 'Ir & ingresar propiedades');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', 'Comentario corto');
+@define('MEDIA_PROPERTY_COMMENT2', 'Comentario extendido');
+@define('MEDIA_PROPERTY_TITLE', 'Ttulo');
+@define('MEDIA_PROP_DESC', 'Ingresa una lista de campos de propiedades separados por ";" que te gustara definir por cada archivo de medios');
+@define('MEDIA_PROP_MULTIDESC', '(Puedes aadir al final de cualquier item ":MULTI" para indicar que contendr una descripcin larga en ves de slo algunos caracteres)');
+@define('STYLE_OPTIONS_NONE', 'Este tema/estilo no tiene opciones especficas. Para ver como tu plantilla puede especificar opciones, lee la documentacin tcnica en www.s9y.org acerca de "Configuracin de las opciones de los estilos".');
+@define('STYLE_OPTIONS', 'Opciones de Tema/estilo');
+@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d extensiones.');
+@define('SYNDICATION_RFC2616', 'Activar seguimiento estricto de la norma RFC2616 para sindicaciones RSS');
+@define('SYNDICATION_RFC2616_DESC', 'NO forzar el seguimiento de RFC2616 significa que todos los GETs condicionales a Serendipity regresarn entradas modificadas desde la fecha de la ltima solicitud. Con esa caracterstica definida a "false", tus visitantes obtendrn todos los artculos desde su ltima solicitud, lo cual es considerado algo bueno. Sin embargo, algunos agentes como Planet tienen un comportamiento extrao, dado viola la norma RFC2616. De esta manera, si defines esta opcin como "TRUE" estars cumpliendo con la norma, pero los lectores de tus sindicaciones RSS quizs pierdan algunas entradas en sus das de ausencia. De cualquier forma, o evitas un funcionamiento adecuado de agregadores como Planet, o daas a tus lectores reales. Si ests enfrentando quejas de cualquiera de los dos, puedes cambiar esta opcin. Rerefencia: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('MEDIA_PROPERTY_DATE', 'Fecha Asociada');
+
+/*Translate*/
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
+/**/
+@define('FILENAME_REASSIGNED', 'Nombre asignado automgicamente al nuevo fichero: %s');
+@define('MEDIA_UPLOAD_SIZE', 'Tamao mximo de los ficheros');//'upload' removed [rlazo]
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Ingresa el tamao mximo en bytes de los ficheros que puedes subir al servidor. Esta opcin puede ser sobreescrita por la configuracin en el servidor en PHP.ini: upload_max_filesize, post_max_size, max_input_time, todas las anteriores tiene precedencia sobre esta opcin. Si la dejas en blanco se usarn slo los lmites definidos en el servidor.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'Error: No puedes subir ficheros de ms de %s bytes!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Ancho mximo de las imgenes'); //'upload' removed [rlazo]
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Ingresa la anchura mxima de las imgenes que se pueden subir al servidor en pixels.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Altura mxima de las imgenes');//'upload' removed [rlazo]
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Ingresa la altura mxima de las imgenes que se pueden subir al servidor en pixels.');
+@define('MEDIA_UPLOAD_DIMERROR', 'Error: No puedes subir imgenes de ms de %s x %s pixels!');
+@define('MEDIA_TARGET', 'Objetivo de este enlace');
+@define('MEDIA_TARGET_JS', 'Ventana emergente (a travs de JavaScript, tamao adaptativo)');
+@define('MEDIA_ENTRY', 'Entrada aislada');
+@define('MEDIA_TARGET_BLANK', 'Ventana emergente (a travs de target=_blank)');
+@define('MEDIA_DYN_RESIZE', 'Permitir redimensionar dinmicamente las imgenes?');
+@define('MEDIA_DYN_RESIZE_DESC', 'Si lo activas, el selector de medios puede regresar imgenes en cualquier tamao solicitado a travs de una variable GET. Los resultados se colocan en la cach, de esta manera puedes crear una base de ficheros muy grande si es que haces un uso intensivo de esta caracterstica.');
+@define('MEDIA_DIRECTORY_MOVED', 'El directorio y los ficheros fueron exitosamente movidos a %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'El directorio y los ficheros no pudieron ser movidos a %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'En bases de datos distintas a MySQL, iterar sobre cada artculo para reemplazar el URL del directorio antiguo con la nueva direccin no es posible. Necesitars que arreglar tus entradas de manera manual. Tambin puedes regresar tu directorio a su ubicacin original si hacer todo aquello te resulta muy incmodo.');
+/*translate*/
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Activa');
+@define('PLUGIN_INACTIVE', 'Inactiva');
+@define('PREFERENCE_USE_JS', 'Activar el uso avanzado de JS?');
+@define('PREFERENCE_USE_JS_DESC', 'Si lo activas, las secciones de JavaScript avanzado sern activadas para una mejor usabilidad, como la extensin de configuracin donde puedes utilizar el mtodo de arrastrar y soltar para reordenar las extensiones.');
+@define('PREFERENCE_USE_JS_WARNING', '(Esta pgina hace uso de JavaScripting avanzado. Si ests teniendo problemas de funcionalidad, por favor desactiva el uso de JS avanzado en tus preferencias personales o desactiva el soporte para JavaScript de tu navegador)');
+/*rlazo [20060722] spell checked*/
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Ruta a los comentarios');
+@define('PERM_SET_CHILD', 'Define los mismos permisos en todos los directorios hijos');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Extensiones prohibidas');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Eventos prohibidos');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Activar la extesin ACL para grupos de usuarios?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Si la opcin "Extensin ACL para grupos de usuarios" es activada en la configuracin, puedes especificar que grupos de usuarios son capaces de ejecutar ciertas extensiones/eventos.');
+@define('DELETE_SELECTED_ENTRIES', 'Eliminar las entradas seleccionadas');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Slo mostrar aquellos autores con al menos X artculos');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
