@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_ja.inc.php 1363 2006-08-09 07:27:09Z elf2000 $
+<?php # $Id: serendipity_lang_ja.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Tadashi Jokagi <elf2000@users.sourceforge.net>, 2004-2005.
@@ -32,8 +32,8 @@
 @define('CREATE_NEW_CAT', '新規カテゴリを作成する');
 @define('I_WANT_THUMB', 'エントリ中でサムネイルを使用したい');
 @define('I_WANT_BIG_IMAGE', 'エントリの中で大きな画像を使用したい');
-@define('I_WANT_NO_LINK', ' 画像としてそれを表示したい');
-@define('I_WANT_IT_TO_LINK', 'それをこの URL へのリンクとして表示したい:');
+@define('I_WANT_NO_LINK', ' 画像として表示したい');
+@define('I_WANT_IT_TO_LINK', 'この URL へのリンクとして表示したい:');
 @define('BACK', '戻る');
 @define('FORWARD', '転送');
 @define('ANONYMOUS', '匿名');
@@ -96,9 +96,9 @@
 @define('SEARCH_FOR_ENTRY', 'エントリの検索');
 @define('ARCHIVES', '書庫一覧');
 @define('BROWSE_ARCHIVES', '月単位の書庫表示');
-@define('TOP_REFERRER', 'トップリファラー');
+@define('TOP_REFERRER', 'トップリファラ一覧');
 @define('SHOWS_TOP_SITES', 'あなたのブログにリンクしたサイトのトップを表示します。');
-@define('TOP_EXITS', 'トップ退出');
+@define('TOP_EXITS', 'トップ退出一覧');
 @define('SHOWS_TOP_EXIT', 'あなたのブログから退出したリンクのトップを表示します。');
 @define('SYNDICATION', '配信');
 @define('SHOWS_RSS_BLAHBLAH', 'RSS 配信のリンクを表示します。');
@@ -352,7 +352,7 @@
 @define('INSTALL_FULLPATH', 'フルパス');
 @define('INSTALL_FULLPATH_DESC', 'serendipity をインストールした絶対フルパスです。');
 @define('INSTALL_UPLOADPATH', 'アップロードパス');
-@define('INSTALL_UPLOADPATH_DESC', 'すべてのアップロードはここに来ます。「フルパス\」への相対パス - 通常「uploads/」です。');
+@define('INSTALL_UPLOADPATH_DESC', 'すべてのアップロードはここに来ます。「フルパス」への相対パス - 通常「uploads/」です。');
 @define('INSTALL_RELPATH', '相対パス');
 @define('INSTALL_RELPATH_DESC', 'ブラウザーで使用する serendipity のパスです。通常「/serendipity/」 です。');
 @define('INSTALL_RELTEMPLPATH', '相対テンプレートパス');
@@ -376,7 +376,7 @@
 @define('INSTALL_SENDMAIL', '管理者にメールを送信しますか?');
 @define('INSTALL_SENDMAIL_DESC', 'エントリにコメントが投稿されたとき、電子メールを受信しますか?');
 @define('INSTALL_SUBSCRIBE', 'ユーザーのエントリの購読を許可しますか?');
-@define('INSTALL_SUBSCRIBE_DESC', 'ユーザーがエントリを購読し、かつ新しいコメントがそのエントリへ作られた場合、そのメイルを受け取ることを許可します。');
+@define('INSTALL_SUBSCRIBE_DESC', 'ユーザーがエントリを購読し、かつ新しいコメントがそのエントリへ作られた場合、そのメールを受け取ることを許可します。');
 @define('INSTALL_BLOGNAME', 'ブログの名前');
 @define('INSTALL_BLOGNAME_DESC', 'ブログの題名を記述します。');
 @define('INSTALL_BLOGDESC', 'ブログの説明');
@@ -398,7 +398,7 @@
 @define('INSTALL_TOP_AS_LINKS', 'トップの退出/リファラーをリンクとして表示しますか?');
 @define('INSTALL_TOP_AS_LINKS_DESC', '"いいえ": google スパムを防ぐために退出とリファラーをただのテキストとして表示します。"はい": 退出とリファラーをハイパーリンクとして表示します。"デフォルト": 一般設定をの設定を使用します(推奨)');
 @define('INSTALL_BLOCKREF', 'リファラーブロック');
-@define('INSTALL_BLOCKREF_DESC', 'Are there any special hosts you want not to show up in the referers list? ホスト名の一覧を「;」で列挙し、そのホスト名が部分一致でブロックされることに注意してください!');
+@define('INSTALL_BLOCKREF_DESC', 'リファラー一覧で表示しないことを希望する特殊なホストがありますか? ホスト名の一覧を「;」で列挙し、そのホスト名が部分一致でブロックされることに注意してください!');
 @define('INSTALL_REWRITE', 'URL 書き換え');
 @define('INSTALL_REWRITE_DESC', 'URL を生成するときに使用するルールを選択します。書き換えルールを有効にさせることで、ウェブログに対してきれいな URL を作成し、google のようなスパイダーはよりよいインデックスを作成します。ウェブサーバーは、serendipity ディレクトリに対して、mod_rewrite あるいは「AllowOverride All」のいずれかをサポートする必要があります。デフォルト設定は自動車検知されます。');
 
@@ -422,7 +422,7 @@
 @define('USERCONF_PASSWORD', 'パスワード');
 @define('USERCONF_PASSWORD_DESC', 'ブログにログインするときに使うパスワードを指定します。');
 @define('USERCONF_EMAIL', '電子メールアドレス');
-@define('USERCONF_EMAIL_DESC', '個人の電子メールアドレスをしていします。');
+@define('USERCONF_EMAIL_DESC', '個人の電子メールアドレスを指定します。');
 @define('USERCONF_SENDCOMMENTS', 'コメントの通知を送信しますか?');
 @define('USERCONF_SENDCOMMENTS_DESC', 'コメントをあなたのエントリが受けたとき、電子メールを受信しますか?');
 @define('USERCONF_SENDTRACKBACKS', 'トラックバックの通知を送信しますか?');
@@ -722,7 +722,7 @@
 @define('PLUGIN_GROUP_FRONTEND_FEATURES', 'フロントエンド: 機能');
 @define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'フロントエンド: Full Mods');
 @define('PLUGIN_GROUP_FRONTEND_VIEWS', 'フロントエンド: 閲覧');
-@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'フロントエン: エントリー関連');
+@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'フロントエンド: エントリー関連');
 @define('PLUGIN_GROUP_BACKEND_EDITOR', 'バックエンド: エディタ');
 @define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'バックエンド: ユーザー管理');
 @define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'バックエンド: メタ情報');
@@ -738,26 +738,26 @@
 @define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', '個人の公開権限設定: エントリを公開する権限の変更');
 @define('PERMISSION_SITECONFIGURATION', 'サイト設定: システム設定のアクセス');
 @define('PERMISSION_BLOGCONFIGURATION', 'ブログ設定: ブログの中心設定のアクセス');
-@define('PERMISSION_ADMINENTRIES', 'adminEntries: エントリの管理');
-@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: 他ユーザーのエントリの管理');
+@define('PERMISSION_ADMINENTRIES', 'エントリ管理: エントリの管理');
+@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', '他ユーザー保持エントリの管理: 他ユーザーのエントリの管理');
 @define('PERMISSION_ADMINIMPORT', 'インポート管理: エントリのインポート');
 @define('PERMISSION_ADMINCATEGORIES', 'カテゴリ管理: カテゴリの管理');
-@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: 他ユーザーのカテゴリの管理');
+@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', '他ユーザー保持カテゴリの管理: 他ユーザーのカテゴリの管理');
 @define('PERMISSION_ADMINCATEGORIESDELETE', 'カテゴリ削除管理: カテゴリの削除');
 @define('PERMISSION_ADMINUSERS', 'ユーザー管理: ユーザーの管理');
 @define('PERMISSION_ADMINUSERSDELETE', 'ユーザー削除管理: ユーザーの削除');
 @define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'ユーザーのユーザーレベル編集管理: ユーザーレベルの変更');
-@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: グループに居るユーザーの管理');
-@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: グループに居ないユーザーの管理');
+@define('PERMISSION_ADMINUSERSMAINTAINSAME', '同じユーザーの管理: グループに居るユーザーの管理');
+@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', '他のユーザーの管理: グループに居ないユーザーの管理');
 @define('PERMISSION_ADMINUSERSCREATENEW', '新規ユーザー作成管理: 新規ユーザーの作成');
 @define('PERMISSION_ADMINUSERSGROUPS', 'ユーザーグループ管理: ユーザーグループの管理');
 @define('PERMISSION_ADMINPLUGINS', 'プラグイン管理: プラグイン管理');
-@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: 他ユーザーのプラグインの管理');
+@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', '他ユーザー保持のプラグインの管理: 他ユーザーのプラグインの管理');
 @define('PERMISSION_ADMINIMAGES', '画像管理: メディアファイルの管理');
 @define('PERMISSION_ADMINIMAGESDIRECTORIES', '画像ディレクトリ管理: メディアディレクトリの管理');
 @define('PERMISSION_ADMINIMAGESADD', '画像追加管理: 新規メディアファイルの追加');
 @define('PERMISSION_ADMINIMAGESDELETE', '画像削除管理: メディアファイルの削除');
-@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: 他ユーザーのメディアファイルの管理');
+@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', '他ユーザー保持画像の管理: 他ユーザーのメディアファイルの管理');
 @define('PERMISSION_ADMINIMAGESVIEW', '画像閲覧管理: メディアファイルの閲覧');
 @define('PERMISSION_ADMINIMAGESSYNC', '画像同期管理: サムネイル同期');
 @define('PERMISSION_ADMINCOMMENTS', 'コメント管理: コメント管理');
@@ -774,7 +774,7 @@
 @define('INSTALL_CHARSET_DESC', 'ここは  UTF-8 かネイティブ(ISO・EUC など)の文字コードを切り替えることができます。「ネイティブ」に文字エンコード設定することに変化がないように、いくつかの言語は UTF-8 のみ翻訳を持っています。UTF-8 は新規インストールで提案されます。特殊文字で既にエントリを作っている場合は、この設定を変更しないでください - これは不正な文字を導くかもしれません。必ずこの問題に関すしては http://www.s9y.org/index.php?node=46 をさらに読んでください。 訳注: 日本語は文字エンコードは UTF-8 のみ用意されています。');
 @define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'プラグインの API フックを有効にする');
 @define('CALENDAR_EXTEVENT_DESC', 'If enabled, plugins can hook into the calendar to display their own events highlighted. Only enable if you have installed plugins that need this, otherwise it just decreases performance.');
-@define('XMLRPC_NO_LONGER_BUNDLED', 's9yへのXML-RPC APIインタフェースは、もはやそれを使用して、このAPIを含めた進行中のセキュリティ問題および多くでない人々のためにバンドルされません。Serendioity の XML-RPC API インターフェースは、ずっと続いくセキュリティの問題と、この API を多くの人が使用していないため、もはやバンドルされていません。したがって、XML-RPC APIを使用するためにXML-RPCプラグインをインストールする必要があります。アプリケーション中で使用するURLは変わりません。プラグインをインストールしたらすぐに、再びAPIを使用することができるでしょう。');
+@define('XMLRPC_NO_LONGER_BUNDLED', 's9y への XML-RPC API インタフェースは、もはやそれを使用して、この API を含めた進行中のセキュリティ問題および多くでない人々のためにバンドルされません。Serendipity の XML-RPC API インターフェースは、ずっと継続するセキュリティの問題と、この API を多くの人が使用していないため、もはやバンドルされていません。したがって、XML-RPC API を使用するために XML-RPC プラグインをインストールする必要があります。アプリケーション中で使用する URL は変わりません。プラグインをインストールしたらすぐに、再び API を使用することができるでしょう。');
 @define('PERM_READ', '読み込み権限');
 @define('PERM_WRITE', '書き込み権限');
 
@@ -785,7 +785,7 @@
 @define('USERCONF_CHECK_PASSWORD', '古いパスワード');
 @define('USERCONF_CHECK_PASSWORD_DESC', '上の項目でパスワードを変更する場合、この項目に現在のユーザーパスワードを入力する必要があります。');
 @define('USERCONF_CHECK_PASSWORD_ERROR', '正しい古いパスワードを指定せず、新しいパスワードを変更することは許可されていません．設定は保存されませんでした。');
-@define('ERROR_XSRF', 'ブラウザーは有効な HTTP-Referrer 文字列を送信しませんでした。これは誤設定されたブラウザー/プロクシ、あるいはあなたに向けたCross Site Request Forgery(XSRF)を引き起ここすかどちらかかもしれません。要求した操作は完了できませんでした。');
+@define('ERROR_XSRF', 'ブラウザーは有効な HTTP-Referrer 文字列を送信しませんでした。これは誤設定されたブラウザー/プロクシ、あるいはあなたに向けた Cross Site Request Forgery(XSRF)を引き起ここすかどちらかかもしれません。要求した操作は完了できませんでした。');
 
 @define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'ここで、ベース URL からある特定のユーザーの RSS フィード が入手可能になる、適当な場所への相対的な URL 構造の先頭を定義することができます。変数は、%id%、%realname%、%username%、%email%、そして他の文字を使用することができます。 ');
 @define('INSTALL_PERMALINK_FEEDAUTHOR', '固定リンク の RSS フィードの著者 URL 構造');
@@ -806,4 +806,87 @@
 @define('INSTALL_TRACKREF_DESC', 'Enabling the referrer tracking will show you which sites refer to your articles. Today this is often abused for spamming, so you can disable it if you want.');
 @define('CATEGORIES_HIDE_PARENT', '選択された親カテゴリを隠しますか?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'If you restrict the listing of categories to a specific category, by default you will see that parent category within the output listing. If you disable this option, the parent category name will not be displayed.');
-@define('WARNING_NO_GROUPS_SELECTED', 'Warning: You did not select any group memberships. This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
+@define('WARNING_NO_GROUPS_SELECTED', '警告: いくつかのグループメンバーを選択していません。This would effectively log you out of the usergroup management, and thus your group memberships werde not changed.');
+@define('INSTALL_RSSFETCHLIMIT', 'フィードに表示するエントリ数');
+@define('INSTALL_RSSFETCHLIMIT_DESC', '各ページでRSSフィードに表示するエントリの数です。');
+@define('INSTAL_DB_UTF8', 'データベース文字エンコード変換を有効にする');
+@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
+@define('ONTHEFLYSYNCH', 'オンザフライメディアの同期を有効にする');
+@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'ユーザー名は空にできません。');
+@define('FURTHER_LINKS', 'Further Links');
+@define('FURTHER_LINKS_S9Y', 'Serendipity ホームページ');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity ドキュメント');
+@define('FURTHER_LINKS_S9Y_BLOG', 'オフィシャルブログ');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'フォーラム');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(コメントは削除されました)');
+
+@define('CURRENT_AUTHOR', '現在の著者');
+
+@define('WORD_NEW', '新規');
+@define('SHOW_MEDIA_TOOLBAR', 'メディア選択ポップアップでツールバーを表示しますか?');
+@define('MEDIA_KEYWORDS', 'メディアキーワード');
+@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
+@define('MEDIA_EXIF', 'EXIF/JPEG 画像データをインポートする');
+@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
+@define('MEDIA_PROP', 'メディアプロパティ');
+
+
+@define('GO_ADD_PROPERTIES', 'Go & enter properties');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
+@define('MEDIA_PROPERTY_COMMENT1', '短いコメント');
+@define('MEDIA_PROPERTY_COMMENT2', '長いコメント');
+@define('MEDIA_PROPERTY_TITLE', '件名');
+@define('MEDIA_PROP_DESC', '各メディアファイルに定義したいプロパティ項目を「;」で分割した一覧で入力します');
+@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');
+
+@define('STYLE_OPTIONS_NONE', 'このテーマ・スタイルは指定オプションがありません。To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
+@define('STYLE_OPTIONS', 'テーマスタイルオプション');
+
+@define('PLUGIN_AVAILABLE_COUNT', '合計: %d プラグインです。');
+
+@define('SYNDICATION_RFC2616', '厳密に RFC2616 に準拠した RSS フィードを動作させる');
+@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also vioaltes RFC2616. So if you set this option to "TRUE" you will compliy with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. リファレンス: https://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('MEDIA_PROPERTY_DATE', '関連した日付');
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
+@define('FILENAME_REASSIGNED', '次の新規ファイル名が自動割当されました: %s');
+@define('MEDIA_UPLOAD_SIZE', 'ファイルアップロードの最大容量');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'エラー: %s バイトより大きなファイルはアップロードできません!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'アップロードされたファイルの最大幅');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'アップロードされた画像の最大幅をピクセル単位で入力します。');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'アップロードされたファイルの最大高');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'アップロードされた画像の最大の高さをピクセル単位で入力します。');
+@define('MEDIA_UPLOAD_DIMERROR', 'エラー: %s x %s ピクセルより大きな画像はアップロードできません!');
+
+@define('MEDIA_TARGET', 'このリンクのターゲット');
+@define('MEDIA_TARGET_JS', 'ポップアップウィンドウ (via JavaScript, adaptive size)');
+@define('MEDIA_ENTRY', 'Isolated Entry');
+@define('MEDIA_TARGET_BLANK', 'ポップアップウィンドウ (「target=_blank」による)');
+
+@define('MEDIA_DYN_RESIZE', '動的な画像のサイズ変更を許可しますか?');
+@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');
+
+@define('MEDIA_DIRECTORY_MOVED', 'ディレクトリとファイルを「%s」に移動することに成功しました。');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'ディレクトリとファイルを「%s」に移動できませんでした!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');@define('PLUGIN_ACTIVE', 'Active');
+@define('PLUGIN_INACTIVE', 'Inactive');
+@define('PREFERENCE_USE_JS', '高度な JS の使用を有効にしますか?');
+@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(このページは高度な JavaScript を使用しています。もし機能に問題がある場合、個人プリファレンスの高度な JS の使用を無効にするか、ブラウザーの JavaScript を無効にしてください)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'パスへのコマンド');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
