@@ -1,9 +1,9 @@
-<?php # $Id: serendipity_lang_en.inc.php 1150 2006-04-24 17:39:59Z garvinhicking $
+<?php # $Id: serendipity_lang_en.inc.php 1252 2006-06-09 20:17:14Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 /* vim: set sts=4 ts=4 expandtab : */
 
-@define('LANG_CHARSET', 'UTF-8');
+@define('LANG_CHARSET', 'ISO-8859-2');
 @define('SQL_CHARSET', 'utf8');
 @define('DATE_LOCALES', 'pl-UTF-8, pl-UTF8, pl_PL-UTF-8, pl_PL-UTF8, pl.UTF8, pl_PL.UTF8, polish, pl, pl_PL');
 @define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@@ -148,9 +148,9 @@
 @define('PASSWORD', 'Haso');
 @define('AUTOMATIC_LOGIN', 'Zapisz dane');
 @define('SERENDIPITY_INSTALLATION', 'Instalacja Serendipity');
-@define('LEFT', 'lewa');
-@define('RIGHT', 'prawa');
-@define('HIDDEN', 'ukryta');
+@define('LEFT', 'Lewy panel');
+@define('RIGHT', 'Prawy panel');
+@define('HIDDEN', 'Wtyczka ukryta');
 @define('REMOVE_TICKED_PLUGINS', 'Usu zaznaczone wtyczki');
 @define('SAVE_CHANGES_TO_LAYOUT', 'Zapisz zmiany w layoucie');
 @define('COMMENTS_FROM', 'Formularz komentarzy');
@@ -306,6 +306,7 @@
 @define('ENTRIES_PER_PAGE', 'Wpisw na stron');
 @define('XML_IMAGE_TO_DISPLAY', 'XML Button');
 @define('XML_IMAGE_TO_DISPLAY_DESC','Linki do feedw XML bd pokazywane za pomoc tego obrazka. Pozostaw puste pole dla ustawie domylnych lub wpisz \'none\' aby nie pokazywa obrazka.');
+
 @define('DIRECTORIES_AVAILABLE', 'Na licie dostpnych podkatalogw moesz klikn na dowolnym katalogu by stworzy nowy katalog w tej strukturze.');
 @define('ALL_DIRECTORIES', 'wszystkie katalogi');
 @define('MANAGE_DIRECTORIES', 'Katalogi');
@@ -478,7 +479,7 @@
 @define('ENTER_MEDIA_UPLOAD', 'Wybierz plik do uploadu:');
 @define('SAVE_FILE_AS', 'Zapisz plik jako:');
 @define('STORE_IN_DIRECTORY', 'Zapisz w nastpujcym katalogu: ');
-@define('ADD_MEDIA_BLAHBLAH', '<b>Dodaj plik do zbioru mediw:</b><p>Tu moesz uploadowa pliki z mediami lub wskaza jakie pliki dostpne w sieci! Jeli nie masz odpowiedniego obrazka, <a href="http://images.google.com" target="_blank">znajd w serwisie Google</a> obrazki, ktre by moe bd Ci odpowiaday. Rezultaty wyszukiwania s czsto przydatne i zabawne :) Ale uwaaj! Wikszo obrazkw ma zastrzeone prawa autorskie i powiniene (powinna) zapyta si o pozwolenie przed ich uyciem!</p><p><b>Wybierz metod:</b></p><br/>');
+@define('ADD_MEDIA_BLAHBLAH', '<b>Dodaj plik do zbioru mediw:</b><p>Tu moesz uploadowa pliki z mediami lub wskaza jakie pliki dostpne w sieci! Jeli nie masz odpowiedniego obrazka, <a href="http://images.google.com" target="_blank">znajd w serwisie Google</a> obrazki, ktre by moe bd Ci odpowiaday. Rezultaty wyszukiwania s czsto przydatne i zabawne :) Ale uwaaj! Wikszo obrazkw ma zastrzeone prawa autorskie i powiniene (powinna) zapyta si o pozwolenie przed ich uyciem!</p><p><b>Wybierz metod:</b></p><br />');
 @define('MEDIA_RENAME', 'Zmien nazw pliku');
 @define('IMAGE_RESIZE', 'Zmie rozmiar obrazka');
 @define('MEDIA_DELETE', 'Usu ten plik');
@@ -562,14 +563,14 @@
 @define('INSTALL_USEGZIP_DESC', 'Aby przyspieszy wysyanie stron do uytkownika moesz uy kompresji gzip (zakadajc, e przegldarka uytkownika obsuguje kompresj gzip - znakomita wikszo obsuguje). To ustawienie jest rekomendowane.');
 @define('INSTALL_SHOWFUTURE', 'Pokazuj przysze wpisy');
 @define('INSTALL_SHOWFUTURE_DESC', 'Jeli opcja zostanie wczona, bd pokazywane wszystkie przysze wpisy (wpisy z ustawion dat przysz). Standardowo wpisy te s ukryte do czasu nadejcia czasu ich wywietlenia.');
-@define('INSTALL_DBPERSISTENT', 'Use persistent connections');
-@define('INSTALL_DBPERSISTENT_DESC', 'Enable the usage of persistent database connections, read more <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">here</a>. This is normally not recommended');
+@define('INSTALL_DBPERSISTENT', 'Uywaj staych pocze z baz danych');
+@define('INSTALL_DBPERSISTENT_DESC', 'Zezwl na uywanie staych pocze z baz danych, wicej <a href="http://pl.php.net/manual/pl/features.persistent-connections.php" target="_blank">tutaj</a>. Wczenie tej opcji nie jest zalecane.');
 @define('NO_IMAGES_FOUND', 'Nie znaleziono obrazkw');
 @define('PERSONAL_SETTINGS', 'Ustawienie osobiste');
 @define('REFERER', 'Referer');
-@define('NOT_FOUND', 'Not found');
-@define('WRITABLE', 'Writable');
-@define('NOT_WRITABLE', 'Not writable');
+@define('NOT_FOUND', 'Nie znaleziono');
+@define('WRITABLE', 'Zapisywalny');
+@define('NOT_WRITABLE', 'Niezapisywalny');
 @define('PROBLEM_DIAGNOSTIC', 'Z powodu problemw, ktre zostay rozpoznane podczas przeprowadzania procedur diagnostycznych, nie moesz kontynuowa instalacji dopki powysze problemy nie zostan usunite.');
 @define('SELECT_INSTALLATION_TYPE', 'Wybierz metod instalacji');
 @define('WELCOME_TO_INSTALLATION', 'Witaj w Instalacji Serendipity');
@@ -583,8 +584,8 @@
 @define('ACTUAL', 'Aktualne');
 @define('PHPINI_CONFIGURATION', 'konfiguracja php.ini');
 @define('PHP_INSTALLATION', 'Instalacja PHP');
-@define('THEY_DO', 'they do');
-@define('THEY_DONT', 'they do not');
+@define('THEY_DO', 'istniej');
+@define('THEY_DONT', 'nie istniej');
 @define('SIMPLE_INSTALLATION', 'Prosta instalacja');
 @define('EXPERT_INSTALLATION', 'Instalacja w trybie Eksperta');
 @define('COMPLETE_INSTALLATION', 'Pena instalacja');
@@ -816,7 +817,9 @@
 @define('FURTHER_LINKS_S9Y_FORUMS', 'Forum');
 @define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
 @define('COMMENT_IS_DELETED', '(Komentarz usunity)');
+
 @define('CURRENT_AUTHOR', 'Biecy Autor');
+
 @define('WORD_NEW', 'Nowy');
 @define('SHOW_MEDIA_TOOLBAR', 'Czy pokazywa pasek narzdziowy w oknie wyboru mediw?');
 @define('MEDIA_KEYWORDS', 'Sowa kluczowe mediw');
@@ -824,6 +827,8 @@
 @define('MEDIA_EXIF', 'Importuj dane EXIF/JPEG obrazkw/zdj');
 @define('MEDIA_EXIF_DESC', 'Jeli opcja zostanie wczona, zapisane w plikach z obrazkami/zdjciami dane EXIF/JPEG zostan zachowane w bazie danych i wykorzystane przy wywietlaniu w Bibliotece mediw.');
 @define('MEDIA_PROP', 'Waciwoci');
+
+
 @define('GO_ADD_PROPERTIES', 'Dodaj i wprowad waciwoci');
 @define('MEDIA_PROPERTY_DPI', 'DPI');
 @define('MEDIA_PROPERTY_COPYRIGHT', 'Prawa autorskie (Copyright)');
@@ -864,3 +869,21 @@
 @define('MEDIA_DIRECTORY_MOVE_ERROR', 'Katalog i pliki nie mogy by przeniesione do %s!');
 @define('MEDIA_DIRECTORY_MOVE_ENTRY', 'W bazach innych ni MySQL przeprowadzenie zmiany URLI ze sciek do starego katalogu na URLe ze ciek do nowego katalogu NIE jest moliwe. Musisz przeprowadzi te zmiany rcznie. Zawsze moesz przenie katalog w jego pierwotne miejsce jeli uznasz, e rczna edycja byaby zbyt nieporcznym rozwizaniem.');
 @define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Zmieniono URL do przeniesionego katalogu w %s wpisach.');
+@define('PLUGIN_ACTIVE', 'Wtyczki aktywne');
+@define('PLUGIN_INACTIVE', 'Wtyczki nieaktywne');
+@define('PREFERENCE_USE_JS', 'Zezwoli na uywanie zaawansowanych skryptw JavaScript?');
+@define('PREFERENCE_USE_JS_DESC', 'Jeli wczone, zaawansowane skrypty JavaScript bd uruchamiane dla zwikszenia komfortu uywalnoci, np. w module Konfiguracji wtyczek moesz administarowa wtyczkami za pomoc myszy przez ich swobodne przesuwanie jak w technologii "drag and drop" (przecignij i upu).');
+
+@define('PREFERENCE_USE_JS_WARNING', '(Ta strona uywa zaawansowanych skryptw JavaScript. Jeli masz problemy z funkcjonowaniem tej strony, wycz uywanie zaawansowanych skryptw JavaScript w swoich Ustawieniach osobistych lub wycz wspracie dla JavaScript w swojej przegldarce.)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
