@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 1251 2006-06-09 20:16:09Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 1515 2006-11-22 10:30:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -775,7 +775,8 @@ $i18n_unknown = 'tw';
 @define('INSTALL_CHARSET_DESC', 'o̥iHzഫ UTF-8 ιw]yt (ISO, EUC, ...)Cǻyu UTF-8 ytɡAҥHw]yt|ܥFCsw˪xĳϥ UTF-8 ytCOonܳoӳ]wpGzwgoGF峹CԱЬ http://www.s9y.org/index.php?node=46C');
 @define('CALENDAR_ENABLE_EXTERNAL_EVENTS', '}ҥ~ API');
 @define('CALENDAR_EXTEVENT_DESC', 'pG}ҡA~iHb䤺HC㥦ƥCpGSϥγoǯS~AĳnϥΡC');
-@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API \w[b s9y w˸̡A]|}MhHϥΪYCҥHzw XML-RPC ~pGnϥ XML-RPC APICҦ URL |]ܡAw˳oӥ~iHWϥΡC');@define('PERM_READ', 'Read permission');
+@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API \w[b s9y w˸̡A]|}MhHϥΪYCҥHzw XML-RPC ~pGnϥ XML-RPC APICҦ URL |]ܡAw˳oӥ~iHWϥΡC');
+@define('PERM_READ', 'Read permission');
 @define('PERM_READ', 'Ūv');
 @define('PERM_WRITE', 'gJv');
 
@@ -806,4 +807,87 @@ $i18n_unknown = 'tw';
 @define('INSTALL_TRACKREF_DESC', '}ҰOӷ|ܭӺޥΤFz峹CziHoӥ\pGӦhUsiC');
 @define('CATEGORIES_HIDE_PARENT', 'ÿܪOH');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'zOܪCAw]O|ܥOW١CpGzoӥ\AOWٱN|ܡC');
-@define('WARNING_NO_GROUPS_SELECTED', 'ĵiGzSܷ|sաCo|NznXsժ޲zA|sդ|QܡC');
\ No newline at end of file
+@define('WARNING_NO_GROUPS_SELECTED', 'ĵiGzSܷ|sաCo|NznXsժ޲zA|sդ|QܡC');
+@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'RSS Feed ܪ峹ƶqC');
+@define('INSTAL_DB_UTF8', '}ҸƮwsXഫ');
+@define('INSTAL_DB_UTF8_DESC', 'ϥ MySQL  "SET NAMES" dߨӳ]wsXCpG峹X{ýXiHNoӳ]w}C');
+@define('ONTHEFLYSYNCH', '}ҧYɪCPB');
+@define('ONTHEFLYSYNCH_DESC', 'pG}ҡASerendipity |ƮwMCؿɮסAMiƦPBC');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'bťաC');
+@define('FURTHER_LINKS', 'hs');
+@define('FURTHER_LINKS_S9Y', 'Serendipity ');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity ');
+@define('FURTHER_LINKS_S9Y_BLOG', 'xx');
+@define('FURTHER_LINKS_S9Y_FORUMS', '׾');
+@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
+@define('COMMENT_IS_DELETED', '(jTwQ)');
+
+@define('CURRENT_AUTHOR', 'ثe@');
+
+@define('WORD_NEW', 's');
+@define('SHOW_MEDIA_TOOLBAR', 'bܴC骺ܤuH');
+@define('MEDIA_KEYWORDS', 'C骺r');
+@define('MEDIA_KEYWORDS_DESC', 'Jw]CrA ";" Ӥ}CrC');
+@define('MEDIA_EXIF', 'J EXIF/JPEG Ϥ');
+@define('MEDIA_EXIF_DESC', 'pG}ҡAEXIF/JPEG ɸ̪ metadata |۰xsƮwC');
+@define('MEDIA_PROP', 'C餺e');
+
+
+@define('GO_ADD_PROPERTIES', 'Je');
+@define('MEDIA_PROPERTY_DPI', 'DPI');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'v');
+@define('MEDIA_PROPERTY_COMMENT1', 'u');
+@define('MEDIA_PROPERTY_COMMENT2', '');
+@define('MEDIA_PROPERTY_TITLE', 'D');
+@define('MEDIA_PROP_DESC', 'JCϥΪeA ";" Ӥ}C쪺W');
+@define('MEDIA_PROP_MULTIDESC', '(ziHbW٫᭱[W ":MULTI" ӳ]w[jr)');
+
+@define('STYLE_OPTIONS_NONE', 'oӧGSSOﶵCpGnbzG̥[WﶵAЬ www.s9y.org  Technical DocumentationAM "Configuration of Theme options"C');
+@define('STYLE_OPTIONS', 'Gﶵ');
+
+@define('PLUGIN_AVAILABLE_COUNT', '`@G %d ӥ~C');
+
+@define('SYNDICATION_RFC2616', '}Ҩ̷Y檺 RFC2616 RSS-Feed');
+@define('SYNDICATION_RFC2616_DESC', 'j RFC2616 ܥ GETs  Serendipity u|Ǧ^̫ק諸峹CpG]w "false" ܳXȷ|峹CLA@Ǻx`n鹳 Planet |X{_ǲ{HCpGX{_ǲ{HܥHϤF RFC2616 зǡCҥH]w "TRUE" ܧAq RFC зǡAOXȥi|Ū峹CӻAޫ˳LkUCTGhttps://sourceforge.net/tracker/index.php?func=detail&aid=1461728&group_id=75065&atid=542822');
+@define('MEDIA_PROPERTY_DATE', '');
+@define('MEDIA_PROPERTY_RUN_LENGTH', '');
+@define('FILENAME_REASSIGNED', '۰ʫwsɮתW١G %s');
+@define('MEDIA_UPLOAD_SIZE', 'ɮפjpW');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Jɮת̤jȡCoӳ]w]iHqD PHP.ini ɮקܡG upload_max_filesize, post_max_size, max_input_time o̪]wLġCpGJܿqDC');
+@define('MEDIA_UPLOAD_SIZEERROR', '~GzWǤj %s 줸ժɮסI');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Ϥ̤je');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'JWǪϤ̤jeסC');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Ϥ̤j');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'JWǪϤ̤jסC');
+@define('MEDIA_UPLOAD_DIMERROR', '~GzWǤj %s x %s ϤI');
+
+@define('MEDIA_TARGET', 'sؼ');
+@define('MEDIA_TARGET_JS', 'uX (ϥ JavaScript)');
+@define('MEDIA_ENTRY', 'j峹');
+@define('MEDIA_TARGET_BLANK', 'uX (ϥ target=_blank)');
+
+@define('MEDIA_DYN_RESIZE', '\ܹϤjpH');
+@define('MEDIA_DYN_RESIZE_DESC', 'pG}ҡAC骺̷ܵ|ܨ̷ GET ܼƩҳ]wϤjpCϤ|xs֨O餺AҥH`ϥη|ΥDŶC');
+@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
+@define('PLUGIN_ACTIVE', 'Active');
+@define('PLUGIN_INACTIVE', 'Inactive');
+@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
+@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+
+@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+
+
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
+@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
+@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
