@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 690 2005-11-13 04:49:04Z elf2000 $
+﻿<?php # $Id: lang_pl.inc.php 1549 2006-12-20 18:26:51Z garvinhicking $
 
 /**
- *  @version $Revision: 690 $
+ *  @version $Revision: 1549 $
  *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -9,5 +9,4 @@
 @define('PLUGIN_EVENT_BBCODE_NAME',     'Znacznik: BBCode');
 @define('PLUGIN_EVENT_BBCODE_DESC',     'Przekształcaj tekst stosując tagi BBCode');
 @define('PLUGIN_EVENT_BBCODE_TRANSFORM', '<a href="http://www.phpbb.com/phpBB/faq.php?mode=bbcode">BBCode</a> format dozwolony');
-
-?>
+@define('PLUGIN_EVENT_BBCODE_TARGET',   'Używać target="blank" dla linków?');
