@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spamblock.php 1529 2006-12-01 09:07:52Z garvinhicking $
+<?php # $Id: serendipity_event_spamblock.php 1528 2006-12-01 08:58:47Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -39,7 +39,7 @@ var $filter_defaults;
             'smarty'      => '2.6.7',
             'php'         => '4.1.0'
         ));
-        $propbag->add('version',       '1.52');
+        $propbag->add('version',       '1.61');
         $propbag->add('event_hooks',    array(
             'frontend_saveComment' => true,
             'external_plugin'      => true,
@@ -54,10 +54,14 @@ var $filter_defaults;
             'bodyclone',
             'entrytitle',
             'ipflood',
+            'csrf',
             'captchas',
             'captchas_ttl',
             'captcha_color',
             'forcemoderation',
+            'forcemoderation_treat',
+            'forcemoderationt',
+            'forcemoderationt_treat',
             'disable_api_comments',
             'trackback_check_url',
             'links_moderate',
@@ -115,6 +119,13 @@ var $filter_defaults;
                 $propbag->add('default', false);
                 break;
 
+            case 'csrf':
+                $propbag->add('type', 'boolean');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_CSRF);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_CSRF_DESC);
+                $propbag->add('default', true);
+                break;
+
             case 'entrytitle':
                 $propbag->add('type', 'boolean');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FILTER_TITLE);
@@ -302,6 +313,37 @@ var $filter_defaults;
                 $propbag->add('default', '30');
                 break;
 
+            case 'forcemoderation_treat':
+                $propbag->add('type', 'radio');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION_TREAT);
+                $propbag->add('description', '');
+                $propbag->add('default', 'moderate');
+                $propbag->add('radio', array(
+                    'value' => array('moderate', 'reject'),
+                    'desc'  => array(PLUGIN_EVENT_SPAMBLOCK_API_MODERATE, PLUGIN_EVENT_SPAMBLOCK_API_REJECT)
+                ));
+                $propbag->add('radio_per_row', '1');
+                break;
+
+            case 'forcemoderationt':
+                $propbag->add('type', 'string');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATIONT);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATIONT_DESC);
+                $propbag->add('default', '30');
+                break;
+
+            case 'forcemoderationt_treat':
+                $propbag->add('type', 'radio');
+                $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATIONT_TREAT);
+                $propbag->add('description', '');
+                $propbag->add('default', 'moderate');
+                $propbag->add('radio', array(
+                    'value' => array('moderate', 'reject'),
+                    'desc'  => array(PLUGIN_EVENT_SPAMBLOCK_API_MODERATE, PLUGIN_EVENT_SPAMBLOCK_API_REJECT)
+                ));
+                $propbag->add('radio_per_row', '1');
+                break;
+
             case 'links_moderate':
                 $propbag->add('type', 'string');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE);
@@ -530,6 +572,10 @@ var $filter_defaults;
             $show_captcha = ($captchas && isset($eventData['timestamp']) && ($captchas_ttl < 1 || ($eventData['timestamp'] < (time() - ($captchas_ttl*60*60*24)))) ? true : false);
 
             $forcemoderation = $this->get_config('forcemoderation', 60);
+            $forcemoderation_treat = $this->get_config('forcemoderation_treat', 'moderate');
+            $forcemoderationt = $this->get_config('forcemoderationt', 60);
+            $forcemoderationt_treat = $this->get_config('forcemoderationt_treat', 'moderate');
+
             $links_moderate  = $this->get_config('links_moderate', 10);
             $links_reject    = $this->get_config('links_reject', 20);
 
@@ -563,6 +609,15 @@ var $filter_defaults;
                         $logfile = $this->logfile = $this->get_config('logfile', $serendipity['serendipityPath'] . 'spamblock.log');
                         $required_fields = $this->get_config('required_fields', '');
 
+                        // Check CSRF [comments only, cannot be applied to trackbacks]
+                        if ($addData['type'] == 'NORMAL' && serendipity_db_bool($this->get_config('csrf', true))) {
+                            if (!serendipity_checkFormToken(false)) {
+                                $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_CSRF_REASON, $addData);
+                                $eventData = array('allow_comments' => false);
+                                $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_CSRF_REASON;
+                            }
+                        }
+
                         // Check required fields
                         if ($addData['type'] == 'NORMAL' && !empty($required_fields)) {
                             $required_field_list = explode(',', $required_fields);
@@ -789,12 +844,32 @@ var $filter_defaults;
 //                            $this->log($logfile, $eventData['id'], 'REJECTED', 'Captcha not needed: ' . $serendipity['POST']['captcha'] . ' / ' . $_SESSION['spamblock']['captcha'] . ' // Source: ' . $_SERVER['REQUEST_URI'], $addData);
                         }
 
-                        // Check for forced moderation
-                        if ($forcemoderation > 0 && $eventData['timestamp'] < (time() - ($forcemoderation * 60 * 60 * 24))) {
-                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION, $addData);
-                            $eventData['moderate_comments'] = true;
-                            $serendipity['csuccess']        = 'moderate';
-                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION;
+                        // Check for forced comment moderation
+                        if ($addData['type'] == 'NORMAL' && $forcemoderation > 0 && $eventData['timestamp'] < (time() - ($forcemoderation * 60 * 60 * 24))) {
+                            $this->log($logfile, $eventData['id'], $forcemoderation_treat, PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION, $addData);
+                            if ($forcemoderation_treat == 'reject') {
+                                $eventData = array('allow_comments' => false);
+                                $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION;
+                                return false;
+                            } else {
+                                $eventData['moderate_comments'] = true;
+                                $serendipity['csuccess']        = 'moderate';
+                                $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION;
+                            }
+                        }
+
+                        // Check for forced trackback moderation
+                        if ($addData['type'] != 'NORMAL' && $forcemoderationt > 0 && $eventData['timestamp'] < (time() - ($forcemoderationt * 60 * 60 * 24))) {
+                            $this->log($logfile, $eventData['id'], $forcemoderationt_treat, PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION, $addData);
+                            if ($forcemoderationt_treat == 'reject') {
+                                $eventData = array('allow_comments' => false);
+                                $serendipity['messagestack']['comments'][] = PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION;
+                                return false;
+                            } else {
+                                $eventData['moderate_comments'] = true;
+                                $serendipity['csuccess']        = 'moderate';
+                                $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION;
+                            }
                         }
 
                         // Check for maximum number of links before forcing moderation
@@ -852,6 +927,10 @@ var $filter_defaults;
                         echo '<div class="serendipity_commentDirection serendipity_comment_spamblock">' . PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_NOTICE . '</div>';
                     }
 
+                    if (serendipity_db_bool($this->get_config('csrf', true))) {
+                        echo serendipity_setFormToken('form');
+                    }
+
                     // Check whether to allow comments from registered authors
                     if (serendipity_userLoggedIn() && $this->inGroup()) {
                         return true;
@@ -1005,11 +1084,14 @@ var $filter_defaults;
 
                 case 'backend_view_comment':
                     $author_is_filtered = $this->checkFilter('authors', $eventData['author']);
-                    $eventData['action_author'] .= ' <a class="serendipityIconLink" title="' . ($author_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR : PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockAuthor]=' . $eventData['id'] . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($author_is_filtered ? 'un' : '') . 'configure.png') . '" /></a>';
+                    $clink1 = 'clink1' . $eventData['id'];
+                    $clink2 = 'clink2' . $eventData['id'];
+
+                    $eventData['action_author'] .= ' <a id="' . $clink1 . '" class="serendipityIconLink" title="' . ($author_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR : PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockAuthor]=' . $eventData['id'] . $addData . '#' . $clink1 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($author_is_filtered ? 'un' : '') . 'configure.png') . '" /></a>';
 
                     if (!empty($eventData['url'])) {
                         $url_is_filtered    = $this->checkFilter('urls', $eventData['url']);
-                        $eventData['action_url']    .= ' <a class="serendipityIconLink" title="' . ($url_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL : PLUGIN_EVENT_SPAMBLOCK_ADD_URL) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockURL]=' . $eventData['id'] . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($url_is_filtered ? 'un' : '') . 'configure.png') . '" /></a>';
+                        $eventData['action_url']    .= ' <a id="' . $clink2 . '" class="serendipityIconLink" title="' . ($url_is_filtered ? PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL : PLUGIN_EVENT_SPAMBLOCK_ADD_URL) . '" href="serendipity_admin.php?serendipity[adminModule]=comments&amp;serendipity[spamBlockURL]=' . $eventData['id'] . $addData . '#' . $clink2 . '"><img src="' . serendipity_getTemplateFile('admin/img/' . ($url_is_filtered ? 'un' : '') . 'configure.png') . '" /></a>';
                     }
 
                     return true;
