@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spartacus.php 1529 2006-12-01 09:07:52Z garvinhicking $
+<?php # $Id: serendipity_event_spartacus.php 1528 2006-12-01 08:58:47Z garvinhicking $
 
 /************
   TODO:
@@ -50,7 +50,10 @@ class serendipity_event_spartacus extends serendipity_event
             'backend_plugins_fetchplugin'        => true,
 
             'backend_templates_fetchlist'        => true,
-            'backend_templates_fetchtemplate'    => true
+            'backend_templates_fetchtemplate'    => true,
+
+            'backend_pluginlisting_header'         => true,
+            'backend_pluginlisting_header_upgrade' => true
         ));
         $propbag->add('groups', array('BACKEND_FEATURES'));
         $propbag->add('configuration', array('mirror_xml', 'mirror_files', 'chown', 'chmod_files', 'chmod_dir'));
@@ -264,6 +267,7 @@ class serendipity_event_spartacus extends serendipity_event
             require_once S9Y_PEAR_PATH . 'HTTP/Request.php';
             $options = array();
             serendipity_plugin_api::hook_event('backend_http_request', $options, 'spartacus');
+            serendipity_request_start();
             $req = &new HTTP_Request($url, $options);
 
             if (PEAR::isError($req->sendRequest()) || $req->getResponseCode() != '200') {
@@ -308,6 +312,7 @@ class serendipity_event_spartacus extends serendipity_event
                 echo '<br />';
                 $this->purgeCache = true;
             }
+            serendipity_request_end();
         }
 
         return $data;
@@ -746,6 +751,21 @@ class serendipity_event_spartacus extends serendipity_event
 
         if (isset($hooks[$event])) {
             switch($event) {
+                case 'backend_pluginlisting_header':
+                    echo '<br /><div id="upgrade_notice" class="serendipityAdminMsgSuccess">';
+                    echo '<a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[only_group]=UPGRADE" class="serendipityIconLink upgrade_sidebar"><img src="' . serendipity_getTemplateFile('admin/img/upgrade_now.png') . '" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" />' . PLUGIN_EVENT_SPARTACUS_CHECK_SIDEBAR . '</a> &nbsp; ';
+                    echo '<a href="?serendipity[adminModule]=plugins&amp;serendipity[adminAction]=addnew&amp;serendipity[only_group]=UPGRADE&amp;serendipity[type]=event" class="serendipityIconLink upgrade_event"><img src="' . serendipity_getTemplateFile('admin/img/upgrade_now.png') . '" style="border: 0px none ; vertical-align: middle; display: inline;" alt="" />' . PLUGIN_EVENT_SPARTACUS_CHECK_EVENT . '</a> ';
+                    echo '</div>';
+
+                    return true;
+                    break;
+
+                case 'backend_pluginlisting_header_upgrade':
+                    echo '<em>' . PLUGIN_EVENT_SPARTACUS_CHECK_HINT . '</em><br />';
+
+                    return true;
+                    break;
+
                 case 'backend_templates_fetchlist':
                     $eventData = $this->buildTemplateList($this->fetchOnline('template', true), 'template');
 
