@@ -1,8 +1,18 @@
-<?php # $Id: serendipity_config.inc.php 1531 2006-12-01 18:47:23Z garvinhicking $
+<?php # $Id: serendipity_config.inc.php 1830 2007-08-08 08:50:11Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
+if (defined('S9Y_FRAMEWORK')) {
+    return;
+}
+
+@define('S9Y_FRAMEWORK', true);
+
 if (!headers_sent()) {
+    if (isset($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) == 'on') {
+        @ini_set('session.name', 'SSLSID');
+        @ini_set('session.cookie_secure', '1');
+    }
     session_start();
 }
 
@@ -18,13 +28,10 @@ if (!defined('IN_serendipity')) {
     define('IN_serendipity', true);
 }
 
-include_once(S9Y_INCLUDE_PATH . 'include/compat.inc.php');
+include(S9Y_INCLUDE_PATH . 'include/compat.inc.php');
 
 // The version string
-$serendipity['version']         = '1.0.4';
-
-// Name of folder for the default theme
-$serendipity['defaultTemplate'] = 'carl_contest';
+$serendipity['version']         = '1.1.4';
 
 // Setting this to 'false' will enable debugging output. All alpa/beta/cvs snapshot versions will emit debug information by default. To increase the debug level (to enable Smarty debugging), set this flag to 'debug'.
 $serendipity['production']      = (preg_match('@\-(alpha|beta|cvs)@', $serendipity['version']) ? false : true);
@@ -64,8 +71,24 @@ if (!isset($serendipity['fetchLimit'])) {
     $serendipity['fetchLimit'] = 15;
 }
 
+if (!isset($serendipity['RSSfetchLimit'])) {
+    $serendipity['RSSfetchLimit'] = 15;
+}
+
+if (!isset($serendipity['mediaProperties'])) {
+    $serendipity['mediaProperties'] = 'DPI;COPYRIGHT;TITLE;COMMENT1:MULTI;COMMENT2:MULTI';
+}
+
 if (!isset($serendipity['use_PEAR'])) {
-    $serendipity['use_PEAR'] = false;
+    $serendipity['use_PEAR'] = true;
+}
+
+if (!isset($serendipity['useHTTP-Auth'])) {
+    $serendipity['useHTTP-Auth'] = true;
+}
+
+if (!isset($serendipity['CacheControl'])) {
+    $serendipity['CacheControl'] = false;
 }
 
 if (!isset($serendipity['expose_s9y'])) {
@@ -78,6 +101,9 @@ $serendipity['use_iframe'] = true;
 /* Default language for autodetection */
 $serendipity['autolang'] = 'en';
 
+/* Name of folder for the default theme */
+$serendipity['defaultTemplate'] = 'carl_contest';
+
 /* Availiable languages */
 $serendipity['languages'] = array('en' => 'English',
                                   'de' => 'German',
@@ -107,11 +133,12 @@ $serendipity['languages'] = array('en' => 'English',
                                   'cn' => 'Simplified Chinese (UTF-8)',
                                   'ja' => 'Japanese',
                                   'ko' => 'Korean',
+                                  'sa' => 'Arabic',
                                   'ta' => 'Tamil');
 
 /* Available Calendars */
 $serendipity['calendars'] = array('gregorian'   => 'Gregorian',
-                                  'jalali-utf8' => 'Jalali (utf8)');
+                                  'persian-utf8' => 'Persian (utf8)');
 
 /*
  *   Load main language file
@@ -135,23 +162,39 @@ $serendipity['charsets'] = array(
  *   Kill the script if we are not installed, and not inside the installer
  */
 if ( !defined('IN_installer') && IS_installed === false ) {
-    header('Location: ' . ($_SERVER['HTTPS'] == 'on' ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . str_replace('\\', '/', dirname($_SERVER['PHP_SELF'])) . '/serendipity_admin.php');
+    header('Location: ' . (strtolower($_SERVER['HTTPS']) == 'on' ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . str_replace('\\', '/', dirname($_SERVER['PHP_SELF'])) . '/serendipity_admin.php');
     serendipity_die(sprintf(SERENDIPITY_NOT_INSTALLED, 'serendipity_admin.php'));
 }
 
-// Check whether local or global PEAR should be used. You can put a
-// $serendipity['use_PEAR'] = true;
-// in your serendipity_config_local.inc.php file to enable this.
-// The required PEAR (and other) packages are mentioned in the file
-// bundled-libs/.current_version
-$old_include = @ini_get('include_path');
-if (@ini_set('include_path', $old_include . PATH_SEPARATOR . $serendipity['serendipityPath'] . PATH_SEPARATOR . $serendipity['serendipityPath'] . 'bundled-libs/') && $serendipity['use_PEAR']) {
-    @define('S9Y_PEAR', true);
+/* Do the PEAR dance. If $serendipity['use_PEAR'] is set to FALSE, Serendipity will first put its own PEAR include path.
+   By default, a local PEAR will be used. */
+if (function_exists('get_include_path')) {
+    $old_include = @get_include_path();
+} else {
+    $old_include = @ini_get('include_path');
+}
+
+
+$new_include = ($serendipity['use_PEAR'] ? $old_include . PATH_SEPARATOR : '')
+             . S9Y_INCLUDE_PATH . 'bundled-libs/' . PATH_SEPARATOR
+             . S9Y_INCLUDE_PATH . 'bundled-libs/Smarty/libs/' . PATH_SEPARATOR
+             . $serendipity['serendipityPath'] . PATH_SEPARATOR
+             . (!$serendipity['use_PEAR'] ? $old_include . PATH_SEPARATOR : '');
+
+if (function_exists('set_include_path')) {
+    $use_include = @set_include_path($new_include);
+} else {
+    $use_include = @ini_set('include_path', $new_include);
+}
+
+if ($use_include !== FALSE && $use_include == $new_include) {
+    @define('S9Y_PEAR',      true);
     @define('S9Y_PEAR_PATH', '');
 } else {
     @define('S9Y_PEAR', false);
     @define('S9Y_PEAR_PATH', S9Y_INCLUDE_PATH . 'bundled-libs/');
 }
+/* PEAR path setup inclusion finished */
 
 if (defined('IN_installer') && IS_installed === false) {
     $serendipity['lang'] = $serendipity['autolang'];
@@ -177,27 +220,33 @@ if (file_exists($_SERVER['DOCUMENT_ROOT'] . dirname($_SERVER['PHP_SELF']) . '/se
     $local_config = S9Y_INCLUDE_PATH . '/serendipity_config_local.inc.php';
 }
 
-if (is_readable($local_config)) {
-    include_once($local_config);
-} else {
-    serendipity_die(sprintf(INCLUDE_ERROR, $local_config));
+if (!is_readable($local_config)) {
+    $serendipity['lang'] = 'en';
+    include(S9Y_INCLUDE_PATH . 'include/lang.inc.php');
+    serendipity_die(sprintf(INCLUDE_ERROR . '<br />' . FILE_CREATE_YOURSELF, $local_config));
 }
 
+include($local_config);
+
 define('IS_up2date', version_compare($serendipity['version'], $serendipity['versionInstalled'], '<='));
 
 /*
  *  Include main functions
  */
-include_once(S9Y_INCLUDE_PATH . 'include/functions.inc.php');
+include(S9Y_INCLUDE_PATH . 'include/functions.inc.php');
 
-if (serendipity_FUNCTIONS_LOADED!== true) {
-    serendipity_die(sprintf(INCLUDE_ERROR, 'include/functions.inc.php'));
+if (serendipity_FUNCTIONS_LOADED !== true) {
+    $serendipity['lang'] = 'en';
+    include(S9Y_INCLUDE_PATH . 'include/lang.inc.php');
+    serendipity_die(sprintf(INCLUDE_ERROR . '<br />' . FILE_CREATE_YOURSELF, 'include/functions.inc.php'));
 }
 
 /*
  *   Attempt to connect to the database
  */
 if (!serendipity_db_connect()) {
+    $serendipity['lang'] = 'en';
+    include(S9Y_INCLUDE_PATH . 'include/lang.inc.php');
     serendipity_die(DATABASE_ERROR);
 }
 
@@ -212,6 +261,25 @@ serendipity_load_configuration();
  */
 
 if (IS_installed === true) {
+    // Import HTTP auth (mostly used for RSS feeds)
+    if ($serendipity['useHTTP-Auth'] && (isset($_REQUEST['http_auth']) || isset($_SERVER['PHP_AUTH_USER']))) {
+        if (!isset($_SERVER['PHP_AUTH_USER'])) {
+            header("WWW-Authenticate: Basic realm=\"Feed Login\"");
+            header("HTTP/1.0 401 Unauthorized");
+            exit;
+        } else {
+            if (!isset($serendipity['POST']['user'])) {
+                $serendipity['POST']['user'] = $_SERVER['PHP_AUTH_USER'];
+            }
+            if (!isset($serendipity['POST']['pass'])) {
+                $serendipity['POST']['pass'] = $_SERVER['PHP_AUTH_PW'];
+            }
+        }
+    } elseif (isset($_REQUEST['http_auth_user']) && isset($_REQUEST['http_auth_pw'])) {
+        $serendipity['POST']['user'] = $_REQUEST['http_auth_user'];
+        $serendipity['POST']['pass'] = $_REQUEST['http_auth_pw'];
+    }
+
     serendipity_login(false);
 }
 
@@ -274,7 +342,7 @@ $serendipity['permissionLevels'] = array(USERLEVEL_EDITOR => USERLEVEL_EDITOR_DE
 
 if ( (isset($serendipity['autodetect_baseURL']) && serendipity_db_bool($serendipity['autodetect_baseURL'])) ||
      (isset($serendipity['embed']) && serendipity_db_bool($serendipity['embed'])) ) {
-    $serendipity['baseURL'] = 'http' . (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on' ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . (!strstr($_SERVER['HTTP_HOST'], ':') && !empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] != '80' ? ':' . $_SERVER['SERVER_PORT'] : '') . $serendipity['serendipityHTTPPath'];
+    $serendipity['baseURL'] = 'http' . (isset($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) == 'on' ? 's' : '') . '://' . $_SERVER['HTTP_HOST'] . (!strstr($_SERVER['HTTP_HOST'], ':') && !empty($_SERVER['SERVER_PORT']) && $_SERVER['SERVER_PORT'] != '80' ? ':' . $_SERVER['SERVER_PORT'] : '') . $serendipity['serendipityHTTPPath'];
 }
 
 /*
@@ -311,7 +379,6 @@ if (isset($_SESSION['serendipityUser'])) {
 if (isset($_SESSION['serendipityEmail'])) {
     $serendipity['email'] = $_SESSION['serendipityEmail'];
 }
-
 serendipity_plugin_api::hook_event('frontend_configure', $serendipity);
 
 /* vim: set sts=4 ts=4 expandtab : */
